(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    333690,       8689]*)
(*NotebookOutlinePosition[    417305,      11520]*)
(*  CellTagsIndexPosition[    417261,      11516]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["\<\
Examples of an exact diagonalization study of a two-orbital model
Part of package SNEG,http://nrgljubljana.ijs.si/sneg
Rok Zitko,rok.zitko@ijs.si, Feb 2007, Mar 2007\
\>", "Text",
  Background->GrayLevel[0.900008]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(<< sneg`sneg`;\)\)], "Input"],

Cell[BoxData[
    \("sneg 1.167 Copyright (C) 2007 Rok Zitko"\)], "Print"]
}, Open  ]],

Cell[BoxData[
    \(<< Graphics`Graphics`\)], "Input"],

Cell[BoxData[
    \(<< diagonalize.m\)], "Input"],

Cell[BoxData[{
    \(\(Off[General::spell1];\)\), "\[IndentingNewLine]", 
    \(snegfermionoperators[c, d]\), "\[IndentingNewLine]", 
    \(snegrealconstants[\[Epsilon]s, \[Delta]d, J, U]\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*\ 
      We\ have\ an\ s - orbital\ and\ a\ d - orbital\ with\ e - 
        e\ repulsion\ U . \ 
            They\ are\ coupled\ by\ exchange\ interaction\ \(\(J\)\(.\)\)\ \
*) \)\(\[IndentingNewLine]\)\(H = \[Epsilon]s\ \((number[c[1]] - 
                1)\) + \[Delta]d\ \((number[d[1]] - 1)\) + 
          U/2\ pow[number[d[1]] - 1, 2] + J\ spinspin[c[1], d[1]] // 
        FullSimplify\)\)\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"\[Epsilon]s", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}], "+", 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], ")"}]}], "+", 
      RowBox[{\(1\/4\), " ", 
        RowBox[{"(", 
          RowBox[{\(2\ \((U - 2\ \((\[Delta]d + \[Epsilon]s)\))\)\), "-", 
            RowBox[{"2", " ", \((U - 2\ \[Delta]d)\), " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["d", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ d, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["d", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)]}], "\<\"\"\>"],
                          Subsuperscript[ d, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], ""],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm]}], "+", 
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["d", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ d, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["d", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\"\>"],
                          Subsuperscript[ d, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], ""],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm]}]}], ")"}]}], "-", 
            RowBox[{"J", " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["d", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ d, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)]}], "\<\"\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], ""],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["d", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)]}], "\<\"\"\>"],
                          Subsuperscript[ d, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], ""],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm]}], "-", 
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["d", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ d, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)]}], "\<\"\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], ""],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["d", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\"\>"],
                          Subsuperscript[ d, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], ""],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm]}], "+", 
                  RowBox[{"2", 
                    RowBox[{
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["d", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ d, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], ""],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["d", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\"\>"],
                            Subsuperscript[ d, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], ""],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm]}]}], "+", 
                  RowBox[{"2", 
                    RowBox[{
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["d", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ d, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], ""],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["d", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\"\>"],
                            Subsuperscript[ d, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], ""],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm]}]}], "-", 
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["d", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ d, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], ""],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["d", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)]}], "\<\"\"\>"],
                          Subsuperscript[ d, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], ""],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm]}], "+", 
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["d", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ d, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], ""],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["d", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\"\>"],
                          Subsuperscript[ d, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], ""],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm]}]}], ")"}]}], "-", 
            RowBox[{"4", " ", "U", " ", 
              RowBox[{
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["d", 
                        RowBox[{"1", 
                          TagBox[
                            StyleBox["\<\"\[DownArrow]\"\>",
                              FontColor->RGBColor[0, 0, 1]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                      Subsuperscript[ d, 
                        RowBox[ {1, 
                          StyleForm[ 
                          "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                        "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["d", 
                        RowBox[{"1", 
                          TagBox[
                            StyleBox["\<\"\[UpArrow]\"\>",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                      Subsuperscript[ d, 
                        RowBox[ {1, 
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["d", 
                        RowBox[{"1", 
                          TagBox[
                            StyleBox["\<\"\[DownArrow]\"\>",
                              FontColor->RGBColor[0, 0, 1]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              0, 0, 1]]&)]}], "\<\"\"\>"],
                      Subsuperscript[ d, 
                        RowBox[ {1, 
                          StyleForm[ 
                          "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                        ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["d", 
                        RowBox[{"1", 
                          TagBox[
                            StyleBox["\<\"\[UpArrow]\"\>",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1, 0, 0]]&)]}], "\<\"\"\>"],
                      Subsuperscript[ d, 
                        RowBox[ {1, 
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(basisops = {c[1], d[1]};\)\), "\[IndentingNewLine]", 
    \(\(diagSetupBasisQSZ[];\)\)}], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({\(-2\), 0}\), \({1}\)},
            {\({\(-1\), \(-\(1\/2\)\)}\), 
              RowBox[{"{", 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], ",", 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}], "}"}]},
            {\({\(-1\), 1\/2}\), 
              RowBox[{"{", 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], ",", 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}], "}"}]},
            {\({0, \(-1\)}\), 
              RowBox[{"{", 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}], "}"}]},
            {\({0, 0}\), 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"\<\"-\"\>", 
                    RowBox[{
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["d", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ d, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["d", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ d, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm]}]}], ",", 
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["d", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ d, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm]}], ",", 
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["d", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ d, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm]}], ",", 
                  RowBox[{"\<\"-\"\>", 
                    RowBox[{
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm]}]}]}], "}"}]},
            {\({0, 1}\), 
              RowBox[{"{", 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}], "}"}]},
            {\({1, \(-\(1\/2\)\)}\), 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"\<\"-\"\>", 
                    RowBox[{
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["d", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ d, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["d", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ d, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm]}]}], ",", 
                  RowBox[{"\<\"-\"\>", 
                    RowBox[{
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["d", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ d, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm]}]}]}], "}"}]},
            {\({1, 1\/2}\), 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"\<\"-\"\>", 
                    RowBox[{
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["d", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ d, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["d", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ d, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm]}]}], ",", 
                  RowBox[{"\<\"-\"\>", 
                    RowBox[{
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["d", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ d, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm]}]}]}], "}"}]},
            {\({2, 0}\), 
              RowBox[{"{", 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["d", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ d, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}], "}"}]}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Print"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({\(-2\), 0}\), 
              RowBox[{"{", 
                TagBox[
                  RowBox[{
                    TagBox[
                      StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                        FontColor->RGBColor[0, 0.392187, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0.0, 0.39219300000000001, 0.0]]&)], 
                    TagBox[
                      StyleBox["\<\"\[EmptyRectangle]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                    TagBox[
                      StyleBox["\<\"\[EmptyRectangle]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                    TagBox[
                      StyleBox["\<\"\[EmptyRectangle]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                    TagBox[
                      StyleBox["\<\"\[EmptyRectangle]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                    TagBox[
                      StyleBox["\<\"\[RightAngleBracket]\"\>",
                        FontColor->RGBColor[0, 0.392187, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0.0, 0.39219300000000001, 0.0]]&)]}],
                  DisplayForm], "}"}]},
            {\({\(-1\), \(-\(1\/2\)\)}\), 
              RowBox[{"{", 
                RowBox[{
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm], ",", 
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm]}], "}"}]},
            {\({\(-1\), 1\/2}\), 
              RowBox[{"{", 
                RowBox[{
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm], ",", 
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm]}], "}"}]},
            {\({0, \(-1\)}\), 
              RowBox[{"{", 
                TagBox[
                  RowBox[{
                    TagBox[
                      StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                        FontColor->RGBColor[0, 0.392187, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0.0, 0.39219300000000001, 0.0]]&)], 
                    TagBox[
                      StyleBox["\<\"\[EmptyRectangle]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                    TagBox[
                      StyleBox["\<\"\[FilledRectangle]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                    TagBox[
                      StyleBox["\<\"\[EmptyRectangle]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                    TagBox[
                      StyleBox["\<\"\[FilledRectangle]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                    TagBox[
                      StyleBox["\<\"\[RightAngleBracket]\"\>",
                        FontColor->RGBColor[0, 0.392187, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0.0, 0.39219300000000001, 0.0]]&)]}],
                  DisplayForm], "}"}]},
            {\({0, 0}\), 
              RowBox[{"{", 
                RowBox[{
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm], ",", 
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm], ",", 
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm], ",", 
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm]}], "}"}]},
            {\({0, 1}\), 
              RowBox[{"{", 
                TagBox[
                  RowBox[{
                    TagBox[
                      StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                        FontColor->RGBColor[0, 0.392187, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0.0, 0.39219300000000001, 0.0]]&)], 
                    TagBox[
                      StyleBox["\<\"\[FilledRectangle]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                    TagBox[
                      StyleBox["\<\"\[EmptyRectangle]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                    TagBox[
                      StyleBox["\<\"\[FilledRectangle]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                    TagBox[
                      StyleBox["\<\"\[EmptyRectangle]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                    TagBox[
                      StyleBox["\<\"\[RightAngleBracket]\"\>",
                        FontColor->RGBColor[0, 0.392187, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0.0, 0.39219300000000001, 0.0]]&)]}],
                  DisplayForm], "}"}]},
            {\({1, \(-\(1\/2\)\)}\), 
              RowBox[{"{", 
                RowBox[{
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm], ",", 
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm]}], "}"}]},
            {\({1, 1\/2}\), 
              RowBox[{"{", 
                RowBox[{
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm], ",", 
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm]}], "}"}]},
            {\({2, 0}\), 
              RowBox[{"{", 
                TagBox[
                  RowBox[{
                    TagBox[
                      StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                        FontColor->RGBColor[0, 0.392187, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0.0, 0.39219300000000001, 0.0]]&)], 
                    TagBox[
                      StyleBox["\<\"\[FilledRectangle]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                    TagBox[
                      StyleBox["\<\"\[FilledRectangle]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                    TagBox[
                      StyleBox["\<\"\[FilledRectangle]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                    TagBox[
                      StyleBox["\<\"\[FilledRectangle]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                    TagBox[
                      StyleBox["\<\"\[RightAngleBracket]\"\>",
                        FontColor->RGBColor[0, 0.392187, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0.0, 0.39219300000000001, 0.0]]&)]}],
                  DisplayForm], "}"}]}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(diagSetupHam[];\)\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({\(-2\), 0}\), 
              TagBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\(1\/2\ \((U - 2\ \((\[Delta]d + \[Epsilon]s)\))\)\)}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
                Function[ BoxForm`e$, 
                  MatrixForm[ BoxForm`e$]]]},
            {\({\(-1\), \(-\(1\/2\)\)}\), 
              TagBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\(-\[Epsilon]s\), "0"},
                      {"0", \(1\/2\ \((U - 2\ \[Delta]d)\)\)}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
                Function[ BoxForm`e$, 
                  MatrixForm[ BoxForm`e$]]]},
            {\({\(-1\), 1\/2}\), 
              TagBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\(-\[Epsilon]s\), "0"},
                      {"0", \(1\/2\ \((U - 2\ \[Delta]d)\)\)}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
                Function[ BoxForm`e$, 
                  MatrixForm[ BoxForm`e$]]]},
            {\({0, \(-1\)}\), 
              TagBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\(J\/4\)}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
                Function[ BoxForm`e$, 
                  MatrixForm[ BoxForm`e$]]]},
            {\({0, 0}\), 
              TagBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\(U\/2 + \[Delta]d - \[Epsilon]s\), "0", "0", "0"},
                      {"0", \(-\(J\/4\)\), \(J\/2\), "0"},
                      {"0", \(J\/2\), \(-\(J\/4\)\), "0"},
                      {"0", "0", "0", \(U\/2 - \[Delta]d + \[Epsilon]s\)}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
                Function[ BoxForm`e$, 
                  MatrixForm[ BoxForm`e$]]]},
            {\({0, 1}\), 
              TagBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\(J\/4\)}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
                Function[ BoxForm`e$, 
                  MatrixForm[ BoxForm`e$]]]},
            {\({1, \(-\(1\/2\)\)}\), 
              TagBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\(U\/2 + \[Delta]d\), "0"},
                      {"0", "\[Epsilon]s"}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
                Function[ BoxForm`e$, 
                  MatrixForm[ BoxForm`e$]]]},
            {\({1, 1\/2}\), 
              TagBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\(U\/2 + \[Delta]d\), "0"},
                      {"0", "\[Epsilon]s"}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
                Function[ BoxForm`e$, 
                  MatrixForm[ BoxForm`e$]]]},
            {\({2, 0}\), 
              TagBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\(U\/2 + \[Delta]d + \[Epsilon]s\)}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
                Function[ BoxForm`e$, 
                  MatrixForm[ BoxForm`e$]]]}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Print"]
}, Open  ]],

Cell[BoxData[
    \(\(\( (*\ 
      Sample\ calculation\ *) \)\(\[IndentingNewLine]\)\(diagonalize[{\
\[Epsilon]s \[Rule] 1, \[Delta]d \[Rule] 0, J \[Rule] 1/5, 
        U \[Rule] 1}]\)\)\)], "Input"],

Cell["", "Text",
  Editable->False,
  Selectable->False,
  CellFrame->{{0, 0}, {0, 3}},
  ShowCellBracket->False,
  CellMargins->{{0, 0}, {1, 1}},
  CellElementSpacings->{"CellMinHeight"->1},
  CellFrameMargins->False,
  CellFrameColor->RGBColor[0, 0, 1],
  CellSize->{Inherited, 5}],

Cell[BoxData[
    \(\(\( (*\ For\ \((Q, Sz)\), \ 
      the\ \((non - 
            accidental)\)\ degeneracy\ of\ states\ in\ each\ subspace\ is\ \
simply\ 1. \ *) \)\(\[IndentingNewLine]\)\(deg[{q_, sz_}] := 
        1;\)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*\ Sum\ of\ degeneracies\ *) \)\(\[IndentingNewLine]\)\(sum1[eig, 
      1 &]\[IndentingNewLine]\[IndentingNewLine] (*\ 
      Number\ of\ states\ *) \[IndentingNewLine]
    sum1[eig, Length@First[#] &]\n\[IndentingNewLine] (*\ 
      Number\ of\ states\ *) \[IndentingNewLine]
    Z = sum1expr[eig2, 1]\n
    9\n
    16\n
    16\)\)\)], "Input"],

Cell[BoxData[
    \(9\)], "Output"],

Cell[BoxData[
    \(16\)], "Output"],

Cell[BoxData[
    \(16\)], "Output"],

Cell[BoxData[
    \(9\)], "Output"],

Cell[BoxData[
    \(16\)], "Output"],

Cell[BoxData[
    \(16\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*\ Partition\ function\ *) \)\(\[IndentingNewLine]\)\(Z = 
      tdtr1expr[eig2, 1]\[IndentingNewLine]
    tdtr1expr[eig2, pow[number[d[1]], 2]]/Z\n
    % /. beta \[Rule] 10. \)\)\)], "Input"],

Cell[BoxData[
    \(2\ \[ExponentialE]\^\(\(\(-3\)\ beta\)/2\) + 
      2\ \[ExponentialE]\^\(-beta\) + 4\ \[ExponentialE]\^\(\(-beta\)/2\) + 
      3\ \[ExponentialE]\^\(\(-beta\)/20\) + \[ExponentialE]\^\(\(3\ \
beta\)/20\) + 2\ \[ExponentialE]\^\(beta/2\) + 
      2\ \[ExponentialE]\^beta\)], "Output"],

Cell[BoxData[
    \(\(4\ \[ExponentialE]\^\(\(\(-3\)\ beta\)/2\) + 2\ \
\[ExponentialE]\^\(-beta\) + 8\ \[ExponentialE]\^\(\(-beta\)/2\) + 3\ \
\[ExponentialE]\^\(\(-beta\)/20\) + \[ExponentialE]\^\(\(3\ beta\)/20\) + 4\ \
\[ExponentialE]\^\(beta/2\) + 2\ \[ExponentialE]\^beta\)\/\(2\ \
\[ExponentialE]\^\(\(\(-3\)\ beta\)/2\) + 2\ \[ExponentialE]\^\(-beta\) + 4\ \
\[ExponentialE]\^\(\(-beta\)/2\) + 3\ \[ExponentialE]\^\(\(-beta\)/20\) + \
\[ExponentialE]\^\(\(3\ beta\)/20\) + 2\ \[ExponentialE]\^\(beta/2\) + 2\ \
\[ExponentialE]\^beta\)\)], "Output"],

Cell[BoxData[
    \(1.0066925036860068`\)], "Output"]
}, Open  ]],

Cell["", "Text",
  Editable->False,
  Selectable->False,
  CellFrame->{{0, 0}, {0, 0.5}},
  ShowCellBracket->False,
  CellMargins->{{0, 0}, {1, 1}},
  CellElementSpacings->{"CellMinHeight"->1},
  CellFrameMargins->False,
  CellFrameColor->RGBColor[0, 0, 1],
  CellSize->{Inherited, 3}],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*\ 
      Number\ of\ subspaces\ squared\ *) \)\(\[IndentingNewLine]\)\(sum2[
      eig2, 1 &]\[IndentingNewLine]\[IndentingNewLine] (*\ 
      Number\ of\ states\ squared\ *) \[IndentingNewLine]
    sum2[eig2, 
      Length\ @\ First[#1]\ \ Length\ @\ 
            First[#2] &]\[IndentingNewLine]\[IndentingNewLine] (*\ 
      Number\ of\ states\ *) \[IndentingNewLine]
    sum2expr[eig2, 1]\)\)\)], "Input"],

Cell[BoxData[
    \(81\)], "Output"],

Cell[BoxData[
    \(256\)], "Output"],

Cell[BoxData[
    \(16\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*\ 
      T\  \[Rule] \ \[Infinity]\ results\ *) \)\(\[IndentingNewLine]\)\(Z = 
      sum2expr[eig2, 1]\[IndentingNewLine]
    sum2expr[eig2, number[d[1]]]/Z\[IndentingNewLine]
    sum2expr[eig2, pow[number[d[1]], 2]]/Z\)\)\)], "Input"],

Cell[BoxData[
    \(16\)], "Output"],

Cell[BoxData[
    \(1\)], "Output"],

Cell[BoxData[
    \(3\/2\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*\ 
      TD\ expectation\ value\ of\ n_d^2\ *) \)\(\[IndentingNewLine]\)\(Z = 
      tdtr2expr[eig2, 1]\[IndentingNewLine]
    tdtr2expr[eig2, pow[number[d[1]], 2]]/Z\[IndentingNewLine]
    % /. beta \[Rule] 0. \)\)\)], "Input"],

Cell[BoxData[
    \(2\ \[ExponentialE]\^\(\(\(-3\)\ beta\)/2\) + 
      2\ \[ExponentialE]\^\(-beta\) + 4\ \[ExponentialE]\^\(\(-beta\)/2\) + 
      3\ \[ExponentialE]\^\(\(-beta\)/20\) + \[ExponentialE]\^\(\(3\ \
beta\)/20\) + 2\ \[ExponentialE]\^\(beta/2\) + 
      2\ \[ExponentialE]\^beta\)], "Output"],

Cell[BoxData[
    \(\(4\ \[ExponentialE]\^\(\(\(-3\)\ beta\)/2\) + 2\ \
\[ExponentialE]\^\(-beta\) + 8\ \[ExponentialE]\^\(\(-beta\)/2\) + 3\ \
\[ExponentialE]\^\(\(-beta\)/20\) + \[ExponentialE]\^\(\(3\ beta\)/20\) + 4\ \
\[ExponentialE]\^\(beta/2\) + 2\ \[ExponentialE]\^beta\)\/\(2\ \
\[ExponentialE]\^\(\(\(-3\)\ beta\)/2\) + 2\ \[ExponentialE]\^\(-beta\) + 4\ \
\[ExponentialE]\^\(\(-beta\)/2\) + 3\ \[ExponentialE]\^\(\(-beta\)/20\) + \
\[ExponentialE]\^\(\(3\ beta\)/20\) + 2\ \[ExponentialE]\^\(beta/2\) + 2\ \
\[ExponentialE]\^beta\)\)], "Output"],

Cell[BoxData[
    \(1.5`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(tdtr2exprALT[eig2, pow[number[d[1]], 2]]/Z\)], "Input"],

Cell[BoxData[
    \(\(4\ \[ExponentialE]\^\(\(\(-3\)\ beta\)/2\) + 2\ \
\[ExponentialE]\^\(-beta\) + 8\ \[ExponentialE]\^\(\(-beta\)/2\) + 3\ \
\[ExponentialE]\^\(\(-beta\)/20\) + \[ExponentialE]\^\(\(3\ beta\)/20\) + 4\ \
\[ExponentialE]\^\(beta/2\) + 2\ \[ExponentialE]\^beta\)\/\(2\ \
\[ExponentialE]\^\(\(\(-3\)\ beta\)/2\) + 2\ \[ExponentialE]\^\(-beta\) + 4\ \
\[ExponentialE]\^\(\(-beta\)/2\) + 3\ \[ExponentialE]\^\(\(-beta\)/20\) + \
\[ExponentialE]\^\(\(3\ beta\)/20\) + 2\ \[ExponentialE]\^\(beta/2\) + 2\ \
\[ExponentialE]\^beta\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(specd = spectral2expr[eig2, d[CR, 1, UP]]/Z\), "\[IndentingNewLine]", 
    \(Chop\ @\ Simplify[specd /. beta \[Rule] 100. ]\)}], "Input"],

Cell[BoxData[
    \(\((1\/2\ \((\[ExponentialE]\^\(\(-beta\)/2\) + \[ExponentialE]\^\(\(3\ \
beta\)/20\))\)\ Delta[\(-\(13\/20\)\) + 
                omega] + \((\[ExponentialE]\^\(\(\(-3\)\ beta\)/2\) + \
\[ExponentialE]\^\(-beta\))\)\ Delta[\(-\(1\/2\)\) + 
                omega] + \((\[ExponentialE]\^\(beta/2\) + \
\[ExponentialE]\^beta)\)\ Delta[\(-\(1\/2\)\) + omega] + 
          3\/2\ \((\[ExponentialE]\^\(\(-beta\)/2\) + \
\[ExponentialE]\^\(\(-beta\)/20\))\)\ Delta[\(-\(9\/20\)\) + omega] + 
          3\/2\ \((\[ExponentialE]\^\(\(-beta\)/2\) + \
\[ExponentialE]\^\(\(-beta\)/20\))\)\ Delta[
              9\/20 + omega] + \((\[ExponentialE]\^\(\(\(-3\)\ beta\)/2\) + \
\[ExponentialE]\^\(-beta\))\)\ Delta[
              1\/2 + omega] + \((\[ExponentialE]\^\(beta/2\) + \
\[ExponentialE]\^beta)\)\ Delta[1\/2 + omega] + 
          1\/2\ \((\[ExponentialE]\^\(\(-beta\)/2\) + \[ExponentialE]\^\(\(3\ \
beta\)/20\))\)\ Delta[
              13\/20 + 
                omega])\)/\((2\ \[ExponentialE]\^\(\(\(-3\)\ beta\)/2\) + 
          2\ \[ExponentialE]\^\(-beta\) + 
          4\ \[ExponentialE]\^\(\(-beta\)/2\) + 
          3\ \[ExponentialE]\^\(\(-beta\)/20\) + \[ExponentialE]\^\(\(3\ beta\
\)/20\) + 2\ \[ExponentialE]\^\(beta/2\) + 
          2\ \[ExponentialE]\^beta)\)\)], "Output"],

Cell[BoxData[
    \(0.5`\ Delta[\(-\(1\/2\)\) + omega] + 
      0.5`\ Delta[1\/2 + omega]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(specc = spectral2expr[eig2, c[CR, 1, UP]]/Z\), "\[IndentingNewLine]", 
    \(Chop\ @\ Simplify[specc /. beta \[Rule] 100. ]\)}], "Input"],

Cell[BoxData[
    \(\((1\/2\ \((\[ExponentialE]\^\(\(3\ beta\)/20\) + \
\[ExponentialE]\^beta)\)\ Delta[17\/20 + omega] + 
          3\/2\ \((\[ExponentialE]\^\(-beta\) + \
\[ExponentialE]\^\(\(-beta\)/20\))\)\ Delta[19\/20 + omega] + 
          2\ \((\[ExponentialE]\^\(\(\(-3\)\ beta\)/2\) + \[ExponentialE]\^\(\
\(-beta\)/2\))\)\ Delta[1 + omega] + 
          2\ \((\[ExponentialE]\^\(\(-beta\)/2\) + \
\[ExponentialE]\^\(beta/2\))\)\ Delta[1 + omega] + 
          3\/2\ \((\[ExponentialE]\^\(\(-beta\)/20\) + \[ExponentialE]\^beta)\
\)\ Delta[21\/20 + omega] + 
          1\/2\ \((\[ExponentialE]\^\(-beta\) + \[ExponentialE]\^\(\(3\ \
beta\)/20\))\)\ Delta[
              23\/20 + 
                omega])\)/\((2\ \[ExponentialE]\^\(\(\(-3\)\ beta\)/2\) + 
          2\ \[ExponentialE]\^\(-beta\) + 
          4\ \[ExponentialE]\^\(\(-beta\)/2\) + 
          3\ \[ExponentialE]\^\(\(-beta\)/20\) + \[ExponentialE]\^\(\(3\ beta\
\)/20\) + 2\ \[ExponentialE]\^\(beta/2\) + 
          2\ \[ExponentialE]\^beta)\)\)], "Output"],

Cell[BoxData[
    \(0.25`\ Delta[17\/20 + omega] + 0.75`\ Delta[21\/20 + omega]\)], "Output"]
}, Open  ]],

Cell["", "Text",
  Editable->False,
  Selectable->False,
  CellFrame->{{0, 0}, {0, 3}},
  ShowCellBracket->False,
  CellMargins->{{0, 0}, {1, 1}},
  CellElementSpacings->{"CellMinHeight"->1},
  CellFrameMargins->False,
  CellFrameColor->RGBColor[0, 0, 1],
  CellSize->{Inherited, 5}],

Cell[BoxData[{
    \(\(evl = {number[d[1]], pow[number[d[1]], 2], number[c[1]], 
          pow[number[c[1]], 2], 
          spinspin[c[1], d[1]]};\)\), "\[IndentingNewLine]", 
    \(\(spl = {d[CR, 1, UP], c[CR, 1, UP]};\)\), "\[IndentingNewLine]", 
    \(calculate[evl, spl]\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Simplify[expvs /. beta \[Rule] 100. ] // 
      Chop\), "\[IndentingNewLine]", 
    \(Simplify[specs /. beta \[Rule] 100. ] // Chop\)}], "Input"],

Cell[BoxData[
    \({1, 1.`, 0, 0, 0}\)], "Output"],

Cell[BoxData[
    \({0.5`\ Delta[\(-\(1\/2\)\) + omega] + 0.5`\ Delta[1\/2 + omega], 
      0.25`\ Delta[17\/20 + omega] + 
        0.75`\ Delta[21\/20 + omega]}\)], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(\(ClearAll[expvresults, specresults];\)\), "\[IndentingNewLine]", 
    \(\(doit[value_, CALCCODE_:  calculate] := 
        Module[{}, \[IndentingNewLine]diagonalize[{\[Epsilon]s \[Rule] 
                value, \[Delta]d \[Rule] 0, J \[Rule] 1/5, 
              U \[Rule] 1}]; \[IndentingNewLine]expvs = \(specs = 
              Infinity\); \[IndentingNewLine]CALCCODE[evl, 
            spl]; \[IndentingNewLine] (*\ Zero\ temperature\ calculation, \ 
            1/T\  >> \ 1. \ *) \[IndentingNewLine]expvs = 
            Simplify[expvs /. beta \[Rule] 100. ] // 
              Chop; \[IndentingNewLine]specs = 
            Simplify[specs /. beta \[Rule] 100. ] // 
              Chop; \[IndentingNewLine]AppendTo[values, 
            value]; \[IndentingNewLine]expvresults[value] = 
            expvs; \[IndentingNewLine]specresults[value] = 
            specs;\[IndentingNewLine]];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(values = {};\)\), "\[IndentingNewLine]", 
    \(Scan[\((Print[#]; doit[#])\) &, 
      Table[x, {x, \(-1\), 1, 0.2}]]\)}], "Input"],

Cell[BoxData[
    \(\(-1\)\)], "Print"],

Cell[BoxData[
    \(\(-0.8`\)\)], "Print"],

Cell[BoxData[
    \(\(-0.6`\)\)], "Print"],

Cell[BoxData[
    \(\(-0.39999999999999997`\)\)], "Print"],

Cell[BoxData[
    \(\(-0.19999999999999996`\)\)], "Print"],

Cell[BoxData[
    \(5.551115123125783`*^-17\)], "Print"],

Cell[BoxData[
    \(0.20000000000000007`\)], "Print"],

Cell[BoxData[
    \(0.4000000000000001`\)], "Print"],

Cell[BoxData[
    \(0.6000000000000001`\)], "Print"],

Cell[BoxData[
    \(0.8`\)], "Print"],

Cell[BoxData[
    \(1.`\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MatrixForm\ @\ Map[{#, expvresults[#]} &, values]\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(-1\), \({1, 1.`, 2.`, 4.`, 0}\)},
            {\(-0.8`\), \({1, 1.`, 2.`, 4.`, 0}\)},
            {\(-0.6`\), \({1, 0.9999999999999999`, 1.9999999999999998`, 
                3.9999999999999996`, 0}\)},
            {\(-0.39999999999999997`\), \({1, 0.9999999999999999`, 
                1.999999999993056`, 3.999999999979168`, 0}\)},
            {\(-0.19999999999999996`\), \({1, 1.`, 1.996642338352805`, 
                3.989927015058415`, \(-0.002518246214634194`\)}\)},
            {
              "5.551115123125783`*^-17", \({1, 1.`, 1.`, 
                1.000001223607777`, \(-0.7499990761107137`\)}\)},
            {
              "0.20000000000000007`", \({1, 1.`, 0.0033576616471948577`, 
                0.003357661647194866`, \(-0.0025182462146341672`\)}\)},
            {"0.4000000000000001`", \({1, 0.9999999999999999`, 0, 0, 0}\)},
            {"0.6000000000000001`", \({1, 0.9999999999999999`, 0, 0, 0}\)},
            {"0.8`", \({1, 1.`, 0, 0, 0}\)},
            {"1.`", \({1, 1.`, 0, 0, 0}\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(\(rule[x_] := 
        weight_\ Delta[omega + freq_. ] \[RuleDelayed] 
          weight\ \ Point[{x, freq}];\)\), "\[IndentingNewLine]", 
    \(\(cfn[x_] := RGBColor[x, 0, 1 - x];\)\), "\[IndentingNewLine]", 
    \(\(pointswithsize[lst_] := 
        Flatten\ @\ \((\ lst /. Plus \[Rule] List)\) /. 
          weight_\ p_Point \[RuleDelayed] {cfn[weight], 
              PointSize[scale\ weight], p};\)\)}], "Input"],

Cell[BoxData[{
    \(\(scale = 0.1;\)\), "\[IndentingNewLine]", 
    \(\(pts = 
        Map[specresults[#] /. rule[#] &, 
          values];\)\), "\[IndentingNewLine]", 
    \(\(pts1 = 
        pointswithsize\ @\ \ pts[\([All, 1]\)];\)\), "\[IndentingNewLine]", 
    \(\(pts2 = pointswithsize\ @\ \ pts[\([All, 2]\)];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show\ [\ 
      GraphicsArray[\ {Graphics\ [pts1, Frame \[Rule] True], 
          Graphics[pts2, Frame \[Rule] True]}], 
      ImageSize \[Rule] 12\ 72]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
%%ImageSize: 864 254.277 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.309017 0.452772 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -12 -9 ]
[.2619 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .03735 -24 -4.5 ]
[-0.0125 .03735 0 4.5 ]
[-0.0125 .12791 -24 -4.5 ]
[-0.0125 .12791 0 4.5 ]
[-0.0125 .21846 -24 -4.5 ]
[-0.0125 .21846 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .39957 -18 -4.5 ]
[-0.0125 .39957 0 4.5 ]
[-0.0125 .49013 -18 -4.5 ]
[-0.0125 .49013 0 4.5 ]
[-0.0125 .58068 -18 -4.5 ]
[-0.0125 .58068 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-1)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(0.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .03735 m
.00625 .03735 L
s
[(-0.6)] -0.0125 .03735 1 0 Mshowa
0 .12791 m
.00625 .12791 L
s
[(-0.4)] -0.0125 .12791 1 0 Mshowa
0 .21846 m
.00625 .21846 L
s
[(-0.2)] -0.0125 .21846 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .39957 m
.00625 .39957 L
s
[(0.2)] -0.0125 .39957 1 0 Mshowa
0 .49013 m
.00625 .49013 L
s
[(0.4)] -0.0125 .49013 1 0 Mshowa
0 .58068 m
.00625 .58068 L
s
[(0.6)] -0.0125 .58068 1 0 Mshowa
.125 Mabswid
0 .05999 m
.00375 .05999 L
s
0 .08263 m
.00375 .08263 L
s
0 .10527 m
.00375 .10527 L
s
0 .15055 m
.00375 .15055 L
s
0 .17319 m
.00375 .17319 L
s
0 .19582 m
.00375 .19582 L
s
0 .2411 m
.00375 .2411 L
s
0 .26374 m
.00375 .26374 L
s
0 .28638 m
.00375 .28638 L
s
0 .33166 m
.00375 .33166 L
s
0 .35429 m
.00375 .35429 L
s
0 .37693 m
.00375 .37693 L
s
0 .42221 m
.00375 .42221 L
s
0 .44485 m
.00375 .44485 L
s
0 .46749 m
.00375 .46749 L
s
0 .51276 m
.00375 .51276 L
s
0 .5354 m
.00375 .5354 L
s
0 .55804 m
.00375 .55804 L
s
0 .01472 m
.00375 .01472 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .03735 m
1 .03735 L
s
.99375 .12791 m
1 .12791 L
s
.99375 .21846 m
1 .21846 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .39957 m
1 .39957 L
s
.99375 .49013 m
1 .49013 L
s
.99375 .58068 m
1 .58068 L
s
.125 Mabswid
.99625 .05999 m
1 .05999 L
s
.99625 .08263 m
1 .08263 L
s
.99625 .10527 m
1 .10527 L
s
.99625 .15055 m
1 .15055 L
s
.99625 .17319 m
1 .17319 L
s
.99625 .19582 m
1 .19582 L
s
.99625 .2411 m
1 .2411 L
s
.99625 .26374 m
1 .26374 L
s
.99625 .28638 m
1 .28638 L
s
.99625 .33166 m
1 .33166 L
s
.99625 .35429 m
1 .35429 L
s
.99625 .37693 m
1 .37693 L
s
.99625 .42221 m
1 .42221 L
s
.99625 .44485 m
1 .44485 L
s
.99625 .46749 m
1 .46749 L
s
.99625 .51276 m
1 .51276 L
s
.99625 .5354 m
1 .5354 L
s
.99625 .55804 m
1 .55804 L
s
.99625 .01472 m
1 .01472 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 0 .5 r
.05 w
.02381 .08263 Mdot
.02381 .5354 Mdot
.11905 .08263 Mdot
.11905 .5354 Mdot
.05 w
.21429 .08263 Mdot
.21429 .5354 Mdot
.05 w
.30952 .08263 Mdot
.30952 .5354 Mdot
.002 0 .998 r
.00017 w
.40476 .01472 Mdot
.498 0 .502 r
.04983 w
.40476 .08263 Mdot
.40476 .5354 Mdot
.002 0 .998 r
.00017 w
.40476 .60332 Mdot
.5 0 .5 r
.05 w
.5 .01472 Mdot
0 0 1 r
0 w
.5 .08263 Mdot
0 w
.5 .10527 Mdot
.5 .51276 Mdot
0 w
.5 .5354 Mdot
.5 0 .5 r
.05 w
.5 .60332 Mdot
.002 0 .998 r
.00017 w
.59524 .01472 Mdot
.498 0 .502 r
.04983 w
.59524 .08263 Mdot
.59524 .5354 Mdot
.002 0 .998 r
.00017 w
.59524 .60332 Mdot
.5 0 .5 r
.05 w
.69048 .08263 Mdot
.69048 .5354 Mdot
.05 w
.78571 .08263 Mdot
.78571 .5354 Mdot
.05 w
.88095 .08263 Mdot
.88095 .5354 Mdot
.97619 .08263 Mdot
.97619 .5354 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.309017 0.280288 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -12 -9 ]
[.2619 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02873 -12 -4.5 ]
[-0.0125 .02873 0 4.5 ]
[-0.0125 .16887 -24 -4.5 ]
[-0.0125 .16887 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .44916 -18 -4.5 ]
[-0.0125 .44916 0 4.5 ]
[-0.0125 .5893 -6 -4.5 ]
[-0.0125 .5893 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-1)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(0.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02873 m
.00625 .02873 L
s
[(-1)] -0.0125 .02873 1 0 Mshowa
0 .16887 m
.00625 .16887 L
s
[(-0.5)] -0.0125 .16887 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .44916 m
.00625 .44916 L
s
[(0.5)] -0.0125 .44916 1 0 Mshowa
0 .5893 m
.00625 .5893 L
s
[(1)] -0.0125 .5893 1 0 Mshowa
.125 Mabswid
0 .05676 m
.00375 .05676 L
s
0 .08479 m
.00375 .08479 L
s
0 .11282 m
.00375 .11282 L
s
0 .14084 m
.00375 .14084 L
s
0 .1969 m
.00375 .1969 L
s
0 .22493 m
.00375 .22493 L
s
0 .25296 m
.00375 .25296 L
s
0 .28099 m
.00375 .28099 L
s
0 .33705 m
.00375 .33705 L
s
0 .36507 m
.00375 .36507 L
s
0 .3931 m
.00375 .3931 L
s
0 .42113 m
.00375 .42113 L
s
0 .47719 m
.00375 .47719 L
s
0 .50522 m
.00375 .50522 L
s
0 .53325 m
.00375 .53325 L
s
0 .56128 m
.00375 .56128 L
s
0 .0007 m
.00375 .0007 L
s
0 .61733 m
.00375 .61733 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02873 m
1 .02873 L
s
.99375 .16887 m
1 .16887 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .44916 m
1 .44916 L
s
.99375 .5893 m
1 .5893 L
s
.125 Mabswid
.99625 .05676 m
1 .05676 L
s
.99625 .08479 m
1 .08479 L
s
.99625 .11282 m
1 .11282 L
s
.99625 .14084 m
1 .14084 L
s
.99625 .1969 m
1 .1969 L
s
.99625 .22493 m
1 .22493 L
s
.99625 .25296 m
1 .25296 L
s
.99625 .28099 m
1 .28099 L
s
.99625 .33705 m
1 .33705 L
s
.99625 .36507 m
1 .36507 L
s
.99625 .3931 m
1 .3931 L
s
.99625 .42113 m
1 .42113 L
s
.99625 .47719 m
1 .47719 L
s
.99625 .50522 m
1 .50522 L
s
.99625 .53325 m
1 .53325 L
s
.99625 .56128 m
1 .56128 L
s
.99625 .0007 m
1 .0007 L
s
.99625 .61733 m
1 .61733 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.75 0 .25 r
.075 w
.02381 .01472 Mdot
.25 0 .75 r
.025 w
.02381 .07077 Mdot
.75 0 .25 r
.075 w
.11905 .07077 Mdot
.25 0 .75 r
.025 w
.11905 .12683 Mdot
.75 0 .25 r
.075 w
.21429 .12683 Mdot
.25 0 .75 r
.025 w
.21429 .18289 Mdot
.75 0 .25 r
.075 w
.30952 .18289 Mdot
.25 0 .75 r
.025 w
.30952 .23895 Mdot
.002 0 .998 r
.00017 w
.40476 .21092 Mdot
.747 0 .253 r
.07475 w
.40476 .23895 Mdot
.251 0 .749 r
.02508 w
.40476 .295 Mdot
.5 0 .5 r
.05 w
.5 .26697 Mdot
0 0 1 r
0 w
.5 .295 Mdot
0 w
.5 .295 Mdot
.5 .32303 Mdot
0 w
.5 .32303 Mdot
.5 0 .5 r
.05 w
.5 .35106 Mdot
.251 0 .749 r
.02508 w
.59524 .32303 Mdot
.747 0 .253 r
.07475 w
.59524 .37909 Mdot
.002 0 .998 r
.00017 w
.59524 .40712 Mdot
.25 0 .75 r
.025 w
.69048 .37909 Mdot
.75 0 .25 r
.075 w
.69048 .43515 Mdot
.25 0 .75 r
.025 w
.78571 .43515 Mdot
.75 0 .25 r
.075 w
.78571 .4912 Mdot
.25 0 .75 r
.025 w
.88095 .4912 Mdot
.75 0 .25 r
.075 w
.88095 .54726 Mdot
.25 0 .75 r
.025 w
.97619 .54726 Mdot
.75 0 .25 r
.075 w
.97619 .60332 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{864, 254.25},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=P0000oR000`400?l00000o`00003oo`3ooooo
0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00
o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS
0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0oooo
o`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool003/0oooo1000001=0?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`<00000C03oool2000004h0oooo0P0000040?ooo`030000003oool0
oooo0080oooo0`00001=0?ooo`@00000E03oool4000004d0oooo0P0000040?ooo`030000003oool0
oooo0080oooo0`00001;0?ooo`800000CP3oool2000000@0oooo00<000000?ooo`3oool00P3oool3
000004d0oooo1000000N0?ooo`00?@3oool00`000000oooo0?ooo`1;0?ooo`040000003oool0oooo
000000/0oooo00<000000?ooo`3oool0B03oool010000000oooo0?ooo`00001<0?ooo`040000003o
ool0oooo000000/0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`1E0?ooo`030000
003oool0oooo04/0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`170?ooo`04
0000003oool0oooo000004`0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`1<
0?ooo`030000003oool0oooo01d0oooo000m0?ooo`030000003oool0oooo04/0oooo00@000000?oo
o`3oool000002`3oool00`000000oooo0?ooo`180?ooo`040000003oool0oooo000004`0oooo00@0
00000?ooo`3oool000002`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0B`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo04L0
oooo00@000000?ooo`3oool00000C03oool010000000oooo0?ooo`00000;0?ooo`030000003oool0
oooo04`0oooo00<000000?ooo`3oool07@3oool003D0oooo100000040?ooo`030000003oool0oooo
04D0oooo100000020?ooo`040000003oool0oooo000000P0oooo0`00001;0?ooo`040000003oool0
oooo000004`0oooo00@000000?ooo`3oool00000203oool3000004l0oooo00<000000?ooo`3oool0
C@3oool4000000@0oooo00<000000?ooo`3oool0A@3oool400000080oooo00@000000?ooo`3oool0
0000203oool3000004X0oooo00@000000?ooo`3oool00000C03oool010000000oooo0?ooo`000008
0?ooo`<00000C`3oool00`000000oooo0?ooo`0M0?ooo`00?@3oool00`000000oooo0?ooo`1;0?oo
o`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0B`3oool010000000oooo0?ooo`00
001<0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`1E0?ooo`030000003oool0oooo04/0oooo00@000000?ooo`3oool00000203oool00`000000
oooo0?ooo`1:0?ooo`040000003oool0oooo000004`0oooo00@000000?ooo`3oool00000203oool0
0`000000oooo0?ooo`1?0?ooo`030000003oool0oooo01d0oooo000k0?ooo`<00000C@3oool01000
0000oooo0?ooo`0000080?ooo`030000003oool0oooo04/0oooo00@000000?ooo`3oool00000C03o
ool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo04d0oooo0`00001E0?ooo`<00000
C@3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo04X0oooo00@000000?ooo`3o
ool00000C03oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo04d0oooo0`00000O
0?ooo`00?@3oool00`000000oooo0?ooo`1<0?ooo`8000002@3oool4000004/0oooo0P00001>0?oo
o`8000002@3oool4000004h0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`1<0?oo
o`8000002@3oool4000004X0oooo0P00001>0?ooo`8000002@3oool4000004h0oooo00<000000?oo
o`3oool07@3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3o
oooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?oo
o`00<P3ooon^000000l0O`1o[@0000130?oooaL0_`0oo`00001E000001H0oooo000b0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool01`3ooolA07l0O`P0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`110?oooaL0_`0o0`3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0503oool00380oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo04`0oooo4@1o07m=0?ooo`030000003o
ool0oooo05<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`110?oooaL0_`0oB03o
ool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0D`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01@0oooo000b0?ooo`030000003oool0
oooo0:X0oooo4@1o07n[0?ooo`030000003oool0oooo0440oooo5`2o03oo0?oooe@0oooo00<00000
0?ooo`3oool0503oool00380oooo00<000000?ooo`3oool0ZP3ooolA07l0Oj/0oooo00<000000?oo
o`3oool0@@3ooolG0;l0?ol0ooooE03oool00`000000oooo0?ooo`0D0?ooo`00<P3oool200000940
oooo00<0003o0?ooo`3oool05P3ooolB07l0OaT0oooo00<0003o0?ooo`3oool0SP3oool2000004<0
oooo5`2o03oo0?oooe@0oooo00<000000?ooo`3oool0503oool00380oooo00<000000?ooo`3oool0
ZP3ooolA07l0Oj/0oooo00<000000?ooo`3oool0@@3ooolG0;l0?ol0ooooE03oool00`000000oooo
0?ooo`0D0?ooo`00<P3oool00`000000oooo0?ooo`2Z0?oooa40O`1oZ`3oool00`000000oooo0?oo
o`110?oooaL0_`0oo`3ooomD0?ooo`030000003oool0oooo01@0oooo000b0?ooo`030000003oool0
oooo0:X0oooo4@1o07n[0?ooo`030000003oool0oooo03P0oooo100000050?oooaL0_`0oo`3ooomD
0?ooo`030000003oool0oooo01@0oooo000b0?ooo`030000003oool0oooo0:X0oooo4@1o07n[0?oo
o`030000003oool0oooo03X0oooo00<000000?ooo`3oool0103ooolG0;l0?ol0ooooE03oool00`00
0000oooo0?ooo`0D0?ooo`00<P3oool00`000000oooo0?ooo`2[0?ooo`l0O`1o[03oool00`000000
oooo0?ooo`0j0?ooo`030000003oool0oooo00@0oooo5P2o03oo0?oooe80oooo1000000F0?ooo`00
7@3oool2000000@0oooo00<000000?ooo`3oool00`3oool2000000L0oooo00<000000?ooo`3oool0
[03oool=07l0Ojd0oooo00<000000?ooo`3oool0<P3oool4000000@0oooo00<000000?ooo`3oool0
103ooolF0;l0?ol0ooooE@3oool00`000000oooo0?ooo`0D0?ooo`00703oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0[@3oool;07l0Ojh0
oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`040?oooaD0_`0oo`3ooomF0?ooo`03
0000003oool0oooo01@0oooo000L0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool000001P3oool300000:h0oooo2@1o07n]0?ooo`<00000>P3oool3000000H0oooo502o03lC0?oo
o`X0_`0oo`3ooolj0?ooo`030000003oool0oooo01@0oooo000F0?ooo`@000000P3oool010000000
oooo0?ooo`0000080?ooo`<000001`3oool00`000000oooo0?ooo`2b0?ooo`0307l0O`3oool0oooo
0;40oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`040?oooa@0_`0o4@3oool>0;l0
?ol0oooo>03oool00`000000oooo0?ooo`0D0?ooo`00703oool010000000oooo0?ooo`0000080?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo
0440oooo00<000000?ooo`2o03l03`2o03lB0?oooa00_`0oo`3ooolg0?ooo`030000003oool0oooo
01@0oooo000L0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0>0;l0
?a40oooo502o03oo0?ooocD0oooo00<000000?ooo`3oool0503oool001d0oooo0P00000:0?ooo`<0
00001P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`020?ooo`X0_`0o4`3ooolD0;l0?ol0oooo=@3oool00`000000oooo0?ooo`0D0?ooo`00
<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool00`000000oooo
0?ooo`0N0?oooaH0_`0oo`3ooold0?ooo`030000003oool0oooo01@0oooo000b0?ooo`030000003o
ool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo01d0oooo602o
03oo0?oooc<0oooo00<000000?ooo`3oool0503oool00380oooo00<000000?ooo`3oool0o`3ooomW
0?ooo`030000003oool0oooo0440oooo0P00000N0?oooaP0_`0oo`3ooola0?ooo`<000005P3oool0
0380oooo00<000000?ooo`3oool00P3oool907l0OaT0oooo2@1o07lJ0?ooo`T0O`1o6@3oool907l0
OaX0oooo2@1o080k0?ooo`T0O`206P3oool907l0OaT0oooo2@1o07lJ0?ooo`T0O`1o6@3oool907l0
O`<0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0L0?oooaX0_`0oo`3ooolb0?oo
o`030000003oool0oooo01@0oooo000b0?ooo`8000000P3oool;07l0OaL0oooo2`1o07lH0?ooo`/0
O`1o5`3oool;07l0OaP0oooo2`1o080i0?ooo`/0O`20603oool;07l0OaL0oooo2`1o07lH0?ooo`/0
O`1o5`3oool;07l0O`030?ooo`000000000004<0oooo00<000000?ooo`3oool0103oool603l0_a80
oooo6P2o03oo0?oooc80oooo00<000000?ooo`3oool0503oool00380oooo00<000000?ooo`3oool0
3@1o07lE0?ooo`d0O`1o5P3oool=07l0OaD0oooo3@1o07lF0?ooo`d0O`20=`3oool=07l0P1H0oooo
3@1o07lE0?ooo`d0O`1o5P3oool=07l0OaD0oooo3@1o07l00`3oool000000?ooo`120?ooo`030000
003oool0oooo00<0oooo200o0;lA0?oooaX0_`0oo`3ooolb0?ooo`030000003oool0oooo01@0oooo
000b0?ooo`030000003oool0O`1o00h0O`1o4`3oool?07l0Oa@0oooo3`1o07lC0?ooo`l0O`1o503o
ool?07l0P3D0oooo3`1o080D0?ooo`l0O`1o4`3oool?07l0Oa@0oooo3`1o07lC0?ooo`l0O`1o00<0
00000?ooo`3oool0@@3oool00`000000oooo0?ooo`030?ooo`P0?`2o4@3ooolJ0;l0?ol0oooo<P3o
ool00`000000oooo0?ooo`0D0?ooo`00<P3oool00`000000O`1o07l0O`0?07l0Oa40oooo4@1o07lB
0?oooa40O`1o4@3ooolA07l0Oa80oooo4@1o080c0?oooa40O`204P3ooolA07l0Oa40oooo4@1o07lB
0?oooa40O`1o4@3ooolA07l0Od<0oooo00<000000?ooo`3oool00`3oool803l0_a40oooo6P2o03oo
0?oooc80oooo00<000000?ooo`3oool0503oool00380oooo00<0000007l0O`1o07l03`1o07lA0?oo
oa40O`1o4P3ooolA07l0Oa40oooo4@1o07lB0?oooa40O`20<`3ooolA07l0P180oooo4@1o07lA0?oo
oa40O`1o4P3ooolA07l0Oa40oooo4@1o07m30?ooo`030000003oool0oooo00<0oooo200o0;lA0?oo
oaX0_`0oo`3ooolb0?ooo`030000003oool0oooo01@0oooo000b0?ooo`030000001o07l0O`1o00l0
O`1o4@3ooolA07l0Oa80oooo4@1o07lA0?oooa40O`1o4P3ooolA07l0P3<0oooo4@1o080B0?oooa40
O`1o4@3ooolA07l0Oa80oooo4@1o07lA0?oooa40O`1o@`3oool00`000000oooo0?ooo`030?ooo`P0
?`2o4@3ooolJ0;l0?ol0oooo<P3oool00`000000oooo0?ooo`0D0?ooo`00<P3oool00`000000O`1o
07l0O`0?07l0Oa40oooo4@1o07lB0?oooa40O`1o4@3ooolA07l0Oa80oooo4@1o080c0?oooa40O`20
4P3ooolA07l0Oa40oooo4@1o07lB0?oooa40O`1o4@3ooolA07l0Od<0oooo00<000000?ooo`3oool0
0`3oool803l0_a40oooo6P2o03oo0?oooc80oooo00<000000?ooo`3oool0503oool00380oooo4P1o
07l@0?oooa80O`1o4@3ooolB07l0Oa00oooo4P1o07lA0?oooa80O`206@3oool00`000?l0oooo0?oo
o`0F0?oooa80O`204@3ooolB07l0Oa00oooo4P1o07lA0?oooa80O`1o403ooolB07l0Od<0oooo00<0
00000?ooo`3oool0103oool603l0_a80oooo6P2o03oo0?oooc80oooo00<000000?ooo`3oool0503o
ool00380oooo00<0000007l0O`1o07l03`1o07lA0?oooa40O`1o4P3ooolA07l0Oa40oooo4@1o07lB
0?oooa40O`20<`3ooolA07l0P180oooo4@1o07lA0?oooa40O`1o4P3ooolA07l0Oa40oooo4@1o07m3
0?ooo`030000003oool0oooo01`0oooo6P2o03oo0?oooc80oooo00<000000?ooo`3oool0503oool0
0380oooo00<0000007l0O`1o07l03`1o07lA0?oooa40O`1o4P3ooolA07l0Oa40oooo4@1o07lB0?oo
oa40O`20<`3ooolA07l0P180oooo4@1o07lA0?oooa40O`1o4P3ooolA07l0Oa40oooo4@1o07m30?oo
o`8000007P3ooolH0;l0?ol0oooo<@3oool3000001H0oooo000b0?ooo`030000001o07l0O`1o00l0
O`1o4@3ooolA07l0Oa80oooo4@1o07lA0?oooa40O`1o4P3ooolA07l0P3<0oooo4@1o080B0?oooa40
O`1o4@3ooolA07l0Oa80oooo4@1o07lA0?oooa40O`1o@`3oool00`000000oooo0?ooo`0M0?oooaP0
_`0oo`3ooolc0?ooo`030000003oool0oooo01@0oooo000b0?ooo`030000001o07l0O`1o00l0O`1o
4@3ooolA07l0Oa80oooo4@1o07lA0?oooa40O`1o4P3ooolA07l0P3<0oooo4@1o080B0?oooa40O`1o
4@3ooolA07l0Oa80oooo4@1o07lA0?oooa40O`1o@`3oool00`000000oooo0?ooo`0N0?oooaH0_`0o
4`3oool:0;l0?ol0oooo5`3oool00`000000oooo0?ooo`0D0?ooo`00<P3oool00`000000oooo07l0
O`0>07l0Oa<0oooo3`1o07lD0?ooo`l0O`1o4`3oool?07l0Oa@0oooo3`1o080e0?ooo`l0O`20503o
ool?07l0Oa<0oooo3`1o07lD0?ooo`l0O`1o4`3oool?07l0O`030000003oool0oooo0440oooo00<0
00000?ooo`3oool07`3ooolD0;l0?a80oooo3P2o03oo0?oooaD0oooo00<000000?ooo`3oool0503o
ool00380oooo00<000000?ooo`3oool03@1o07lE0?ooo`d0O`1o5P3oool=07l0OaD0oooo3@1o07lF
0?ooo`d0O`20=`3oool=07l0P1H0oooo3@1o07lE0?ooo`d0O`1o5P3oool=07l0OaD0oooo3@1o07l0
0`3oool000000?ooo`120?ooo`030000003oool0oooo01l0oooo502o03lA0?oooa00_`0oo`3ooolD
0?ooo`030000003oool0oooo01@0oooo000b0?ooo`040000003oool0oooo0?ooo`/0O`1o5`3oool;
07l0OaP0oooo2`1o07lG0?ooo`/0O`1o603oool;07l0P3T0oooo2`1o080H0?ooo`/0O`1o5`3oool;
07l0OaP0oooo2`1o07lG0?ooo`/0O`1o0P3oool00`000000oooo0?ooo`110?ooo`030000003oool0
oooo0240oooo402o03lA0?oooa@0_`0oo`3ooolB0?ooo`030000003oool0oooo01@0oooo000b0?oo
o`030000003oool0oooo0080oooo2@1o07lI0?ooo`T0O`1o6P3oool907l0OaT0oooo2@1o07lJ0?oo
o`T0O`207@3oool00`000?l0oooo0?ooo`0K0?ooo`T0O`206P3oool907l0OaT0oooo2@1o07lJ0?oo
o`T0O`1o6@3oool907l0O`<0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0R0?oo
o`h0_`0o4P3ooolD0;l0?ol0oooo4P3oool00`000000oooo0?ooo`0D0?ooo`00<P3oool2000000L0
oooo00<0O`1o0?ooo`3oool07`3oool00`1o07l0oooo0?ooo`0P0?ooo`0307l0O`3oool0oooo01l0
oooo00<0O`1o0?ooo`3oool0803oool00`1o0800oooo0?ooo`110?ooo`0307l0P03oool0oooo0200
oooo00<0O`1o0?ooo`3oool07`3oool00`1o07l0oooo0?ooo`0P0?ooo`0307l0O`3oool0oooo01l0
oooo00<0O`1o0?ooo`3oool0103oool2000004<0oooo00<000000?ooo`3oool0903oool:0;l0?a<0
oooo5P2o03oo0?oooa40oooo00<000000?ooo`3oool0503oool00380oooo00<000000?ooo`3oool0
o`3ooomW0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0@03ooolH0;l0?ol0oooo
403oool00`000000oooo0?ooo`0D0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<0
00000?ooo`3oool0@@3oool00`000000oooo0?ooo`100?oooaP0_`0oo`3oool@0?ooo`030000003o
ool0oooo01@0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`11
0?ooo`800000@03ooolJ0;l0?ol0oooo3@3oool3000001H0oooo000b0?ooo`030000003oool0oooo
0?l0ooooI`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo02H0oooo1P0o0;lC0?oo
oaX0_`0oo`3oool?0?ooo`030000003oool0oooo01@0oooo000b0?ooo`030000003oool0oooo0?l0
ooooI`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo02D0oooo200o0;lB0?oooaX0
_`0oo`3oool?0?ooo`030000003oool0oooo01@0oooo000M0?ooo`800000103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000
003oool0oooo0440oooo00<000000?ooo`3oool09@3oool803l0_a80oooo6P2o03oo0?ooo`l0oooo
00<000000?ooo`3oool0503oool001`0oooo00@000000?ooo`3oool000002P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`110?ooo`030000
003oool0oooo02D0oooo200o0;lB0?oooaX0_`0oo`3oool?0?ooo`030000003oool0oooo01@0oooo
000L0?ooo`040000003oool0oooo000000L0oooo1@0000060?ooo`<00000o`3ooomU0?ooo`<00000
@`3oool00`000000oooo0?ooo`0U0?ooo`P0?`2o4P3ooolJ0;l0?ol0oooo3`3oool00`000000oooo
0?ooo`0D0?ooo`005P3oool400000080oooo00@000000?ooo`3oool000001`3oool010000000oooo
0?ooo`0000070?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`110?ooo`03
0000003oool0oooo02D0oooo200o0;lB0?oooaX0_`0oo`3oool?0?ooo`030000003oool0oooo01@0
oooo000L0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`0000001`3oool00`000000
oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0U0?ooo`P0
?`2o4P3ooolJ0;l0?ol0oooo3`3oool00`000000oooo0?ooo`0D0?ooo`00703oool010000000oooo
0?ooo`0000090?ooo`8000001`3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3o
ool0@@3oool00`000000oooo0?ooo`0V0?ooo`H0?`2o4`3ooolJ0;l0?ol0oooo3`3oool00`000000
oooo0?ooo`0D0?ooo`007@3oool2000000/0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0o0?oooaX0_`0o
o`3oool?0?ooo`030000003oool0oooo01@0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3o
ool00`000000oooo0?ooo`110?ooo`800000@@3ooolH0;l0?ol0oooo3P3oool3000001H0oooo000b
0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`110?ooo`030000003oool0
oooo0400oooo602o03oo0?oooa00oooo00<000000?ooo`3oool0503oool00380oooo00<000000?oo
o`3oool0o`3ooomW0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0@@3ooolF0;l0
?a80oooo2P2o03od0?ooo`030000003oool0oooo01@0oooo000b0?ooo`800000o`3ooomW0?ooo`80
0000@`3oool00`000000oooo0?ooo`120?oooa@0_`0o4@3oool>0;l0?o80oooo00<000000?ooo`3o
ool0503oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo0440oooo
00<000000?ooo`3oool0@P3ooolD0;l0?a00oooo402o03oa0?ooo`030000003oool0oooo01@0oooo
000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo04@0oooo402o03l@0?oooa@0_`0ok`3oool00`000000oooo0?ooo`0D0?ooo`00<P3oool0
0`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`15
0?ooo`h0_`0o4@3ooolD0;l0?nl0oooo00<000000?ooo`3oool0503oool00380oooo00<000000?oo
o`3oool0o`3ooomW0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0A`3oool:0;l0
?a80oooo5P2o03o^0?ooo`030000003oool0oooo01@0oooo000b0?ooo`030000003oool0oooo0?l0
ooooI`3oool00`000000oooo0?ooo`0]0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`<0
00001P3oool00`000000oooo0?ooo`1R0?oooaP0_`0ok@3oool00`000000oooo0?ooo`0D0?ooo`00
<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0;03oool010000000oooo
0?ooo`00000;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0HP3ooolH0;l0?nd0
oooo00<000000?ooo`3oool0503oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000
003oool0oooo02`0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`030?ooo`<0
0000H@3ooolJ0;l0?nT0oooo1000000F0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo
00<000000?ooo`3oool09P3oool400000080oooo00@000000?ooo`3oool00000203oool3000000H0
oooo00<000000?ooo`3oool0B@3oool603l0_a80oooo6P2o03o/0?ooo`030000003oool0oooo01@0
oooo000b0?ooo`800000o`3ooomW0?ooo`800000;P3oool010000000oooo0?ooo`0000080?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0B03oool803l0_a40oooo6P2o03o/0?ooo`03
0000003oool0oooo01@0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo
0?ooo`0/0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`180?ooo`P0?`2o4@3ooolJ0;l0?n`0oooo00<000000?ooo`3oool0503oool00380oooo
00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo02d0oooo0P0000090?ooo`@00000
1@3oool00`000000oooo0?ooo`180?ooo`P0?`2o4@3ooolJ0;l0?n`0oooo00<000000?ooo`3oool0
503oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool0B03oool803l0_a40oooo6P2o03o/0?ooo`030000003oool0oooo01@0oooo000b
0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`110?ooo`030000003oool0
oooo04P0oooo200o0;lA0?oooaX0_`0ok03oool00`000000oooo0?ooo`0D0?ooo`00<P3oool00`00
0000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`180?oo
o`P0?`2o4@3ooolJ0;l0?n`0oooo00<000000?ooo`3oool0503oool00380oooo00<000000?ooo`3o
ool0o`3ooomW0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0B@3oool603l0_a80
oooo6P2o03o/0?ooo`030000003oool0oooo01@0oooo000b0?ooo`030000003oool0oooo0?l0oooo
I`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0640oooo6P2o03o/0?ooo`030000
003oool0oooo01@0oooo000b0?ooo`800000o`3ooomW0?ooo`800000@`3oool2000006<0oooo602o
03o[0?ooo`<000005P3oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool0HP3ooolH0;l0?nd0oooo00<000000?ooo`3oool0503oool0
0380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo0440oooo00<000000?oo
o`3oool0H`3ooolF0;l0?a80oooo2P2o043B0?ooo`030000003oool0oooo01@0oooo000b0?ooo`03
0000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo06@0
oooo502o03lA0?ooo`h0_`10d03oool00`000000oooo0?ooo`0D0?ooo`00<P3oool00`000000oooo
0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`1T0?oooa@0_`0o
403oool@0;l0@<l0oooo00<000000?ooo`3oool0503oool00380oooo00<000000?ooo`3oool0o`3o
oomW0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0IP3oool@0;l0?a00oooo502o
043=0?ooo`030000003oool0oooo01@0oooo000M0?ooo`800000103oool00`000000oooo0?ooo`02
0?ooo`@000001P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool0
0`000000oooo0?ooo`1W0?ooo`h0_`0o4@3ooolD0;l0@<d0oooo00<000000?ooo`3oool0503oool0
01`0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0?l0ooooI`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo06T0oooo2P2o03lB
0?oooaH0_`10c03oool00`000000oooo0?ooo`0D0?ooo`00703oool010000000oooo0?ooo`000009
0?ooo`030000003oool0oooo00H0oooo0`00003o0?ooofD0oooo0`0000130?ooo`030000003oool0
oooo08@0oooo602o043;0?ooo`030000003oool0oooo01@0oooo000F0?ooo`@000000P3oool01000
0000oooo0?ooo`00000:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooomW
0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0Q03ooolH0;l0@</0oooo00<00000
0?ooo`3oool0503oool001`0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`110?ooo`800000Q03ooolJ
0;l0@<P0oooo0`00000F0?ooo`00703oool010000000oooo0?ooo`0000080?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool0J`3oool603l0_a80oooo6P2o043:0?ooo`030000003oool0oooo01@0oooo000M
0?ooo`8000002P3oool2000000L0oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool0JP3oool803l0_a40oooo6P2o043:0?ooo`030000003oool0
oooo01@0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo06X0oooo200o0;lA0?oooaX0_`10bP3oool00`000000oooo0?ooo`0D0?oo
o`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`1Z0?ooo`P0?`2o4@3ooolJ0;l0@<X0oooo00<000000?ooo`3oool0503oool00380oooo
00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
JP3oool803l0_a40oooo6P2o043:0?ooo`030000003oool0oooo01@0oooo000b0?ooo`800000o`3o
oomW0?ooo`800000@`3oool00`000000oooo0?ooo`1Z0?ooo`P0?`2o4@3ooolJ0;l0@<X0oooo00<0
00000?ooo`3oool0503oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool0JP3oool803l0_a40oooo6P2o040A0?ooo`T0O`1o/03oool0
0`000000oooo0?ooo`0D0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?oo
o`3oool0@@3oool00`000000oooo0?ooo`1[0?ooo`H0?`2o4P3ooolJ0;l0@100oooo2`1o07n_0?oo
o`030000003oool0oooo01@0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000
oooo0?ooo`110?ooo`030000003oool0oooo08<0oooo6P2o040?0?ooo`d0O`1o[P3oool00`000000
oooo0?ooo`0D0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0
@@3oool2000008D0oooo602o040?0?ooo`l0O`1oZ`3oool3000001H0oooo000b0?ooo`030000003o
ool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo08@0oooo602o
040>0?oooa40O`1o[03oool00`000000oooo0?ooo`0D0?ooo`00<P3oool00`000000oooo0?ooo`3o
0?ooofL0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`250?oooaH0_`103`3ooolA
07l0Oj`0oooo00<000000?ooo`3oool0503oool00380oooo00<000000?ooo`3oool0o`3ooomW0?oo
o`030000003oool0oooo0440oooo00<000000?ooo`3oool0QP3ooolD0;l0@100oooo4@1o07n/0?oo
o`030000003oool0oooo01@0oooo000b0?ooo`800000o`3ooomW0?ooo`800000@`3oool00`000000
oooo0?ooo`260?oooa@0_`10403ooolA07l0Oj`0oooo00<000000?ooo`3oool0503oool00380oooo
00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
R03oool@0;l0@140oooo4P1o07n/0?ooo`030000003oool0oooo01@0oooo000b0?ooo`030000003o
ool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo08T0oooo3P2o
040C0?oooa40O`1o[03oool00`000000oooo0?ooo`0D0?ooo`00<P3oool00`000000oooo0?ooo`3o
0?ooofL0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`2;0?ooo`X0_`105@3ooolA
07l0Oj`0oooo00<000000?ooo`3oool0503oool00380oooo00<000000?ooo`3oool0o`3ooomW0?oo
o`030000003oool0oooo0440oooo00<000000?ooo`3oool0ZP3ooolA07l0Oj`0oooo00<000000?oo
o`3oool0503oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo0440
oooo00<000000?ooo`3oool0ZP3ooolA07l0Oj`0oooo00<000000?ooo`3oool0503oool00380oooo
00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
Z`3oool?07l0Ojd0oooo00<000000?ooo`3oool0503oool00380oooo00<000000?ooo`3oool0o`3o
oomW0?ooo`030000003oool0oooo0440oooo0P00002]0?ooo`d0O`1o[03oool3000001H0oooo000b
0?ooo`800000o`3ooomW0?ooo`800000@`3oool00`000000oooo0?ooo`2=0?ooo`H0@02o6P3oool;
07l0Ojl0oooo00<000000?ooo`3oool0503oool00380oooo00<000000?ooo`3oool0o`3ooomW0?oo
o`030000003oool0oooo0440oooo00<000000?ooo`3oool0S03oool80400_aX0oooo2@1o07n`0?oo
o`030000003oool0oooo01@0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000
oooo0?ooo`110?ooo`030000003oool0oooo08`0oooo20100;lN0?ooo`0307l0O`3oool0oooo0;80
oooo00<000000?ooo`3oool0503oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000
003oool0oooo0440oooo00<000000?ooo`3oool0S03oool80400_ah0oooo00<0003o0?ooo`3oool0
/P3oool00`000000oooo0?ooo`0D0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<0
00000?ooo`3oool0@@3oool00`000000oooo0?ooo`2<0?ooo`P0@02od`3oool00`000000oooo0?oo
o`0D0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool0
0`000000oooo0?ooo`2<0?ooo`P0@02od`3oool00`000000oooo0?ooo`0D0?ooo`00<P3oool00`00
0000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`2<0?oo
o`P0@02od`3oool00`000000oooo0?ooo`0D0?ooo`00:@3oool2000000L0oooo00<000000?ooo`3o
ool0o`3ooomW0?ooo`030000003oool0oooo03T0oooo0P0000060?ooo`030000003oool0oooo08d0
oooo1P100;oD0?ooo`030000003oool0oooo01@0oooo000X0?ooo`040000003oool0oooo000000H0
oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo03P0oooo00@000000?ooo`3o
ool000001@3oool00`000000oooo0?ooo`3o0?ooofP0oooo00<000000?ooo`3oool0503oool002P0
oooo00@000000?ooo`3oool000001P3oool300000?l0ooooI@3oool3000003X0oooo00@000000?oo
o`3oool000001@3oool300000?l0ooooI@3oool4000001H0oooo000X0?ooo`040000003oool0oooo
000000H0oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo03P0oooo00@00000
0?ooo`3oool000001@3oool00`000000oooo0?ooo`3B0?ooo`H0@02oS`3oool00`000000oooo0?oo
o`0D0?ooo`00:03oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo0?l0ooooI`3o
ool00`000000oooo0?ooo`0h0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
d@3oool80400_hh0oooo00<000000?ooo`3oool0503oool002P0oooo00@000000?ooo`3oool00000
1P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0>03oool010000000oooo
0?ooo`0000050?ooo`030000003oool0oooo0=40oooo20100;n>0?ooo`030000003oool0oooo01@0
oooo000Y0?ooo`8000001`3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0
>@3oool2000000H0oooo00<000000?ooo`3oool0/P3oool00`000?l0oooo0?ooo`0L0?ooo`P0@02o
SP3oool00`000000oooo0?ooo`0D0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<0
00000?ooo`3oool0@@3oool00`000000oooo0?ooo`3A0?ooo`P0@02oSP3oool00`000000oooo0?oo
o`0D0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool0
0`000000oooo0?ooo`2^0?ooo`T0O`1o6P3oool80400_hh0oooo00<000000?ooo`3oool0503oool0
0380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo0440oooo00<000000?oo
o`3oool0[@3oool;07l0OaT0oooo20100;n>0?ooo`030000003oool0oooo01@0oooo000b0?ooo`80
0000o`3ooomW0?ooo`800000@`3oool00`000000oooo0?ooo`2/0?ooo`d0O`1o6@3oool60400_hl0
oooo00<000000?ooo`3oool0503oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000
003oool0oooo0440oooo00<000000?ooo`3oool0Z`3oool?07l0Ojd0oooo00<000000?ooo`3oool0
503oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo0440oooo0P00
002[0?oooa40O`1oZP3oool3000001H0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo0:X0oooo4@1o07n/0?ooo`030000003oool0
oooo01@0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo0:X0oooo4@1o07lE0?ooo`X0_`10S@3oool00`000000oooo0?ooo`0D0?oo
o`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`2Z0?oooa40O`1o4`3oool>0;l0@8/0oooo00<000000?ooo`3oool0503oool00380oooo
00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
Z@3ooolB07l0Oa80oooo402o042:0?ooo`030000003oool0oooo01@0oooo000b0?ooo`030000003o
ool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0:X0oooo4@1o
07l@0?oooa@0_`10R03oool00`000000oooo0?ooo`0D0?ooo`00<P3oool200000?l0ooooI`3oool2
000004<0oooo00<000000?ooo`3oool0ZP3ooolA07l0Oa00oooo502o04280?ooo`030000003oool0
oooo01@0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo0:X0oooo4@1o07l?0?oooaH0_`10Q`3oool00`000000oooo0?ooo`0D0?oo
o`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`2Z0?oooa40O`1o3P3ooolH0;l0@8H0oooo00<000000?ooo`3oool0503oool00380oooo
00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
Z`3oool?07l0O`l0oooo602o04260?ooo`030000003oool0oooo01@0oooo000b0?ooo`030000003o
ool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`110?ooo`800000[@3oool=07l0O`l0oooo6P2o
04230?ooo`<000005P3oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool0[@3oool;07l0Oa00oooo6P2o040C0?ooo`H0?`2oK03oool0
0`000000oooo0?ooo`0D0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?oo
o`3oool0@@3oool00`000000oooo0?ooo`2^0?ooo`T0O`1o4@3ooolJ0;l0@180oooo200o0;m[0?oo
o`030000003oool0oooo01@0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000
oooo0?ooo`110?ooo`030000003oool0oooo0;80oooo00<0O`1o0?ooo`3oool04`3ooolJ0;l0@180
oooo200o0;m[0?ooo`030000003oool0oooo01@0oooo000b0?ooo`800000o`3ooomW0?ooo`800000
@`3oool00`000000oooo0?ooo`380?oooaX0_`104P3oool803l0_f/0oooo00<000000?ooo`3oool0
503oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool0b03ooolJ0;l0@180oooo200o0;m[0?ooo`030000003oool0oooo01@0oooo000b
0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`110?ooo`030000003oool0
oooo0<P0oooo6P2o040B0?ooo`P0?`2oJ`3oool00`000000oooo0?ooo`0D0?ooo`00<P3oool00`00
0000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`380?oo
oaX0_`104P3oool803l0_f/0oooo00<000000?ooo`3oool0503oool00380oooo00<000000?ooo`3o
ool0o`3ooomW0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0b03ooolJ0;l0@1<0
oooo1P0o0;m/0?ooo`030000003oool0oooo01@0oooo000b0?ooo`030000003oool0oooo0?l0oooo
I`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0<P0oooo6P2o04250?ooo`030000
003oool0oooo01@0oooo000M0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`@000001P3o
ool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool200000<X0oooo602o
04240?ooo`<000005P3oool001`0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo0<T0oooo602o04260?ooo`030000003oool0oooo01@0oooo000L0?ooo`040000003oool0
oooo000000T0oooo00<000000?ooo`3oool01P3oool300000?l0ooooI@3oool3000004<0oooo00<0
00000?ooo`3oool0bP3ooolF0;l0@1<0oooo2P2o03mZ0?ooo`030000003oool0oooo01@0oooo000L
0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3;0?oooa@0_`104P3o
ool>0;l0?fP0oooo00<000000?ooo`3oool0503oool001`0oooo00@000000?ooo`3oool000002`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?oo
o`110?ooo`030000003oool0oooo0</0oooo502o040A0?oooa00_`0oI`3oool00`000000oooo0?oo
o`0D0?ooo`00703oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000H0oooo
00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
c@3oool80;l0@0030000o`2o0400_`1000D0_`104@3ooolD0;l0?fD0oooo00<000000?ooo`3oool0
503oool001d0oooo0P00000:0?ooo`8000001`3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<0
00000?ooo`3oool0@@3oool00`000000oooo0?ooo`3>0?ooo`h0_`104P3ooolD0;l0?fD0oooo00<0
00000?ooo`3oool0503oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool0d03oool:0;l0@1<0oooo5P2o03mT0?ooo`030000003oool0
oooo01@0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo0>`0oooo602o03mS0?ooo`030000003oool0oooo01@0oooo000b0?ooo`03
0000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0>`0
oooo602o03mS0?ooo`030000003oool0oooo01@0oooo000b0?ooo`030000003oool0oooo0?l0oooo
I`3oool00`000000oooo0?ooo`110?ooo`800000k03ooolJ0;l0?f00oooo0`00000F0?ooo`00<P3o
ool200000?l0ooooI`3oool2000004<0oooo00<000000?ooo`3oool0j`3ooolJ0;l0?a80oooo1P0o
0;m:0?ooo`030000003oool0oooo01@0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo0>/0oooo6P2o03lA0?ooo`P0?`2oB@3oool0
0`000000oooo0?ooo`0D0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?oo
o`3oool0@@3oool00`000000oooo0?ooo`3[0?oooaX0_`0o4@3oool803l0_dT0oooo00<000000?oo
o`3oool0503oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo0440
oooo00<000000?ooo`3oool0j`3ooolJ0;l0?a40oooo200o0;m90?ooo`030000003oool0oooo01@0
oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`110?ooo`030000
003oool0oooo0>/0oooo6P2o03lA0?ooo`P0?`2oB@3oool00`000000oooo0?ooo`0D0?ooo`00<P3o
ool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?oo
o`3[0?oooaX0_`0o4@3oool803l0_dT0oooo00<000000?ooo`3oool0503oool00380oooo00<00000
0?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0j`3ooolJ
0;l0?a40oooo200o0;m90?ooo`030000003oool0oooo01@0oooo000b0?ooo`030000003oool0oooo
0?l0ooooI`3oool00`000000oooo0?ooo`0]0?ooo`800000103oool00`000000oooo0?ooo`020?oo
o`<000001P3oool00`000000oooo0?ooo`3[0?oooaX0_`0o4P3oool603l0_dX0oooo00<000000?oo
o`3oool0503oool00380oooo0P00003o0?ooofL0oooo0P00000^0?ooo`040000003oool0oooo0000
00/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3[0?oooaX0_`0oHP3oool00`00
0000oooo0?ooo`0D0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3o
ool0;03oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo00<0oooo0`00003/0?oo
oaP0_`0oH03oool4000001H0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000
oooo0?ooo`0/0?ooo`040000003oool0oooo000000P0oooo0`0000060?ooo`030000003oool0oooo
0>`0oooo602o03mS0?ooo`030000003oool0oooo01@0oooo000b0?ooo`030000003oool0oooo0?l0
ooooI`3oool00`000000oooo0?ooo`0/0?ooo`040000003oool0oooo000000P0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`3]0?oooaH0_`0oI03oool00`000000oooo0?ooo`0D0?oo
o`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0;03oool010000000
oooo0?ooo`0000080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0kP3ooolD0;l0
?a<0oooo2P2o03m80?ooo`030000003oool0oooo01@0oooo000b0?ooo`030000003oool0oooo0?l0
ooooI`3oool00`000000oooo0?ooo`0]0?ooo`8000002@3oool4000000D0oooo00<000000?ooo`3o
ool0kP3ooolD0;l0?a40oooo3P2o03m60?ooo`030000003oool0oooo01@0oooo000b0?ooo`030000
003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0?00oooo
402o03lB0?oooa00_`0oA@3oool00`000000oooo0?ooo`0D0?ooo`00<P3oool00`000000oooo0?oo
o`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3a0?ooo`h0_`0o4@3o
oolD0;l0?d<0oooo00<000000?ooo`3oool0503oool00380oooo0P00003o0?ooofL0oooo0P000013
0?ooo`030000003oool0oooo0?<0oooo2P2o03lC0?oooa@0_`0o@`3oool00`000000oooo0?ooo`0D
0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool00`00
0000oooo0?ooo`3o0?oooa00oooo5P2o03m20?ooo`030000003oool0oooo01@0oooo000b0?ooo`03
0000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0?l0
oooo3`3ooolH0;l0?d40oooo00<000000?ooo`3oool0503oool00380oooo00<000000?ooo`3oool0
o`3ooomW0?ooo`030000003oool0oooo0440oooo0P00003o0?oooa00oooo602o03lo0?ooo`<00000
5P3oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool0o`3oool>0?oooaX0_`0o@03oool00`000000oooo0?ooo`0D0?ooo`00<P3oool0
0`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3o
0?ooo`h0oooo6P2o03lC0?ooo`H0?`2o9`3oool00`000000oooo0?ooo`0D0?ooo`007@3oool20000
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0?l0ooooI`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0?l0oooo3P3ooolJ0;l0
?a80oooo200o0;lV0?ooo`030000003oool0oooo01@0oooo000L0?ooo`040000003oool0oooo0000
00X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?oo
o`3oool0@@3oool00`000000oooo0?ooo`3o0?ooo`h0oooo6P2o03lB0?ooo`P0?`2o9P3oool00`00
0000oooo0?ooo`0D0?ooo`00703oool010000000oooo0?ooo`0000070?ooo`D000001P3oool30000
0?l0ooooI@3oool3000004<0oooo00<000000?ooo`3oool0o`3oool>0?oooaX0_`0o4P3oool803l0
_bH0oooo00<000000?ooo`3oool0503oool001`0oooo00@000000?ooo`3oool000001`3oool01000
0000oooo0?ooo`0000070?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`11
0?ooo`030000003oool0oooo0?l0oooo3P3ooolJ0;l0?a80oooo200o0;lV0?ooo`030000003oool0
oooo01@0oooo000L0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`0000001`3oool0
0`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3o
0?ooo`h0oooo6P2o03lB0?ooo`P0?`2o9P3oool00`000000oooo0?ooo`0D0?ooo`00703oool01000
0000oooo0?ooo`0000090?ooo`8000001`3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<00000
0?ooo`3oool0@@3oool00`000000oooo0?ooo`3o0?ooo`h0oooo6P2o03lB0?ooo`P0?`2o9P3oool0
0`000000oooo0?ooo`0D0?ooo`007@3oool2000000/0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3o0?oo
o`h0oooo6P2o03lC0?ooo`H0?`2o9`3oool00`000000oooo0?ooo`0D0?ooo`00<P3oool00`000000
oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3o0?ooo`h0
oooo6P2o03m00?ooo`030000003oool0oooo01@0oooo000b0?ooo`030000003oool0oooo0?l0oooo
I`3oool00`000000oooo0?ooo`110?ooo`800000o`3oool@0?oooaP0_`0o?`3oool3000001H0oooo
000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo0?l0oooo3`3ooolH0;l0?d40oooo00<000000?ooo`3oool0503oool00380oooo0P000003
0?ooo`T0O`1o6@3oool907l0OaX0oooo2@1o07lI0?ooo`T0O`1o6P3oool907l0P1d0oooo00<0003o
0?ooo`3oool06`3oool907l0P1X0oooo2@1o07lI0?ooo`T0O`1o6P3oool907l0OaT0oooo2@1o07l2
0?ooo`800000@`3oool00`000000oooo0?ooo`3o0?oooa00oooo5P2o03lC0?ooo`X0_`0o9@3oool0
0`000000oooo0?ooo`0D0?ooo`00<P3oool010000000oooo0?ooo`3oool;07l0OaL0oooo2`1o07lH
0?ooo`/0O`1o5`3oool;07l0OaP0oooo2`1o080i0?ooo`/0O`20603oool;07l0OaL0oooo2`1o07lH
0?ooo`/0O`1o5`3oool;07l0O`80oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3o
0?oooa40oooo502o03lB0?ooo`h0_`0o8`3oool00`000000oooo0?ooo`0D0?ooo`00<P3oool00`00
0000oooo0?ooo`0=07l0OaD0oooo3@1o07lF0?ooo`d0O`1o5@3oool=07l0OaH0oooo3@1o080g0?oo
o`d0O`205P3oool=07l0OaD0oooo3@1o07lF0?ooo`d0O`1o5@3oool=07l0O`030?ooo`000000oooo
0480oooo00<000000?ooo`3oool0o`3ooolA0?oooa@0_`0o4@3oool@0;l0?b80oooo00<000000?oo
o`3oool0503oool00380oooo00<000000?ooo`1o07l03P1o07lC0?ooo`l0O`1o503oool?07l0Oa<0
oooo3`1o07lD0?ooo`l0O`20=@3oool?07l0P1@0oooo3`1o07lC0?ooo`l0O`1o503oool?07l0Oa<0
oooo3`1o07l00`000000oooo0?ooo`110?ooo`030000003oool0oooo0?l0oooo4`3oool@0;l0?a40
oooo502o03lP0?ooo`030000003oool0oooo01@0oooo000b0?ooo`030000001o07l0O`1o00l0O`1o
4@3ooolA07l0Oa80oooo4@1o07lA0?oooa40O`1o4P3ooolA07l0P3<0oooo4@1o080B0?oooa40O`1o
4@3ooolA07l0Oa80oooo4@1o07lA0?oooa40O`1o@`3oool00`000000oooo0?ooo`3o0?oooa@0oooo
3P2o03lB0?oooa@0_`0o803oool00`000000oooo0?ooo`0D0?ooo`00<P3oool00`000000O`1o07l0
O`0?07l0Oa40oooo4@1o07lB0?oooa40O`1o4@3ooolA07l0Oa80oooo4@1o080c0?oooa40O`204P3o
oolA07l0Oa40oooo4@1o07lB0?oooa40O`1o4@3ooolA07l0Od<0oooo00<000000?ooo`3oool0o`3o
oolF0?ooo`X0_`0o4`3ooolF0;l0?al0oooo00<000000?ooo`3oool0503oool00380oooo00<00000
07l0O`1o07l03`1o07lA0?oooa40O`1o4P3ooolA07l0Oa40oooo4@1o07lB0?oooa40O`20<`3ooolA
07l0P180oooo4@1o07lA0?oooa40O`1o4P3ooolA07l0Oa40oooo4@1o07m30?ooo`030000003oool0
oooo0?l0oooo<P3ooolH0;l0?ah0oooo00<000000?ooo`3oool0503oool00380oooo00<0000007l0
O`1o07l03`1o07lA0?oooa40O`1o4P3ooolA07l0Oa40oooo4@1o07lB0?oooa40O`20<`3ooolA07l0
P180oooo4@1o07lA0?oooa40O`1o4P3ooolA07l0Oa40oooo4@1o07m30?ooo`030000003oool0oooo
0?l0oooo<P3ooolH0;l0?ah0oooo00<000000?ooo`3oool0503oool00380oooo4P1o07l@0?oooa80
O`1o4@3ooolB07l0Oa00oooo4P1o07lA0?oooa80O`206@3oool00`000?l0oooo0?ooo`0F0?oooa80
O`204@3ooolB07l0Oa00oooo4P1o07lA0?oooa80O`1o403ooolB07l0Od<0oooo0P00003o0?oooc80
oooo6P2o03lK0?ooo`<000005P3oool00380oooo00<0000007l0O`1o07l03`1o07lA0?oooa40O`1o
4P3ooolA07l0Oa40oooo4@1o07lB0?oooa40O`20<`3ooolA07l0P180oooo4@1o07lA0?oooa40O`1o
4P3ooolA07l0Oa40oooo4@1o07m30?ooo`030000003oool0oooo0?l0oooo<@3ooolJ0;l0?a80oooo
1P0o0;l50?ooo`030000003oool0oooo01@0oooo000b0?ooo`030000001o07l0O`1o00l0O`1o4@3o
oolA07l0Oa80oooo4@1o07lA0?oooa40O`1o4P3ooolA07l0P3<0oooo4@1o080B0?oooa40O`1o4@3o
oolA07l0Oa80oooo4@1o07lA0?oooa40O`1o@`3oool00`000000oooo0?ooo`3o0?oooc40oooo6P2o
03lA0?ooo`P0?`2o103oool00`000000oooo0?ooo`0D0?ooo`00<P3oool00`000000O`1o07l0O`0?
07l0Oa40oooo4@1o07lB0?oooa40O`1o4@3ooolA07l0Oa80oooo4@1o080c0?oooa40O`204P3ooolA
07l0Oa40oooo4@1o07lB0?oooa40O`1o4@3ooolA07l0Od<0oooo00<000000?ooo`3oool0o`3ooola
0?oooaX0_`0o4@3oool803l0_`@0oooo00<000000?ooo`3oool0503oool00380oooo00<0000007l0
O`1o07l03`1o07lA0?oooa40O`1o4P3ooolA07l0Oa40oooo4@1o07lB0?oooa40O`20<`3ooolA07l0
P180oooo4@1o07lA0?oooa40O`1o4P3ooolA07l0Oa40oooo4@1o07m30?ooo`030000003oool0oooo
0?l0oooo<@3ooolJ0;l0?a40oooo200o0;l40?ooo`030000003oool0oooo01@0oooo000b0?ooo`03
0000003oool0O`1o00h0O`1o4`3oool?07l0Oa@0oooo3`1o07lC0?ooo`l0O`1o503oool?07l0P3D0
oooo3`1o080D0?ooo`l0O`1o4`3oool?07l0Oa@0oooo3`1o07lC0?ooo`l0O`1o00<000000?ooo`3o
ool0@@3oool00`000000oooo0?ooo`3o0?oooc40oooo6P2o03lA0?ooo`P0?`2o103oool00`000000
oooo0?ooo`0D0?ooo`00<P3oool00`000000oooo0?ooo`0=07l0OaD0oooo3@1o07lF0?ooo`d0O`1o
5@3oool=07l0OaH0oooo3@1o080g0?ooo`d0O`205P3oool=07l0OaD0oooo3@1o07lF0?ooo`d0O`1o
5@3oool=07l0O`030?ooo`000000oooo0480oooo00<000000?ooo`3oool0o`3ooola0?oooaX0_`0o
4@3oool803l0_`@0oooo00<000000?ooo`3oool0503oool00380oooo00@000000?ooo`3oool0oooo
2`1o07lG0?ooo`/0O`1o603oool;07l0OaL0oooo2`1o07lH0?ooo`/0O`20>@3oool;07l0P1P0oooo
2`1o07lG0?ooo`/0O`1o603oool;07l0OaL0oooo2`1o07l20?ooo`030000003oool0oooo0440oooo
00<000000?ooo`3oool0o`3ooola0?oooaX0_`0o4@3oool803l0_`@0oooo00<000000?ooo`3oool0
503oool00380oooo00<000000?ooo`3oool00P3oool907l0OaT0oooo2@1o07lJ0?ooo`T0O`1o6@3o
ool907l0OaX0oooo2@1o080k0?ooo`T0O`206P3oool907l0OaT0oooo2@1o07lJ0?ooo`T0O`1o6@3o
ool907l0O`<0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3o0?oooc40oooo6P2o
03lB0?ooo`H0?`2o1@3oool00`000000oooo0?ooo`0D0?ooo`00<P3oool2000000L0oooo00<0O`1o
0?ooo`3oool07`3oool00`1o07l0oooo0?ooo`0P0?ooo`0307l0O`3oool0oooo01l0oooo00<0O`1o
0?ooo`3oool0803oool00`1o0800oooo0?ooo`110?ooo`0307l0P03oool0oooo0200oooo00<0O`1o
0?ooo`3oool07`3oool00`1o07l0oooo0?ooo`0P0?ooo`0307l0O`3oool0oooo01l0oooo00<0O`1o
0?ooo`3oool0103oool2000004<0oooo00<000000?ooo`3oool0o`3ooola0?oooaX0_`0o7@3oool0
0`000000oooo0?ooo`0D0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?oo
o`3oool0@@3oool200000?l0oooo<`3ooolH0;l0?a`0oooo0`00000F0?ooo`00<P3oool00`000000
oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3o0?oooc80
oooo602o03lN0?ooo`030000003oool0oooo01@0oooo000b0?ooo`030000003oool0oooo0?l0oooo
I`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0?l0oooo<`3ooolF0;l0?al0oooo
00<000000?ooo`3oool0503oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool0o`3ooold0?oooa@0_`0o4`3oool:0;l0?`<0oooo00<0
00000?ooo`3oool0503oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool0o`3ooold0?oooa@0_`0o4@3oool>0;l0?`030?ooo`000000
oooo01D0oooo000M0?ooo`800000103oool00`000000oooo0?ooo`030?ooo`8000001`3oool00`00
0000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3o0?oo
ocH0oooo402o03lB0?oooa00_`0o00<000000?ooo`3oool0503oool001`0oooo00@000000?ooo`3o
ool00000203oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo0?l0ooooI`3oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo0?l0oooo=`3oool>0;l0?a40oooo4`2o03lF
0?ooo`00703oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000H0oooo0`00
002^0?ooo`T0O`1o[@3oool3000004<0oooo00<000000?ooo`3oool0o`3oooli0?ooo`X0_`0o4`3o
oolC0;l0?aH0oooo000L0?ooo`040000003oool0oooo000000P0oooo0`0000070?ooo`030000003o
ool0oooo0:d0oooo2`1o07n^0?ooo`030000003oool0oooo03P0oooo100000050?ooo`030000003o
ool0oooo0?l0ooooE@3ooolD0;l0?aH0oooo000L0?ooo`040000003oool0oooo000000P0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`2/0?ooo`d0O`1o[@3oool00`000000oooo0?oo
o`0j0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooomD0?oooaD0_`0o5P3o
ool001`0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo0:/0oooo3`1o07n/0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0103o
ool300000?l0ooooE03ooolE0;l0?aH0oooo000M0?ooo`8000002P3oool3000000H0oooo00<00000
0?ooo`3oool0ZP3ooolA07l0Oj/0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0?l0ooooD`3ooolF0;l0?aH0oooo000b0?ooo`030000003oool0oooo
0:X0oooo4@1o07n[0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`3o0?oooe<0oooo5P2o03lF0?ooo`00<P3oool00`000000oooo0?ooo`2Z0?oooa40
O`1oZ`3oool00`000000oooo0?ooo`0h0?ooo`<000001P3oool00`000000oooo0?ooo`3o0?oooe<0
oooo5P2o03lF0?ooo`00<P3oool00`000000oooo0?ooo`2Z0?oooa40O`1oZ`3oool00`000000oooo
0?ooo`0j0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooomC0?oooaH0_`0o
5P3oool00380oooo0P00002A0?ooo`030000o`3oool0oooo01H0oooo4P1o07lI0?ooo`030000o`3o
ool0oooo08h0oooo0P0000130?ooo`030000003oool0oooo0?l0ooooD`3ooolF0;l0?aH0oooo000b
0?ooo`030000003oool0oooo0:X0oooo4@1o07n[0?ooo`030000003oool0oooo0440oooo00<00000
0?ooo`3oool0o`3ooomC0?oooaH0_`0o5P3oool00380oooo00<000000?ooo`3oool0ZP3ooolA07l0
Oj/0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3o0?oooe<0oooo5P2o03lF0?oo
o`00<P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3o
ool0C03ooolA07l0Odd0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0440oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1C0?ooo`03
0000003oool0oooo05<0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`170?oooaH0
_`0o5P3oool00380oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`070?oooa40O`1o
203oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo5P2o03lF0?ooo`00<P3o
oon^000000l0O`1o[@0000130?ooool00000EP00000F0;l0?aH0oooo003o0?ooool0ooooo`3ooomS
0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0oooo
o`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?oo
ool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00001\
\>"],
  ImageRangeCache->{{{0, 863}, {253.25, 0}} -> {-0.0530409, -0.0147182, \
0.00244042, 0.00244042}, {{21.6875, 411.938}, {247.188, 6}} -> {-1.34159, \
-0.814895, 0.00580751, 0.00610788}, {{451, 841.25}, {247.188, 6}} -> \
{-3.83483, -1.31637, 0.00580751, 0.00986655}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  GraphicsArray  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["", "Text",
  Editable->False,
  Selectable->False,
  CellFrame->{{0, 0}, {0, 3}},
  ShowCellBracket->False,
  CellMargins->{{0, 0}, {1, 1}},
  CellElementSpacings->{"CellMinHeight"->1},
  CellFrameMargins->False,
  CellFrameColor->RGBColor[0, 0, 1],
  CellSize->{Inherited, 5}],

Cell[" Faster approach", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*\ Prepare\ matrices\ *) \)\(\[IndentingNewLine]\)\(Zmatrix = 
      makematricesbzvc[1, bvc]\[IndentingNewLine]
    x1 = makematricesbzvc[number[d[1]], bvc]\)\)\)], "Input"],

Cell[BoxData[
    \({{{\(-2\), 
          0}, {{1}}}, {{\(-1\), \(-\(1\/2\)\)}, {{1, 0}, {0, 1}}}, {{\(-1\), 
          1\/2}, {{1, 0}, {0, 1}}}, {{0, \(-1\)}, {{1}}}, {{0, 
          0}, {{1, 0, 0, 0}, {0, 1, 0, 0}, {0, 0, 1, 0}, {0, 0, 0, 1}}}, {{0, 
          1}, {{1}}}, {{1, \(-\(1\/2\)\)}, {{1, 0}, {0, 1}}}, {{1, 
          1\/2}, {{1, 0}, {0, 1}}}, {{2, 0}, {{1}}}}\)], "Output"],

Cell[BoxData[
    \({{{\(-2\), 
          0}, {{0}}}, {{\(-1\), \(-\(1\/2\)\)}, {{1, 0}, {0, 0}}}, {{\(-1\), 
          1\/2}, {{1, 0}, {0, 0}}}, {{0, \(-1\)}, {{1}}}, {{0, 
          0}, {{2, 0, 0, 0}, {0, 1, 0, 0}, {0, 0, 1, 0}, {0, 0, 0, 0}}}, {{0, 
          1}, {{1}}}, {{1, \(-\(1\/2\)\)}, {{2, 0}, {0, 1}}}, {{1, 
          1\/2}, {{2, 0}, {0, 1}}}, {{2, 0}, {{2}}}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(tdtr1FAST[eig, Zmatrix]\), "\[IndentingNewLine]", 
    \(tdtr1expr[eig2, 1]\)}], "Input"],

Cell[BoxData[
    \(2.`\ \[ExponentialE]\^\(\(-1.5`\)\ beta\) + 
      2.`\ \[ExponentialE]\^\(\(-1.`\)\ beta\) + 
      4.`\ \[ExponentialE]\^\(\(-0.5`\)\ beta\) + 
      1.0000000000000002`\ \[ExponentialE]\^\(\(-0.05000000000000002`\)\ beta\
\) + 2\ \[ExponentialE]\^\(\(-beta\)/20\) + 
      1.0000000000000002`\ \[ExponentialE]\^\(0.15`\ beta\) + 
      2.`\ \[ExponentialE]\^\(0.5`\ beta\) + 
      2.`\ \[ExponentialE]\^\(1.`\ beta\)\)], "Output"],

Cell[BoxData[
    \(2.`\ \[ExponentialE]\^\(\(-1.5`\)\ beta\) + 
      2.`\ \[ExponentialE]\^\(\(-1.`\)\ beta\) + 
      4.`\ \[ExponentialE]\^\(\(-0.5`\)\ beta\) + 
      1.0000000000000002`\ \[ExponentialE]\^\(\(-0.05000000000000002`\)\ beta\
\) + 2\ \[ExponentialE]\^\(\(-beta\)/20\) + 
      1.0000000000000002`\ \[ExponentialE]\^\(0.15`\ beta\) + 
      2.`\ \[ExponentialE]\^\(0.5`\ beta\) + 
      2.`\ \[ExponentialE]\^\(1.`\ beta\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(tdtr1FAST[eig, x1]\), "\[IndentingNewLine]", 
    \(tdtr1expr[eig2, number[d[1]]]\)}], "Input"],

Cell[BoxData[
    \(2.`\ \[ExponentialE]\^\(\(-1.5`\)\ beta\) + 
      2.`\ \[ExponentialE]\^\(\(-1.`\)\ beta\) + 
      4.`\ \[ExponentialE]\^\(\(-0.5`\)\ beta\) + 
      1.0000000000000002`\ \[ExponentialE]\^\(\(-0.05000000000000002`\)\ beta\
\) + 2\ \[ExponentialE]\^\(\(-beta\)/20\) + 
      1.0000000000000002`\ \[ExponentialE]\^\(0.15`\ beta\) + 
      2.`\ \[ExponentialE]\^\(0.5`\ beta\) + 
      2.`\ \[ExponentialE]\^\(1.`\ beta\)\)], "Output"],

Cell[BoxData[
    \(2.`\ \[ExponentialE]\^\(\(-1.5`\)\ beta\) + 
      2.`\ \[ExponentialE]\^\(\(-1.`\)\ beta\) + 
      4.`\ \[ExponentialE]\^\(\(-0.5`\)\ beta\) + 
      1.0000000000000002`\ \[ExponentialE]\^\(\(-0.05000000000000002`\)\ beta\
\) + 2\ \[ExponentialE]\^\(\(-beta\)/20\) + 
      1.0000000000000002`\ \[ExponentialE]\^\(0.15`\ beta\) + 
      2.`\ \[ExponentialE]\^\(0.5`\ beta\) + 
      2.`\ \[ExponentialE]\^\(1.`\ beta\)\)], "Output"]
}, Open  ]],

Cell["", "Text",
  Editable->False,
  Selectable->False,
  CellFrame->{{0, 0}, {0, 2}},
  ShowCellBracket->False,
  CellMargins->{{0, 0}, {1, 1}},
  CellElementSpacings->{"CellMinHeight"->1},
  CellFrameMargins->False,
  CellFrameColor->RGBColor[0, 0, 1],
  CellSize->{Inherited, 4}],

Cell[CellGroupData[{

Cell[BoxData[{
    \(makeallmatricesbzvc[1, bvc]\), "\[IndentingNewLine]", 
    \(% /. {{qn1_?VectorQ, qn2_?VectorQ}, mat_?ArrayQ} \[RuleDelayed] {qn1, 
          mat}\), "\[IndentingNewLine]", 
    \(makematricesbzvc[1, bvc]\)}], "Input"],

Cell[BoxData[
    \({{{{\(-2\), 0}, {\(-2\), 
            0}}, {{1}}}, {{{\(-1\), \(-\(1\/2\)\)}, {\(-1\), \(-\(1\/2\)\)}}, \
{{1, 0}, {0, 1}}}, {{{\(-1\), 1\/2}, {\(-1\), 1\/2}}, {{1, 0}, {0, 
            1}}}, {{{0, \(-1\)}, {0, \(-1\)}}, {{1}}}, {{{0, 0}, {0, 
            0}}, {{1, 0, 0, 0}, {0, 1, 0, 0}, {0, 0, 1, 0}, {0, 0, 0, 
            1}}}, {{{0, 1}, {0, 
            1}}, {{1}}}, {{{1, \(-\(1\/2\)\)}, {1, \(-\(1\/2\)\)}}, {{1, 
            0}, {0, 1}}}, {{{1, 1\/2}, {1, 1\/2}}, {{1, 0}, {0, 1}}}, {{{2, 
            0}, {2, 0}}, {{1}}}}\)], "Output"],

Cell[BoxData[
    \({{{\(-2\), 
          0}, {{1}}}, {{\(-1\), \(-\(1\/2\)\)}, {{1, 0}, {0, 1}}}, {{\(-1\), 
          1\/2}, {{1, 0}, {0, 1}}}, {{0, \(-1\)}, {{1}}}, {{0, 
          0}, {{1, 0, 0, 0}, {0, 1, 0, 0}, {0, 0, 1, 0}, {0, 0, 0, 1}}}, {{0, 
          1}, {{1}}}, {{1, \(-\(1\/2\)\)}, {{1, 0}, {0, 1}}}, {{1, 
          1\/2}, {{1, 0}, {0, 1}}}, {{2, 0}, {{1}}}}\)], "Output"],

Cell[BoxData[
    \({{{\(-2\), 
          0}, {{1}}}, {{\(-1\), \(-\(1\/2\)\)}, {{1, 0}, {0, 1}}}, {{\(-1\), 
          1\/2}, {{1, 0}, {0, 1}}}, {{0, \(-1\)}, {{1}}}, {{0, 
          0}, {{1, 0, 0, 0}, {0, 1, 0, 0}, {0, 0, 1, 0}, {0, 0, 0, 1}}}, {{0, 
          1}, {{1}}}, {{1, \(-\(1\/2\)\)}, {{1, 0}, {0, 1}}}, {{1, 
          1\/2}, {{1, 0}, {0, 1}}}, {{2, 0}, {{1}}}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cmat = makeallmatricesbzvc[c[CR, 1, UP], bvc]\)], "Input"],

Cell[BoxData[
    \({{{{\(-1\), 1\/2}, {\(-2\), 0}}, {{0}, {1}}}, {{{0, 
            0}, {\(-1\), \(-\(1\/2\)\)}}, {{0, 0}, {0, 0}, {1, 0}, {0, 
            1}}}, {{{0, 1}, {\(-1\), 1\/2}}, {{1, 
            0}}}, {{{1, \(-\(1\/2\)\)}, {0, \(-1\)}}, {{0}, {1}}}, {{{1, 
            1\/2}, {0, 0}}, {{1, 0, 0, 0}, {0, 1, 0, 0}}}, {{{2, 
            0}, {1, \(-\(1\/2\)\)}}, {{1, 0}}}}\)], "Output"]
}, Open  ]],

Cell["", "Text",
  Editable->False,
  Selectable->False,
  CellFrame->{{0, 0}, {0, 2}},
  ShowCellBracket->False,
  CellMargins->{{0, 0}, {1, 1}},
  CellElementSpacings->{"CellMinHeight"->1},
  CellFrameMargins->False,
  CellFrameColor->RGBColor[0, 0, 1],
  CellSize->{Inherited, 4}],

Cell[CellGroupData[{

Cell[BoxData[{
    \(spectral2FAST[eig, cmat]\), "\[IndentingNewLine]", 
    \(Expand\ @\ spectral2expr[eig2, c[CR, 1, UP]]\)}], "Input"],

Cell[BoxData[
    \(0.5000000000000001`\ \[ExponentialE]\^\(0.15`\ beta\)\ \
Delta[\(\(0.85`\)\(\[InvisibleSpace]\)\) + omega] + 
      0.5000000000000001`\ \[ExponentialE]\^\(1.`\ beta\)\ \
Delta[\(\(0.85`\)\(\[InvisibleSpace]\)\) + omega] + 
      1.5`\ \[ExponentialE]\^\(\(-1.`\)\ beta\)\ Delta[\(\(0.95`\)\(\
\[InvisibleSpace]\)\) + omega] + 
      0.5000000000000001`\ \[ExponentialE]\^\(\(-0.05000000000000002`\)\ beta\
\)\ Delta[\(\(0.95`\)\(\[InvisibleSpace]\)\) + omega] + 
      1.`\ \[ExponentialE]\^\(\(-beta\)/20\)\ Delta[\(\(0.95`\)\(\
\[InvisibleSpace]\)\) + omega] + 
      2.`\ \[ExponentialE]\^\(\(-1.5`\)\ beta\)\ Delta[\(\(1.`\)\(\
\[InvisibleSpace]\)\) + omega] + 
      4.`\ \[ExponentialE]\^\(\(-0.5`\)\ beta\)\ Delta[\(\(1.`\)\(\
\[InvisibleSpace]\)\) + omega] + 
      2.`\ \[ExponentialE]\^\(0.5`\ beta\)\ \
Delta[\(\(1.`\)\(\[InvisibleSpace]\)\) + omega] + 
      0.5000000000000001`\ \[ExponentialE]\^\(\(-0.05000000000000002`\)\ beta\
\)\ Delta[\(\(1.05`\)\(\[InvisibleSpace]\)\) + omega] + 
      1.`\ \[ExponentialE]\^\(\(-beta\)/20\)\ Delta[\(\(1.05`\)\(\
\[InvisibleSpace]\)\) + omega] + 
      1.5`\ \[ExponentialE]\^\(1.`\ beta\)\ Delta[\(\(1.05`\)\(\
\[InvisibleSpace]\)\) + omega] + 
      0.5000000000000001`\ \[ExponentialE]\^\(\(-1.`\)\ beta\)\ \
Delta[\(\(1.15`\)\(\[InvisibleSpace]\)\) + omega] + 
      0.5000000000000001`\ \[ExponentialE]\^\(0.15`\ beta\)\ \
Delta[\(\(1.15`\)\(\[InvisibleSpace]\)\) + omega]\)], "Output"],

Cell[BoxData[
    \(0.5000000000000001`\ \[ExponentialE]\^\(0.15`\ beta\)\ \
Delta[\(\(0.85`\)\(\[InvisibleSpace]\)\) + omega] + 
      0.5000000000000001`\ \[ExponentialE]\^\(1.`\ beta\)\ \
Delta[\(\(0.85`\)\(\[InvisibleSpace]\)\) + omega] + 
      1.5`\ \[ExponentialE]\^\(\(-1.`\)\ beta\)\ Delta[\(\(0.95`\)\(\
\[InvisibleSpace]\)\) + omega] + 
      0.5000000000000001`\ \[ExponentialE]\^\(\(-0.05000000000000002`\)\ beta\
\)\ Delta[\(\(0.95`\)\(\[InvisibleSpace]\)\) + omega] + 
      1.`\ \[ExponentialE]\^\(\(-beta\)/20\)\ Delta[\(\(0.95`\)\(\
\[InvisibleSpace]\)\) + omega] + 
      2.`\ \[ExponentialE]\^\(\(-1.5`\)\ beta\)\ Delta[\(\(1.`\)\(\
\[InvisibleSpace]\)\) + omega] + 
      4.`\ \[ExponentialE]\^\(\(-0.5`\)\ beta\)\ Delta[\(\(1.`\)\(\
\[InvisibleSpace]\)\) + omega] + 
      2.`\ \[ExponentialE]\^\(0.5`\ beta\)\ \
Delta[\(\(1.`\)\(\[InvisibleSpace]\)\) + omega] + 
      0.5000000000000001`\ \[ExponentialE]\^\(\(-0.05000000000000002`\)\ beta\
\)\ Delta[\(\(1.05`\)\(\[InvisibleSpace]\)\) + omega] + 
      1.`\ \[ExponentialE]\^\(\(-beta\)/20\)\ Delta[\(\(1.05`\)\(\
\[InvisibleSpace]\)\) + omega] + 
      1.5`\ \[ExponentialE]\^\(1.`\ beta\)\ Delta[\(\(1.05`\)\(\
\[InvisibleSpace]\)\) + omega] + 
      0.5000000000000001`\ \[ExponentialE]\^\(\(-1.`\)\ beta\)\ \
Delta[\(\(1.15`\)\(\[InvisibleSpace]\)\) + omega] + 
      0.5000000000000001`\ \[ExponentialE]\^\(0.15`\ beta\)\ \
Delta[\(\(1.15`\)\(\[InvisibleSpace]\)\) + omega]\)], "Output"]
}, Open  ]],

Cell["", "Text",
  Editable->False,
  Selectable->False,
  CellFrame->{{0, 0}, {0, 3}},
  ShowCellBracket->False,
  CellMargins->{{0, 0}, {1, 1}},
  CellElementSpacings->{"CellMinHeight"->1},
  CellFrameMargins->False,
  CellFrameColor->RGBColor[0, 0, 1],
  CellSize->{Inherited, 5}],

Cell[BoxData[
    \(calculateSetup[evl, spl]\)], "Input"],

Cell[BoxData[{
    \(\(values = {};\)\), "\[IndentingNewLine]", 
    \(Scan[\((doit[#, calculateFAST])\) &, 
      Table[x, {x, \(-0.4\), 0.4, 0.02}]]\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MatrixForm\ @\ Map[{#, expvresults[#]} &, values]\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(-0.4`\), \({1, 0.9999999999999999`, 1.999999999993056`, 
                3.999999999979168`, 0}\)},
            {\(-0.38`\), \({1, 1.`, 1.9999999999486908`, 3.999999999846072`, 
                0}\)},
            {\(-0.36000000000000004`\), \({1, 1.`, 1.9999999996208722`, 
                3.999999998862616`, \(-2.843460153528102`*^-10\)}\)},
            {\(-0.34`\), \({1, 1.`, 1.9999999971986018`, 
                3.999999991595805`, \(-2.1010486538600175`*^-9\)}\)},
            {\(-0.32`\), \({1, 1.`, 1.9999999793003116`, 
                3.999999937900935`, \(-1.5524766092087625`*^-8\)}\)},
            {\(-0.30000000000000004`\), \({1, 1.`, 1.999999847048862`, 
                3.999999541146586`, \(-1.1471335240620195`*^-7\)}\)},
            {\(-0.28`\), \({1, 1.`, 1.9999988698365667`, 
                3.9999966095097004`, \(-8.476225679176962`*^-7\)}\)},
            {\(-0.26`\), \({1, 0.9999999999999999`, 1.9999916492192893`, 
                3.999974947657867`, \(-6.263085481342643`*^-6\)}\)},
            {\(-0.24000000000000002`\), \({1, 1.`, 1.9999382989048353`, 
                3.999814896714506`, \(-0.000046275820992098266`\)}\)},
            {\(-0.22000000000000003`\), \({1, 1.`, 1.999544266801847`, 
                3.9986328004055407`, \(-0.00034179989579675275`\)}\)},
            {\(-0.2`\), \({1, 0.9999999999999999`, 1.9966423383528047`, 
                3.9899270150584147`, \(-0.002518246214634185`\)}\)},
            {\(-0.18000000000000002`\), \({1, 1.`, 1.9757111021741949`, 
                3.927133306522585`, \(-0.018216673219164026`\)}\)},
            {\(-0.16000000000000003`\), \({1, 1.`, 1.8446375956915928`, 
                3.5339127870748`, \(-0.11652180227061194`\)}\)},
            {\(-0.14`\), \({1, 1.`, 1.4238831137237147`, 
                2.271649341171729`, \(-0.43208766114437847`\)}\)},
            {\(-0.12000000000000002`\), \({1, 1.`, 1.0905570009742822`, 
                1.271671002929684`, \(-0.6820822436406551`\)}\)},
            {\(-0.10000000000000002`\), \({1, 1.`, 1.0132967088488347`, 
                1.0398901266013172`, \(-0.740027462221023`\)}\)},
            {\(-0.08000000000000002`\), \({1, 1.`, 1.001820443654765`, 
                1.005461331374023`, \(-0.7486346607794261`\)}\)},
            {\(-0.06000000000000001`\), \({1, 1.`, 1.0002467571852494`, 
                1.000740274588024`, \(-0.749814923654921`\)}\)},
            {\(-0.040000000000000015`\), \({1, 1.`, 1.0000333910800314`, 
                1.0001001956505309`, \(-0.7499749336988947`\)}\)},
            {\(-0.020000000000000014`\), \({1, 1.`, 1.0000044378396027`, 
                1.0000134791155537`, \(-0.7499965412393065`\)}\)},
            {\(-1.3877787807814457`*^-17\), \({1, 1.`, 1.`, 
                1.000001223607777`, \(-0.7499990761107137`\)}\)},
            {
              "0.019999999999999987`", \({1, 1.`, 0.9999955621603972`, 
                0.9999957277571426`, \(-0.7499965412393065`\)}\)},
            {
              "0.03999999999999999`", \({1, 1.`, 0.9999666089199688`, 
                0.9999666313304055`, \(-0.7499749336988947`\)}\)},
            {
              "0.059999999999999984`", \({1, 1.`, 0.9997532428147504`, 
                0.9997532458470262`, \(-0.749814923654921`\)}\)},
            {
              "0.07999999999999999`", \({1, 1.`, 0.998179556345235`, 
                0.998179556754963`, \(-0.7486346607794261`\)}\)},
            {
              "0.09999999999999999`", \({1, 1.`, 0.9867032911511654`, 
                0.9867032912059785`, \(-0.740027462221023`\)}\)},
            {
              "0.12`", \({1, 1.`, 0.909442999025718`, 
                0.9094429990325553`, \(-0.6820822436406553`\)}\)},
            {
              "0.13999999999999999`", \({1, 1.`, 0.5761168862762865`, 
                0.5761168862768727`, \(-0.432087661144379`\)}\)},
            {
              "0.15999999999999998`", \({1, 1.`, 0.1553624043084078`, 
                0.1553624043084292`, \(-0.11652180227061246`\)}\)},
            {
              "0.18`", \({1, 1.`, 0.02428889782580517`, 
                0.024288897825805626`, \(-0.01821667321916409`\)}\)},
            {
              "0.19999999999999998`", \({1, 0.9999999999999999`, 
                0.0033576616471948815`, 
                0.0033576616471948893`, \(-0.002518246214634185`\)}\)},
            {"0.22`", \({1, 1.`, 0.0004557331981530166`, 
                0.00045573319815301683`, \(-0.000341799895796754`\)}\)},
            {
              "0.24`", \({1, 1.`, 0.00006170109516483299`, 
                0.000061701095164833`, \(-0.000046275820992098435`\)}\)},
            {
              "0.26`", \({1, 0.9999999999999999`, 8.350780710639159`*^-6, 
                8.350780710639159`*^-6, \(-6.263085481342643`*^-6\)}\)},
            {
              "0.27999999999999997`", \({1, 1.`, 1.1301634332080315`*^-6, 
                1.1301634332080315`*^-6, \(-8.476225679177022`*^-7\)}\)},
            {
              "0.3`", \({1, 1.`, 1.5295113780262632`*^-7, 
                1.5295113780262632`*^-7, \(-1.1471335240620235`*^-7\)}\)},
            {
              "0.32`", \({1, 1.`, 2.069968829344445`*^-8, 
                2.069968829344445`*^-8, \(-1.5524766092087625`*^-8\)}\)},
            {
              "0.33999999999999997`", \({1, 1.`, 2.8013982282431387`*^-9, 
                2.8013982282431387`*^-9, \(-2.1010486538600175`*^-9\)}\)},
            {
              "0.36`", \({1, 1.`, 3.791280235961807`*^-10, 
                3.791280235961807`*^-10, \(-2.843460153528122`*^-10\)}\)},
            {"0.38`", \({1, 1.`, 0, 0, 0}\)},
            {"0.4`", \({1, 0.9999999999999999`, 0, 0, 0}\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({\[Epsilon]s \[Rule] value, \[Delta]d \[Rule] 0, J \[Rule] 1/5, 
      U \[Rule] 1}\)], "Input"],

Cell[BoxData[
    \({\[Epsilon]s \[Rule] value, \[Delta]d \[Rule] 0, J \[Rule] 1\/5, 
      U \[Rule] 1}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(scale = 0.03;\)\), "\[IndentingNewLine]", 
    \(\(pts = 
        Map[specresults[#] /. rule[#] &, 
          values];\)\), "\[IndentingNewLine]", 
    \(\(pts1 = pointswithsize\ @\ \ pts[\([All, 1]\)];\)\), "\n", 
    \(\(pts2 = 
        pointswithsize\ @\ \ pts[\([All, 2]\)];\)\), "\[IndentingNewLine]", 
    \(Show\ [\ 
      GraphicsArray[\ {Graphics\ [pts1, Frame \[Rule] True], 
          Graphics[pts2, Frame \[Rule] True]}], 
      ImageSize \[Rule] 12\ 72]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
%%ImageSize: 864 254.277 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 1.19048 0.309017 0.452772 [
[.02381 -0.0125 -12 -9 ]
[.02381 -0.0125 12 0 ]
[.2619 -0.0125 -12 -9 ]
[.2619 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .03735 -24 -4.5 ]
[-0.0125 .03735 0 4.5 ]
[-0.0125 .12791 -24 -4.5 ]
[-0.0125 .12791 0 4.5 ]
[-0.0125 .21846 -24 -4.5 ]
[-0.0125 .21846 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .39957 -18 -4.5 ]
[-0.0125 .39957 0 4.5 ]
[-0.0125 .49013 -18 -4.5 ]
[-0.0125 .49013 0 4.5 ]
[-0.0125 .58068 -18 -4.5 ]
[-0.0125 .58068 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-0.4)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-0.2)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(0.2)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(0.4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.08333 0 m
.08333 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.20238 0 m
.20238 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.44048 0 m
.44048 .00375 L
s
.55952 0 m
.55952 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.67857 0 m
.67857 .00375 L
s
.79762 0 m
.79762 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .03735 m
.00625 .03735 L
s
[(-0.6)] -0.0125 .03735 1 0 Mshowa
0 .12791 m
.00625 .12791 L
s
[(-0.4)] -0.0125 .12791 1 0 Mshowa
0 .21846 m
.00625 .21846 L
s
[(-0.2)] -0.0125 .21846 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .39957 m
.00625 .39957 L
s
[(0.2)] -0.0125 .39957 1 0 Mshowa
0 .49013 m
.00625 .49013 L
s
[(0.4)] -0.0125 .49013 1 0 Mshowa
0 .58068 m
.00625 .58068 L
s
[(0.6)] -0.0125 .58068 1 0 Mshowa
.125 Mabswid
0 .05999 m
.00375 .05999 L
s
0 .08263 m
.00375 .08263 L
s
0 .10527 m
.00375 .10527 L
s
0 .15055 m
.00375 .15055 L
s
0 .17319 m
.00375 .17319 L
s
0 .19582 m
.00375 .19582 L
s
0 .2411 m
.00375 .2411 L
s
0 .26374 m
.00375 .26374 L
s
0 .28638 m
.00375 .28638 L
s
0 .33166 m
.00375 .33166 L
s
0 .35429 m
.00375 .35429 L
s
0 .37693 m
.00375 .37693 L
s
0 .42221 m
.00375 .42221 L
s
0 .44485 m
.00375 .44485 L
s
0 .46749 m
.00375 .46749 L
s
0 .51276 m
.00375 .51276 L
s
0 .5354 m
.00375 .5354 L
s
0 .55804 m
.00375 .55804 L
s
0 .01472 m
.00375 .01472 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.08333 .61428 m
.08333 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.20238 .61428 m
.20238 .61803 L
s
.32143 .61428 m
.32143 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.44048 .61428 m
.44048 .61803 L
s
.55952 .61428 m
.55952 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.67857 .61428 m
.67857 .61803 L
s
.79762 .61428 m
.79762 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.91667 .61428 m
.91667 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .03735 m
1 .03735 L
s
.99375 .12791 m
1 .12791 L
s
.99375 .21846 m
1 .21846 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .39957 m
1 .39957 L
s
.99375 .49013 m
1 .49013 L
s
.99375 .58068 m
1 .58068 L
s
.125 Mabswid
.99625 .05999 m
1 .05999 L
s
.99625 .08263 m
1 .08263 L
s
.99625 .10527 m
1 .10527 L
s
.99625 .15055 m
1 .15055 L
s
.99625 .17319 m
1 .17319 L
s
.99625 .19582 m
1 .19582 L
s
.99625 .2411 m
1 .2411 L
s
.99625 .26374 m
1 .26374 L
s
.99625 .28638 m
1 .28638 L
s
.99625 .33166 m
1 .33166 L
s
.99625 .35429 m
1 .35429 L
s
.99625 .37693 m
1 .37693 L
s
.99625 .42221 m
1 .42221 L
s
.99625 .44485 m
1 .44485 L
s
.99625 .46749 m
1 .46749 L
s
.99625 .51276 m
1 .51276 L
s
.99625 .5354 m
1 .5354 L
s
.99625 .55804 m
1 .55804 L
s
.99625 .01472 m
1 .01472 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 0 .5 r
.015 w
.02381 .08263 Mdot
.02381 .5354 Mdot
.015 w
.04762 .08263 Mdot
.04762 .5354 Mdot
0 0 1 r
0 w
.07143 .01472 Mdot
.5 0 .5 r
.015 w
.07143 .08263 Mdot
.07143 .5354 Mdot
0 0 1 r
0 w
.07143 .60332 Mdot
0 w
.09524 .01472 Mdot
.5 0 .5 r
.015 w
.09524 .08263 Mdot
.09524 .5354 Mdot
0 0 1 r
0 w
.09524 .60332 Mdot
0 w
.11905 .01472 Mdot
.5 0 .5 r
.015 w
.11905 .08263 Mdot
.11905 .5354 Mdot
0 0 1 r
0 w
.11905 .60332 Mdot
0 w
.14286 .01472 Mdot
.5 0 .5 r
.015 w
.14286 .08263 Mdot
.14286 .5354 Mdot
0 0 1 r
0 w
.14286 .60332 Mdot
0 w
.16667 .01472 Mdot
.5 0 .5 r
.015 w
.16667 .08263 Mdot
.16667 .5354 Mdot
0 0 1 r
0 w
.16667 .60332 Mdot
0 w
.19048 .01472 Mdot
.5 0 .5 r
.015 w
.19048 .08263 Mdot
.19048 .5354 Mdot
0 0 1 r
0 w
.19048 .60332 Mdot
0 w
.21429 .01472 Mdot
.5 0 .5 r
.015 w
.21429 .08263 Mdot
.21429 .5354 Mdot
0 0 1 r
0 w
.21429 .60332 Mdot
1e-05 w
.2381 .01472 Mdot
.5 0 .5 r
.01499 w
.2381 .08263 Mdot
.2381 .5354 Mdot
0 0 1 r
1e-05 w
.2381 .60332 Mdot
.002 0 .998 r
5e-05 w
.2619 .01472 Mdot
.498 0 .502 r
.01495 w
.2619 .08263 Mdot
.2619 .5354 Mdot
.002 0 .998 r
5e-05 w
.2619 .60332 Mdot
.012 0 .988 r
.00036 w
.28571 .01472 Mdot
.488 0 .512 r
.01464 w
.28571 .08263 Mdot
.28571 .5354 Mdot
.012 0 .988 r
.00036 w
.28571 .60332 Mdot
.078 0 .922 r
.00233 w
.30952 .01472 Mdot
.422 0 .578 r
.01267 w
.30952 .08263 Mdot
0 0 1 r
0 w
.30952 .10527 Mdot
.30952 .51276 Mdot
.422 0 .578 r
.01267 w
.30952 .5354 Mdot
.078 0 .922 r
.00233 w
.30952 .60332 Mdot
.288 0 .712 r
.00864 w
.33333 .01472 Mdot
.212 0 .788 r
.00636 w
.33333 .08263 Mdot
0 0 1 r
0 w
.33333 .10527 Mdot
.33333 .51276 Mdot
.212 0 .788 r
.00636 w
.33333 .5354 Mdot
.288 0 .712 r
.00864 w
.33333 .60332 Mdot
.455 0 .545 r
.01364 w
.35714 .01472 Mdot
.045 0 .955 r
.00136 w
.35714 .08263 Mdot
0 0 1 r
0 w
.35714 .10527 Mdot
.35714 .51276 Mdot
.045 0 .955 r
.00136 w
.35714 .5354 Mdot
.455 0 .545 r
.01364 w
.35714 .60332 Mdot
.493 0 .507 r
.0148 w
.38095 .01472 Mdot
.007 0 .993 r
.0002 w
.38095 .08263 Mdot
0 0 1 r
0 w
.38095 .10527 Mdot
.38095 .51276 Mdot
.007 0 .993 r
.0002 w
.38095 .5354 Mdot
.493 0 .507 r
.0148 w
.38095 .60332 Mdot
.499 0 .501 r
.01497 w
.40476 .01472 Mdot
.001 0 .999 r
3e-05 w
.40476 .08263 Mdot
0 0 1 r
0 w
.40476 .10527 Mdot
.40476 .51276 Mdot
.001 0 .999 r
3e-05 w
.40476 .5354 Mdot
.499 0 .501 r
.01497 w
.40476 .60332 Mdot
.5 0 .5 r
.015 w
.42857 .01472 Mdot
0 0 1 r
0 w
.42857 .08263 Mdot
0 w
.42857 .10527 Mdot
.42857 .51276 Mdot
0 w
.42857 .5354 Mdot
.5 0 .5 r
.015 w
.42857 .60332 Mdot
.015 w
.45238 .01472 Mdot
0 0 1 r
0 w
.45238 .08263 Mdot
0 w
.45238 .10527 Mdot
.45238 .51276 Mdot
0 w
.45238 .5354 Mdot
.5 0 .5 r
.015 w
.45238 .60332 Mdot
.015 w
.47619 .01472 Mdot
0 0 1 r
0 w
.47619 .08263 Mdot
0 w
.47619 .10527 Mdot
.47619 .51276 Mdot
0 w
.47619 .5354 Mdot
.5 0 .5 r
.015 w
.47619 .60332 Mdot
.015 w
.5 .01472 Mdot
0 0 1 r
0 w
.5 .08263 Mdot
0 w
.5 .10527 Mdot
.5 .51276 Mdot
0 w
.5 .5354 Mdot
.5 0 .5 r
.015 w
.5 .60332 Mdot
.015 w
.52381 .01472 Mdot
0 0 1 r
0 w
.52381 .08263 Mdot
0 w
.52381 .10527 Mdot
.52381 .51276 Mdot
0 w
.52381 .5354 Mdot
.5 0 .5 r
.015 w
.52381 .60332 Mdot
.015 w
.54762 .01472 Mdot
0 0 1 r
0 w
.54762 .08263 Mdot
0 w
.54762 .10527 Mdot
.54762 .51276 Mdot
0 w
.54762 .5354 Mdot
.5 0 .5 r
.015 w
.54762 .60332 Mdot
.015 w
.57143 .01472 Mdot
0 0 1 r
0 w
.57143 .08263 Mdot
0 w
.57143 .10527 Mdot
.57143 .51276 Mdot
0 w
.57143 .5354 Mdot
.5 0 .5 r
.015 w
.57143 .60332 Mdot
.499 0 .501 r
.01497 w
.59524 .01472 Mdot
.001 0 .999 r
3e-05 w
.59524 .08263 Mdot
0 0 1 r
0 w
.59524 .10527 Mdot
.59524 .51276 Mdot
.001 0 .999 r
3e-05 w
.59524 .5354 Mdot
.499 0 .501 r
.01497 w
.59524 .60332 Mdot
.493 0 .507 r
.0148 w
.61905 .01472 Mdot
.007 0 .993 r
.0002 w
.61905 .08263 Mdot
0 0 1 r
0 w
.61905 .10527 Mdot
.61905 .51276 Mdot
.007 0 .993 r
.0002 w
.61905 .5354 Mdot
.493 0 .507 r
.0148 w
.61905 .60332 Mdot
.455 0 .545 r
.01364 w
.64286 .01472 Mdot
.045 0 .955 r
.00136 w
.64286 .08263 Mdot
0 0 1 r
0 w
.64286 .10527 Mdot
.64286 .51276 Mdot
.045 0 .955 r
.00136 w
.64286 .5354 Mdot
.455 0 .545 r
.01364 w
.64286 .60332 Mdot
.288 0 .712 r
.00864 w
.66667 .01472 Mdot
.212 0 .788 r
.00636 w
.66667 .08263 Mdot
0 0 1 r
0 w
.66667 .10527 Mdot
.66667 .51276 Mdot
.212 0 .788 r
.00636 w
.66667 .5354 Mdot
.288 0 .712 r
.00864 w
.66667 .60332 Mdot
.078 0 .922 r
.00233 w
.69048 .01472 Mdot
.422 0 .578 r
.01267 w
.69048 .08263 Mdot
0 0 1 r
0 w
.69048 .10527 Mdot
.69048 .51276 Mdot
.422 0 .578 r
.01267 w
.69048 .5354 Mdot
.078 0 .922 r
.00233 w
.69048 .60332 Mdot
.012 0 .988 r
.00036 w
.71429 .01472 Mdot
.488 0 .512 r
.01464 w
.71429 .08263 Mdot
.71429 .5354 Mdot
.012 0 .988 r
.00036 w
.71429 .60332 Mdot
.002 0 .998 r
5e-05 w
.7381 .01472 Mdot
.498 0 .502 r
.01495 w
.7381 .08263 Mdot
.7381 .5354 Mdot
.002 0 .998 r
5e-05 w
.7381 .60332 Mdot
0 0 1 r
1e-05 w
.7619 .01472 Mdot
.5 0 .5 r
.01499 w
.7619 .08263 Mdot
.7619 .5354 Mdot
0 0 1 r
1e-05 w
.7619 .60332 Mdot
0 w
.78571 .01472 Mdot
.5 0 .5 r
.015 w
.78571 .08263 Mdot
.78571 .5354 Mdot
0 0 1 r
0 w
.78571 .60332 Mdot
0 w
.80952 .01472 Mdot
.5 0 .5 r
.015 w
.80952 .08263 Mdot
.80952 .5354 Mdot
0 0 1 r
0 w
.80952 .60332 Mdot
0 w
.83333 .01472 Mdot
.5 0 .5 r
.015 w
.83333 .08263 Mdot
.83333 .5354 Mdot
0 0 1 r
0 w
.83333 .60332 Mdot
0 w
.85714 .01472 Mdot
.5 0 .5 r
.015 w
.85714 .08263 Mdot
.85714 .5354 Mdot
0 0 1 r
0 w
.85714 .60332 Mdot
0 w
.88095 .01472 Mdot
.5 0 .5 r
.015 w
.88095 .08263 Mdot
.88095 .5354 Mdot
0 0 1 r
0 w
.88095 .60332 Mdot
0 w
.90476 .01472 Mdot
.5 0 .5 r
.015 w
.90476 .08263 Mdot
.90476 .5354 Mdot
0 0 1 r
0 w
.90476 .60332 Mdot
0 w
.92857 .01472 Mdot
.5 0 .5 r
.015 w
.92857 .08263 Mdot
.92857 .5354 Mdot
0 0 1 r
0 w
.92857 .60332 Mdot
.5 0 .5 r
.015 w
.95238 .08263 Mdot
.95238 .5354 Mdot
.015 w
.97619 .08263 Mdot
.97619 .5354 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 1.19048 0.309017 0.577063 [
[.02381 -0.0125 -12 -9 ]
[.02381 -0.0125 12 0 ]
[.2619 -0.0125 -12 -9 ]
[.2619 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .07819 -24 -4.5 ]
[-0.0125 .07819 0 4.5 ]
[-0.0125 .1936 -24 -4.5 ]
[-0.0125 .1936 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .42443 -18 -4.5 ]
[-0.0125 .42443 0 4.5 ]
[-0.0125 .53984 -18 -4.5 ]
[-0.0125 .53984 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-0.4)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-0.2)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(0.2)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(0.4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.08333 0 m
.08333 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.20238 0 m
.20238 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.44048 0 m
.44048 .00375 L
s
.55952 0 m
.55952 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.67857 0 m
.67857 .00375 L
s
.79762 0 m
.79762 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .07819 m
.00625 .07819 L
s
[(-0.4)] -0.0125 .07819 1 0 Mshowa
0 .1936 m
.00625 .1936 L
s
[(-0.2)] -0.0125 .1936 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .42443 m
.00625 .42443 L
s
[(0.2)] -0.0125 .42443 1 0 Mshowa
0 .53984 m
.00625 .53984 L
s
[(0.4)] -0.0125 .53984 1 0 Mshowa
.125 Mabswid
0 .10705 m
.00375 .10705 L
s
0 .1359 m
.00375 .1359 L
s
0 .16475 m
.00375 .16475 L
s
0 .22246 m
.00375 .22246 L
s
0 .25131 m
.00375 .25131 L
s
0 .28016 m
.00375 .28016 L
s
0 .33787 m
.00375 .33787 L
s
0 .36672 m
.00375 .36672 L
s
0 .39558 m
.00375 .39558 L
s
0 .45328 m
.00375 .45328 L
s
0 .48214 m
.00375 .48214 L
s
0 .51099 m
.00375 .51099 L
s
0 .04934 m
.00375 .04934 L
s
0 .02049 m
.00375 .02049 L
s
0 .5687 m
.00375 .5687 L
s
0 .59755 m
.00375 .59755 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.08333 .61428 m
.08333 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.20238 .61428 m
.20238 .61803 L
s
.32143 .61428 m
.32143 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.44048 .61428 m
.44048 .61803 L
s
.55952 .61428 m
.55952 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.67857 .61428 m
.67857 .61803 L
s
.79762 .61428 m
.79762 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.91667 .61428 m
.91667 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .07819 m
1 .07819 L
s
.99375 .1936 m
1 .1936 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .42443 m
1 .42443 L
s
.99375 .53984 m
1 .53984 L
s
.125 Mabswid
.99625 .10705 m
1 .10705 L
s
.99625 .1359 m
1 .1359 L
s
.99625 .16475 m
1 .16475 L
s
.99625 .22246 m
1 .22246 L
s
.99625 .25131 m
1 .25131 L
s
.99625 .28016 m
1 .28016 L
s
.99625 .33787 m
1 .33787 L
s
.99625 .36672 m
1 .36672 L
s
.99625 .39558 m
1 .39558 L
s
.99625 .45328 m
1 .45328 L
s
.99625 .48214 m
1 .48214 L
s
.99625 .51099 m
1 .51099 L
s
.99625 .04934 m
1 .04934 L
s
.99625 .02049 m
1 .02049 L
s
.99625 .5687 m
1 .5687 L
s
.99625 .59755 m
1 .59755 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.75 0 .25 r
.0225 w
.02381 .04934 Mdot
.25 0 .75 r
.0075 w
.02381 .16475 Mdot
.75 0 .25 r
.0225 w
.04762 .06088 Mdot
.25 0 .75 r
.0075 w
.04762 .17629 Mdot
0 0 1 r
0 w
.07143 .01472 Mdot
.75 0 .25 r
.0225 w
.07143 .07242 Mdot
.25 0 .75 r
.0075 w
.07143 .18783 Mdot
0 0 1 r
0 w
.09524 .02626 Mdot
.75 0 .25 r
.0225 w
.09524 .08396 Mdot
.25 0 .75 r
.0075 w
.09524 .19938 Mdot
0 0 1 r
0 w
.11905 .0378 Mdot
.75 0 .25 r
.0225 w
.11905 .0955 Mdot
.25 0 .75 r
.0075 w
.11905 .21092 Mdot
0 0 1 r
0 w
.14286 .04934 Mdot
.75 0 .25 r
.0225 w
.14286 .10705 Mdot
.25 0 .75 r
.0075 w
.14286 .22246 Mdot
0 0 1 r
0 w
.16667 .06088 Mdot
.75 0 .25 r
.0225 w
.16667 .11859 Mdot
.25 0 .75 r
.0075 w
.16667 .234 Mdot
0 0 1 r
0 w
.19048 .07242 Mdot
.75 0 .25 r
.0225 w
.19048 .13013 Mdot
.25 0 .75 r
.0075 w
.19048 .24554 Mdot
0 0 1 r
0 w
.21429 .08396 Mdot
.75 0 .25 r
.0225 w
.21429 .14167 Mdot
.25 0 .75 r
.0075 w
.21429 .25708 Mdot
0 0 1 r
1e-05 w
.2381 .0955 Mdot
.75 0 .25 r
.02249 w
.2381 .15321 Mdot
.25 0 .75 r
.0075 w
.2381 .26862 Mdot
.002 0 .998 r
5e-05 w
.2619 .10705 Mdot
.747 0 .253 r
.02242 w
.2619 .16475 Mdot
.251 0 .749 r
.00753 w
.2619 .28016 Mdot
.012 0 .988 r
.00036 w
.28571 .11859 Mdot
.732 0 .268 r
.02195 w
.28571 .17629 Mdot
.256 0 .744 r
.00768 w
.28571 .29171 Mdot
.078 0 .922 r
.00233 w
.30952 .13013 Mdot
.633 0 .367 r
.019 w
.30952 .18783 Mdot
0 0 1 r
0 w
.30952 .24554 Mdot
.289 0 .711 r
.00867 w
.30952 .30325 Mdot
.288 0 .712 r
.00864 w
.33333 .14167 Mdot
.318 0 .682 r
.00954 w
.33333 .19938 Mdot
0 0 1 r
0 w
.33333 .25708 Mdot
.394 0 .606 r
.01182 w
.33333 .31479 Mdot
.455 0 .545 r
.01364 w
.35714 .15321 Mdot
.068 0 .932 r
.00204 w
.35714 .21092 Mdot
0 0 1 r
0 w
.35714 .26862 Mdot
.477 0 .523 r
.01432 w
.35714 .32633 Mdot
.493 0 .507 r
.0148 w
.38095 .16475 Mdot
.01 0 .99 r
.0003 w
.38095 .22246 Mdot
0 0 1 r
0 w
.38095 .28016 Mdot
0 w
.38095 .28016 Mdot
.497 0 .503 r
.0149 w
.38095 .33787 Mdot
.499 0 .501 r
.01497 w
.40476 .17629 Mdot
.001 0 .999 r
4e-05 w
.40476 .234 Mdot
0 0 1 r
0 w
.40476 .29171 Mdot
0 w
.40476 .29171 Mdot
.5 0 .5 r
.01499 w
.40476 .34941 Mdot
.015 w
.42857 .18783 Mdot
0 0 1 r
1e-05 w
.42857 .24554 Mdot
0 w
.42857 .30325 Mdot
0 w
.42857 .30325 Mdot
.5 0 .5 r
.015 w
.42857 .36095 Mdot
.015 w
.45238 .19938 Mdot
0 0 1 r
0 w
.45238 .25708 Mdot
0 w
.45238 .31479 Mdot
0 w
.45238 .31479 Mdot
.5 0 .5 r
.015 w
.45238 .37249 Mdot
.015 w
.47619 .21092 Mdot
0 0 1 r
0 w
.47619 .26862 Mdot
0 w
.47619 .32633 Mdot
0 w
.47619 .32633 Mdot
.5 0 .5 r
.015 w
.47619 .38404 Mdot
.015 w
.5 .22246 Mdot
0 0 1 r
0 w
.5 .28016 Mdot
0 w
.5 .28016 Mdot
.5 .33787 Mdot
0 w
.5 .33787 Mdot
.5 0 .5 r
.015 w
.5 .39558 Mdot
.015 w
.52381 .234 Mdot
0 0 1 r
0 w
.52381 .29171 Mdot
0 w
.52381 .29171 Mdot
0 w
.52381 .34941 Mdot
.5 0 .5 r
.015 w
.52381 .40712 Mdot
.015 w
.54762 .24554 Mdot
0 0 1 r
0 w
.54762 .30325 Mdot
0 w
.54762 .30325 Mdot
0 w
.54762 .36095 Mdot
.5 0 .5 r
.015 w
.54762 .41866 Mdot
.015 w
.57143 .25708 Mdot
0 0 1 r
0 w
.57143 .31479 Mdot
0 w
.57143 .31479 Mdot
1e-05 w
.57143 .37249 Mdot
.5 0 .5 r
.015 w
.57143 .4302 Mdot
.01499 w
.59524 .26862 Mdot
0 0 1 r
0 w
.59524 .32633 Mdot
0 w
.59524 .32633 Mdot
.001 0 .999 r
4e-05 w
.59524 .38404 Mdot
.499 0 .501 r
.01497 w
.59524 .44174 Mdot
.497 0 .503 r
.0149 w
.61905 .28016 Mdot
0 0 1 r
0 w
.61905 .33787 Mdot
0 w
.61905 .33787 Mdot
.01 0 .99 r
.0003 w
.61905 .39558 Mdot
.493 0 .507 r
.0148 w
.61905 .45328 Mdot
.477 0 .523 r
.01432 w
.64286 .29171 Mdot
0 0 1 r
0 w
.64286 .34941 Mdot
.068 0 .932 r
.00204 w
.64286 .40712 Mdot
.455 0 .545 r
.01364 w
.64286 .46482 Mdot
.394 0 .606 r
.01182 w
.66667 .30325 Mdot
0 0 1 r
0 w
.66667 .36095 Mdot
.318 0 .682 r
.00954 w
.66667 .41866 Mdot
.288 0 .712 r
.00864 w
.66667 .47637 Mdot
.289 0 .711 r
.00867 w
.69048 .31479 Mdot
0 0 1 r
0 w
.69048 .37249 Mdot
.633 0 .367 r
.019 w
.69048 .4302 Mdot
.078 0 .922 r
.00233 w
.69048 .48791 Mdot
.256 0 .744 r
.00768 w
.71429 .32633 Mdot
.732 0 .268 r
.02195 w
.71429 .44174 Mdot
.012 0 .988 r
.00036 w
.71429 .49945 Mdot
.251 0 .749 r
.00753 w
.7381 .33787 Mdot
.747 0 .253 r
.02242 w
.7381 .45328 Mdot
.002 0 .998 r
5e-05 w
.7381 .51099 Mdot
.25 0 .75 r
.0075 w
.7619 .34941 Mdot
.75 0 .25 r
.02249 w
.7619 .46482 Mdot
0 0 1 r
1e-05 w
.7619 .52253 Mdot
.25 0 .75 r
.0075 w
.78571 .36095 Mdot
.75 0 .25 r
.0225 w
.78571 .47637 Mdot
0 0 1 r
0 w
.78571 .53407 Mdot
.25 0 .75 r
.0075 w
.80952 .37249 Mdot
.75 0 .25 r
.0225 w
.80952 .48791 Mdot
0 0 1 r
0 w
.80952 .54561 Mdot
.25 0 .75 r
.0075 w
.83333 .38404 Mdot
.75 0 .25 r
.0225 w
.83333 .49945 Mdot
0 0 1 r
0 w
.83333 .55715 Mdot
.25 0 .75 r
.0075 w
.85714 .39558 Mdot
.75 0 .25 r
.0225 w
.85714 .51099 Mdot
0 0 1 r
0 w
.85714 .5687 Mdot
.25 0 .75 r
.0075 w
.88095 .40712 Mdot
.75 0 .25 r
.0225 w
.88095 .52253 Mdot
0 0 1 r
0 w
.88095 .58024 Mdot
.25 0 .75 r
.0075 w
.90476 .41866 Mdot
.75 0 .25 r
.0225 w
.90476 .53407 Mdot
0 0 1 r
0 w
.90476 .59178 Mdot
.25 0 .75 r
.0075 w
.92857 .4302 Mdot
.75 0 .25 r
.0225 w
.92857 .54561 Mdot
0 0 1 r
0 w
.92857 .60332 Mdot
.25 0 .75 r
.0075 w
.95238 .44174 Mdot
.75 0 .25 r
.0225 w
.95238 .55715 Mdot
.25 0 .75 r
.0075 w
.97619 .45328 Mdot
.75 0 .25 r
.0225 w
.97619 .5687 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{864, 254.25},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=P0000oR000`400?l00000o`00003oo`3ooooo
0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00
o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS
0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0oooo
o`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool003H0oooo0P0000040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0AP3oool2000000@0oooo00<000000?ooo`3oool00P3oool4
000004X0oooo0P00001>0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`@00000A`3oool2
000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`190?ooo`800000103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo04H0oooo0P0000040?ooo`030000003oool0
oooo0080oooo1000001:0?ooo`800000CP3oool2000000@0oooo00<000000?ooo`3oool00P3oool4
000004L0oooo0P0000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05`3oool0
03D0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`150?ooo`040000003oool0
oooo000000P0oooo00<000000?ooo`3oool0BP3oool010000000oooo0?ooo`00001<0?ooo`040000
003oool0oooo000000P0oooo00<000000?ooo`3oool0A`3oool010000000oooo0?ooo`00000:0?oo
o`030000003oool0oooo04P0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`15
0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0BP3oool010000000oooo0?oo
o`00001<0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0A`3oool010000000
oooo0?ooo`00000:0?ooo`030000003oool0oooo01L0oooo000e0?ooo`040000003oool0oooo0000
00L0oooo1@0000160?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0B@3oool0
10000000oooo0?ooo`00001<0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0
AP3oool010000000oooo0?ooo`0000070?ooo`D00000B@3oool010000000oooo0?ooo`0000070?oo
o`D00000AP3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo04T0oooo00@00000
0?ooo`3oool00000C03oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo04H0oooo
00@000000?ooo`3oool000001`3oool5000001P0oooo000_0?ooo`@000000P3oool010000000oooo
0?ooo`0000070?ooo`040000003oool0oooo00000440oooo100000020?ooo`040000003oool0oooo
000000X0oooo00<000000?ooo`3oool0B03oool010000000oooo0?ooo`00001<0?ooo`040000003o
ool0oooo000000X0oooo00<000000?ooo`3oool0A@3oool010000000oooo0?ooo`0000070?ooo`04
0000003oool0oooo000004@0oooo100000020?ooo`040000003oool0oooo000000L0oooo00@00000
0?ooo`3oool00000@@3oool400000080oooo00@000000?ooo`3oool000002P3oool00`000000oooo
0?ooo`180?ooo`040000003oool0oooo000004`0oooo00@000000?ooo`3oool000002P3oool00`00
0000oooo0?ooo`150?ooo`040000003oool0oooo000000L0oooo00@000000?ooo`3oool000006@3o
ool003D0oooo00@000000?ooo`3oool00000203oool00`000000oooo000000170?ooo`040000003o
ool0oooo000000/0oooo00<000000?ooo`3oool0A`3oool010000000oooo0?ooo`00001<0?ooo`04
0000003oool0oooo000000/0oooo00<000000?ooo`3oool0A03oool010000000oooo0?ooo`000008
0?ooo`030000003oool0000004X0oooo00@000000?ooo`3oool00000203oool00`000000oooo0000
00170?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0A`3oool010000000oooo
0?ooo`00001<0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0A03oool01000
0000oooo0?ooo`0000080?ooo`030000003oool0000001T0oooo000e0?ooo`040000003oool0oooo
000000T0oooo0P0000170?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000
B@3oool010000000oooo0?ooo`00001<0?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool00000AP3oool010000000oooo0?ooo`0000090?ooo`800000BP3oool010000000oooo0?oo
o`0000090?ooo`800000A`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo0000
04T0oooo00@000000?ooo`3oool00000C03oool010000000oooo0?ooo`0000080?ooo`040000003o
ool0oooo000004H0oooo00@000000?ooo`3oool000002@3oool2000001T0oooo000f0?ooo`800000
2`3oool00`000000oooo0?ooo`160?ooo`8000002P3oool2000004/0oooo0P00001>0?ooo`800000
2P3oool2000004P0oooo0P00000;0?ooo`030000003oool0oooo04T0oooo0P00000;0?ooo`030000
003oool0oooo04H0oooo0P00000:0?ooo`800000B`3oool2000004h0oooo0P00000:0?ooo`800000
B03oool2000000/0oooo00<000000?ooo`3oool05`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o
0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0
oooo003o0?ooool0ooooo`3ooomS0?ooo`00<P3ooooo000006/00000@`3ooooo000006/000005`3o
ool00380oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0D`3oool00`00
0000oooo0?ooo`1C0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0D`3oool00`00
0000oooo0?ooo`1C0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0D`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo01D0oooo000b0?ooo`030000003oool0oooo08D0
oooo101n085B0?ooo`@0OP21Q`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0?l0
ooooI`3oool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo0?ooo`1e0?ooo`80B@2f
1P3oool307@0R`D0oooo101n08450?ooo`@0O`20103oool407l0O`D0oooo101o07l50?ooo`@0O`1o
103oool407l0O`D0oooo101o07l40?ooo`@0O`1o1@3oool407l0O`D0oooo101o08040?ooo`@0OP21
1@3oool307@0R`L0oooo0P190;If0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
o`3ooomW0?ooo`030000003oool0oooo01D0oooo000b0?ooo`800000603oool00`000?l0oooo0?oo
o`060?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?oo
o`050?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?oo
o`050?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`030?`0oooo0?oo
o`060?ooo`0301<0k03oool0oooo00D0oooo0P190;H50?ooo`@0M02;1@3oool407h0P@D0oooo101o
08040?ooo`@0O`1o1@3oool407l0O`D0oooo101o07l40?ooo`@0O`1o1@3oool407l0O`@0oooo101o
07l50?ooo`@0O`1o1@3oool407l0P0@0oooo101n08440?ooo`@0M02;1`3oool204T0]PH0oooo00<0
4`3/0?ooo`3oool01P3oool00`030?`0oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0
003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0
003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0
003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0E0?ooo`800000@`3oool00`000000oooo0?oo
o`0G0?ooo`030000o`3oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`0E0?ooo`00<P3oool0
0`000000oooo0?ooo`1m0?ooo`<0M02;1@3oool407h0P@D0oooo101o08040?ooo`@0O`1o1@3oool4
07l0O`D0oooo101o07l40?ooo`@0O`1o1@3oool407l0O`@0oooo101o07l50?ooo`@0O`1o1@3oool4
07l0P0@0oooo101n08450?ooo`<0M02;O`3oool00`000000oooo0?ooo`110?ooo`030000003oool0
oooo0?l0ooooI`3oool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo0?ooo`1n0?oo
o`0307@0R`3oool0oooo00d0oooo101o08040?ooo`@0O`1o1@3oool407l0O`D0oooo101o07l40?oo
o`@0O`1o1@3oool407l0O`@0oooo101o07l50?ooo`@0O`1o1@3oool407l0P0h0oooo00<0M02;0?oo
o`3oool0OP3oool00`000000oooo0?ooo`110?ooo`800000o`3ooomW0?ooo`8000005`3oool00380
oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3o
ool0o`3ooomW0?ooo`030000003oool0oooo01D0oooo000b0?ooo`030000003oool0oooo0?l0oooo
I`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0200oooo00<0003o0?ooo`3oool0
o`3ooom40?ooo`030000003oool0oooo01D0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3o
ool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?oo
o`0E0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool0
0`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool05@3oool001d0oooo0P0000040?oo
o`030000003oool0oooo00<0oooo0P0000070?ooo`030000003oool0oooo0?l0ooooI`3oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`0E0?oo
o`00703oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000H0oooo00<00000
0?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0:@3oool0
0`000?l0oooo0?ooo`3o0?oooc/0oooo00<000000?ooo`3oool05@3oool001`0oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`0000060?ooo`<00000o`3ooomU0?ooo`<00000@`3o
ool00`000000oooo0?ooo`040?ooo`D0_`0oo`3ooomN0?ooo`030000003oool0oooo01D0oooo000F
0?ooo`@000000P3oool010000000oooo0?ooo`0000080?ooo`<000001`3oool00`000000oooo0?oo
o`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`030?ooo`L0_`0oo`3o
oomM0?ooo`030000003oool0oooo01D0oooo000L0?ooo`040000003oool0oooo000000P0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0@@3o
ool00`000000oooo0?ooo`030?ooo`L0_`0oo`3ooomM0?ooo`030000003oool0oooo01D0oooo000L
0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`020?ooo`P0_`0o9`3o
ool00`000?l0oooo0?ooo`3o0?oooc<0oooo00<000000?ooo`3oool05@3oool001d0oooo0P00000:
0?ooo`<000001P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool2
000000@0oooo1`2o03oo0?oooe`0oooo0P00000G0?ooo`00<P3oool00`000000oooo0?ooo`3o0?oo
ofL0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`030?ooo`L0_`0o0`3oool50;l0
?ol0ooooE@3oool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0
oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`040?ooo`D0_`0o0`3oool70;l0?ol0
ooooE03oool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`060?ooo`030;l0?`3oool0oooo00<0oooo
1`2o03oo0?oooe@0oooo00<000000?ooo`3oool05@3oool00380oooo0P00003o0?ooofL0oooo0P00
00130?ooo`030000003oool0oooo00/0oooo202o03lW0?ooo`030000o`3oool0oooo0?l0oooo:P3o
ool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<00000
0?ooo`3oool0@@3oool00`000000oooo0?ooo`0<0?ooo`L0_`0o0P3oool50;l0?ol0ooooC@3oool0
0`000000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?oo
o`3oool0@@3oool00`000000oooo0?ooo`0<0?ooo`L0_`0o00<0oooo0;l0?`2o03l01@2o03oo0?oo
od`0oooo00<000000?ooo`3oool05@3oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`03
0000003oool0oooo0440oooo00<000000?ooo`3oool03@3oool50;l0?`80oooo1`2o03oo0?oood`0
oooo00<000000?ooo`3oool05@3oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000
003oool0oooo02d0oooo0P0000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0?0?ooo`040;l0?`3oool0oooo0?ooo`P0_`0o9`3oool00`000?l0
oooo0?ooo`3o0?ooob80oooo00<000000?ooo`3oool05@3oool00380oooo00<000000?ooo`3oool0
o`3ooomW0?ooo`030000003oool0oooo02`0oooo00@000000?ooo`3oool000002P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo01@0oooo1`2o03l30?ooo`D0_`0oo`3ooom40?ooo`03
0000003oool0oooo01D0oooo000b0?ooo`030000003oool0oooo00@0oooo101o07l50?ooo`@0O`1o
103oool407l0O`D0oooo101o07l50?ooo`@0O`1o103oool407l0O`D0oooo101o07l40?ooo`@0O`1o
1@3oool407l0O`D0oooo101o07l40?ooo`@0O`201@3oool407`0PiL0oooo101l08<40?ooo`@0O`20
1@3oool407l0O`@0oooo101o07l50?ooo`@0O`1o1@3oool407l0O`@0oooo101o07l50?ooo`@0O`1o
103oool407l0O`D0oooo101o07l50?ooo`@0O`1o103oool407l0O`H0oooo00<000000?ooo`3oool0
;03oool010000000oooo0?ooo`0000070?ooo`D000001@3oool3000001@0oooo1`2o03l20?ooo`L0
_`0oo`3ooom10?ooo`<000005`3oool00380oooo00<000000?ooo`3oool0103oool407l0O`D0oooo
101o07l40?ooo`@0O`1o1@3oool407l0O`D0oooo101o07l40?ooo`@0O`1o1@3oool407l0O`@0oooo
101o07l50?ooo`@0O`1o1@3oool407l0O`@0oooo101o08050?ooo`@0O0231@3oool306`0T`H0oooo
0P0f0<T@0?ooo`030040oP3oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo
0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo
0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo
0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<00@3n0?ooo`3oool03@3oool203H0b@H0oooo
0`1/09<60?ooo`@0O023103oool407l0P0D0oooo101o07l40?ooo`@0O`1o1@3oool407l0O`D0oooo
101o07l40?ooo`@0O`1o1@3oool407l0O`@0oooo101o07l50?ooo`@0O`1o1@3oool407l0O`@0oooo
101o07l60?ooo`030000003oool0oooo02H0oooo100000020?ooo`040000003oool0oooo000000L0
oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`0E0?ooo`D0_`0o0`3oool70;l0
?ol0oooo@`3oool00`000000oooo0?ooo`0E0?ooo`00<P3oool2000000D0oooo101o07l50?ooo`@0
O`1o103oool407l0O`D0oooo101o07l50?ooo`@0O`1o103oool407l0O`D0oooo101o07l40?ooo`@0
O`1o1@3oool407l0O`D0oooo101o07l40?ooo`@0O`201@3oool407`0P`@0oooo101/09<70?ooo`03
03H0b@3oool0oooo00D0oooo00<02`3d0?ooo`3oool0I03oool00`0;0?@0oooo0?ooo`060?ooo`03
03H0b@3oool0oooo00<0oooo101/09<60?ooo`@0O023103oool407l0P0D0oooo101o07l40?ooo`@0
O`1o1@3oool407l0O`D0oooo101o07l40?ooo`@0O`1o1@3oool407l0O`@0oooo101o07l50?ooo`@0
O`1o1@3oool407l0O`@0oooo101o07l50?ooo`800000;P3oool010000000oooo0?ooo`0000080?oo
o`030000003oool0000000H0oooo00<000000?ooo`3oool05`3oool00`2o03l0oooo0?ooo`020?oo
o`P0_`0o9`3oool00`000?l0oooo0?ooo`3o0?oooaT0oooo00<000000?ooo`3oool05@3oool00380
oooo00<000000?ooo`3oool0103oool407l0O`D0oooo101o07l40?ooo`@0O`1o1@3oool407l0O`D0
oooo101o07l40?ooo`@0O`1o1@3oool407l0O`@0oooo101o07l50?ooo`@0O`1o1@3oool407l0O`@0
oooo101o08050?ooo`@0O0231@3oool306`0ThH0oooo0`1/09<60?ooo`@0O023103oool407l0P0D0
oooo101o07l40?ooo`@0O`1o1@3oool407l0O`D0oooo101o07l40?ooo`@0O`1o1@3oool407l0O`@0
oooo101o07l50?ooo`@0O`1o1@3oool407l0O`@0oooo101o07l60?ooo`030000003oool0oooo02`0
oooo00@000000?ooo`3oool000002@3oool2000000H0oooo00<000000?ooo`3oool07@3oool70;l0
?`80oooo1@2o03oo0?oooc`0oooo00<000000?ooo`3oool05@3oool00380oooo00<000000?ooo`3o
ool0K@3oool00`1/09<0oooo0?ooo`260?ooo`0306`0T`3oool0oooo06d0oooo00<000000?ooo`3o
ool0;@3oool2000000/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0M0?ooo`L0
_`0o00<0oooo0;l0?`2o03l01@2o03oo0?oooc/0oooo00<000000?ooo`3oool05@3oool00380oooo
00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
7P3oool50;l0?`80oooo1`2o03oo0?oooc/0oooo00<000000?ooo`3oool05@3oool00380oooo00<0
00000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0803o
ool0102o03l0oooo0?ooo`3oool80;l0?bP0oooo00<0003o0?ooo`3oool0o`3oool@0?ooo`030000
003oool0oooo01D0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?oo
o`110?ooo`030000003oool0oooo02D0oooo1`2o03l30?ooo`D0_`0oo`3ooolc0?ooo`030000003o
ool0oooo01D0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`11
0?ooo`030000003oool0oooo02D0oooo1`2o03l20?ooo`L0_`0oo`3ooolb0?ooo`030000003oool0
oooo01D0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo02H0oooo1@2o03l30?ooo`L0_`0oo`3ooolb0?ooo`030000003oool0oooo
01D0oooo000b0?ooo`800000KP3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00D0
oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00H0
oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00H0
oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00H0
oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00D0
oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo06/0
oooo0P0000130?ooo`030000003oool0oooo02P0oooo00<0_`0o0?ooo`3oool00P3oool80;l0?bL0
oooo00<0003o0?ooo`3oool0o`3oool80?ooo`030000003oool0oooo01D0oooo000b0?ooo`030000
003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`110?ooo`800000;`3oool70;l0?`<0oooo
1@2o03oo0?ooobT0oooo0P00000G0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<0
00000?ooo`3oool0@@3oool00`000000oooo0?ooo`0^0?ooo`L0_`0o0P3oool70;l0?ol0oooo:@3o
ool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<00000
0?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`D0_`0o0`3oool70;l0?ol0oooo:@3oool0
0`000000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?oo
o`3oool0@@3oool00`000000oooo0?ooo`0a0?ooo`030;l0?`3oool0oooo0080oooo202o03lW0?oo
o`0300<0o03oool0oooo0?h0oooo00<000000?ooo`3oool05@3oool00380oooo00<000000?ooo`3o
ool0o`3ooomW0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0=`3oool70;l0?ol0
oooo:@3oool00`000000oooo0?ooo`0E0?ooo`007@3oool2000000@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo
0?ooo`110?ooo`030000003oool0oooo03L0oooo1`2o03l20?ooo`D0_`0oo`3ooolR0?ooo`030000
003oool0oooo01D0oooo000L0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool00`000000oooo
0?ooo`0h0?ooo`D0_`0o0P3oool70;l0?ol0oooo8@3oool00`000000oooo0?ooo`0E0?ooo`00703o
ool010000000oooo0?ooo`0000070?ooo`D000001P3oool300000?l0ooooI@3oool3000004<0oooo
00<000000?ooo`3oool0>P3oool00`2o03l0oooo0?ooo`020?ooo`L0_`0oo`3ooolQ0?ooo`030000
003oool0oooo01D0oooo000F0?ooo`@000000P3oool010000000oooo0?ooo`0000070?ooo`040000
003oool0oooo000000L0oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo0440
oooo00<000000?ooo`3oool0?P3oool80;l0?bL0oooo00<04`3/0?ooo`3oool0mP3oool00`000000
oooo0?ooo`0E0?ooo`00703oool010000000oooo0?ooo`0000080?ooo`030000003oool0000000L0
oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3o
ool0?`3oool70;l0?`<0oooo1@2o03oo0?oooaT0oooo00<000000?ooo`3oool05@3oool001`0oooo
00@000000?ooo`3oool000002@3oool2000000L0oooo00<000000?ooo`3oool0o`3ooomW0?ooo`03
0000003oool0oooo0440oooo0P0000100?ooo`L0_`0o0P3oool70;l0?ol0oooo5`3oool2000001L0
oooo000M0?ooo`8000002`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo
I`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0400oooo1@2o03l30?ooo`L0_`0o
9P3oool204T0]^l0oooo00<000000?ooo`3oool05@3oool00380oooo00<000000?ooo`3oool0o`3o
oomW0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0@P3oool00`2o03l0oooo0?oo
o`020?ooo`P0_`0o9P3oool204T0]^l0oooo00<000000?ooo`3oool05@3oool00380oooo00<00000
0?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0B03oool7
0;l0?`80oooo1@2o03oo0?oooa40oooo00<000000?ooo`3oool05@3oool00380oooo00<000000?oo
o`3oool0o`3ooomW0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0B03oool70;l0
?`030?ooo`2o03l0_`0o00D0_`0oo`3oool@0?ooo`030000003oool0oooo01D0oooo000b0?ooo`80
0000o`3ooomW0?ooo`800000@`3oool00`000000oooo0?ooo`190?ooo`D0_`0o0P3oool70;l0?bH0
oooo0`1d08_V0?ooo`030000003oool0oooo01D0oooo000b0?ooo`030000003oool0oooo0?l0oooo
I`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo04/0oooo00@0_`0o0?ooo`3oool0
oooo202o03lU0?ooo`@0M02;iP3oool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo
0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`1@0?ooo`L0_`0o
0`3oool50;l0@1h0oooo0`1d08_V0?ooo`030000003oool0oooo01D0oooo000b0?ooo`030000003o
ool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0500oooo1`2o
03l20?ooo`L0_`107P3oool00`1d08/0oooo0?ooo`3U0?ooo`030000003oool0oooo01D0oooo000b
0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`110?ooo`030000003oool0
oooo0540oooo1@2o03l30?ooo`L0_`109P3oool407h0PM`0oooo00<000000?ooo`3oool05@3oool0
0380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo0440oooo00<000000?oo
o`3oool01@3oool203l0_d`0oooo00<0_`0o0?ooo`3oool00P3oool80;l0@2H0oooo101n087L0?oo
o`030000003oool0oooo01D0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000
oooo0?ooo`110?ooo`8000001`3oool00`0o0;l0oooo0?ooo`1@0?ooo`L0_`109P3oool407h0PM/0
oooo0P00000G0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0
@@3oool00`000000oooo0?ooo`1I0?ooo`L0_`100`3oool40;/0A1l0oooo101n087L0?ooo`030000
003oool0oooo01D0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?oo
o`110?ooo`030000003oool0oooo05X0oooo1@2o04030?ooo`H0^`149P3oool407l0P=@0oooo00<0
00000?ooo`3oool05@3oool00380oooo0P00003o0?ooofL0oooo0P0000130?ooo`030000003oool0
oooo05`0oooo00<0_`100?ooo`3oool00`3oool60;/0A2H0oooo101o083D0?ooo`030000003oool0
oooo01D0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo00d0oooo0P0o0;mC0?ooo`H0^`149P3oool407l0P=@0oooo00<000000?oo
o`3oool05@3oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo0440
oooo00<000000?ooo`3oool03P3oool00`0o0;l0oooo0?ooo`1A0?ooo`H0^`149P3oool407l0P=@0
oooo00<000000?ooo`3oool05@3oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000
003oool0oooo0440oooo00<000000?ooo`3oool0H`3oool40;/0A0@0oooo1@2R05dW0?ooo`@0O`1o
b`3oool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<0
00000?ooo`3oool0@@3oool00`000000oooo0?ooo`1[0?ooo`D0XP1M9`3oool407l0Ol/0oooo00<0
00000?ooo`3oool05@3oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0
oooo02d0oooo0P0000040?ooo`030000003oool0oooo0080oooo100000050?ooo`030000003oool0
oooo01H0oooo0P0o0;mB0?ooo`H0XP1M9`3oool407l0Ol/0oooo00<000000?ooo`3oool05@3oool0
0380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo02`0oooo00@000000?oo
o`3oool00000203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01L0oooo00<0?`2o
0?ooo`3oool0D@3oool50:80GBL0oooo101o07o;0?ooo`030000003oool0oooo01D0oooo000b0?oo
o`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`0/0?ooo`040000003oool0oooo
000000T0oooo00<000000?ooo`3oool01@3oool3000006/0oooo1@2R05d_0?ooo`@0O`1o`@3oool3
000001L0oooo000b0?ooo`800000o`3ooomW0?ooo`800000:03oool400000080oooo00@000000?oo
o`3oool000002P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo06d0oooo00<0XP1M
0?ooo`3oool01@3oool20540[RP0oooo101o07o30?ooo`030000003oool0oooo01D0oooo000b0?oo
o`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`0/0?ooo`040000003oool0oooo
000000/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0O0?ooo`80?`2oE03oool2
0540[RP0oooo101o07o30?ooo`030000003oool0oooo01D0oooo000b0?ooo`030000003oool0oooo
0?l0ooooI`3oool00`000000oooo0?ooo`0/0?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000001@3oool00`000000oooo0?ooo`0P0?ooo`0303l0_`3oool0oooo07`0oooo101o
07o30?ooo`030000003oool0oooo01D0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool0
0`000000oooo0?ooo`0]0?ooo`8000002P3oool2000000H0oooo00<000000?ooo`3oool0Z03oool4
07l0OkX0oooo00<000000?ooo`3oool05@3oool00380oooo00<000000?ooo`3oool0o`3ooomW0?oo
o`030000003oool0oooo0440oooo00<000000?ooo`3oool0Z03oool407l0OkX0oooo00<000000?oo
o`3oool05@3oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo0440
oooo00<000000?ooo`3oool09`3oool203l0_eD0oooo00<04@3^0?ooo`3oool09`3oool407l0OkX0
oooo00<000000?ooo`3oool05@3oool001d0oooo0P0000040?ooo`030000003oool0oooo0080oooo
100000060?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`110?ooo`030000
003oool0oooo02P0oooo00<0?`2o0?ooo`3oool0O@3oool407l0OkX0oooo00<000000?ooo`3oool0
5@3oool001`0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0?l0oooo
I`3oool00`000000oooo0?ooo`0E0?ooo`00703oool010000000oooo0?ooo`0000090?ooo`030000
003oool0oooo00H0oooo0`00003o0?ooofD0oooo0`0000130?ooo`030000003oool0oooo0;00oooo
101o07nb0?ooo`030000003oool0oooo01D0oooo000F0?ooo`@000000P3oool010000000oooo0?oo
o`00000:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000
003oool0oooo0440oooo0P00000a0?ooo`80?`2oE@3oool00`020?d0oooo0?ooo`0V0?ooo`@0O`1o
/@3oool2000001L0oooo000L0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool00`000000oooo
0?ooo`0a0?ooo`0303l0_`3oool0oooo07`0oooo101o07nb0?ooo`030000003oool0oooo01D0oooo
000L0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000001P3oool00`000000
oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`2`0?ooo`@0
O`1o/P3oool00`000000oooo0?ooo`0E0?ooo`007@3oool2000000X0oooo0P0000070?ooo`030000
003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0;T0oooo
101o07nY0?ooo`030000003oool0oooo01D0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3o
ool00`000000oooo0?ooo`110?ooo`030000003oool0oooo03P0oooo0P0o0;mF0?ooo`030000o`3o
ool0oooo02H0oooo101o07nY0?ooo`030000003oool0oooo01D0oooo000b0?ooo`030000003oool0
oooo0?l0ooooI`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo03T0oooo00<0?`2o
0?ooo`3oool0O@3oool407l0OjT0oooo00<000000?ooo`3oool05@3oool00380oooo00<000000?oo
o`3oool0o`3ooomW0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0^@3oool407l0
OjT0oooo00<000000?ooo`3oool05@3oool00380oooo0P00003o0?ooofL0oooo0P0000130?ooo`03
0000003oool0oooo0<80oooo101o07nP0?ooo`030000003oool0oooo01D0oooo000b0?ooo`030000
003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo06d0oooo
00<0003o0?ooo`3oool0:03oool00`000?l0oooo0?ooo`0W0?ooo`@0O`1oX03oool00`000000oooo
0?ooo`0E0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0@@3o
ool00`000000oooo0?ooo`110?ooo`80?`2oO`3oool407l0Oj00oooo00<000000?ooo`3oool05@3o
ool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo0440oooo00<00000
0?ooo`3oool0@P3oool00`0o0;l0oooo0?ooo`1m0?ooo`@0O`1oX03oool00`000000oooo0?ooo`0E
0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool20000
0</0oooo101o07nG0?ooo`8000005`3oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`03
0000003oool0oooo0440oooo00<000000?ooo`3oool0MP3oool00`000?l0oooo0?ooo`0X0?ooo`03
0000o`3oool0oooo02H0oooo101o07nH0?ooo`030000003oool0oooo01D0oooo000b0?ooo`030000
003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo04X0oooo
0P0o0;mn0?ooo`@0O`1oV03oool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo0?oo
o`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`1;0?ooo`0303l0_`3o
ool0oooo07`0oooo101o07nH0?ooo`030000003oool0oooo01D0oooo000b0?ooo`800000o`3ooomW
0?ooo`800000@`3oool00`000000oooo0?ooo`3C0?ooo`@0O`1oS`3oool00`000000oooo0?ooo`0E
0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool00`00
0000oooo0?ooo`3C0?ooo`@0O`1oS`3oool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`000000
oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`1B0?ooo`80
?`2o:`3oool00`000?l0oooo0?ooo`0X0?ooo`030000o`3oool0oooo02H0oooo101o07n?0?ooo`03
0000003oool0oooo01D0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo
0?ooo`110?ooo`030000003oool0oooo05<0oooo00<0?`2o0?ooo`3oool0O@3oool407l0Ohl0oooo
00<000000?ooo`3oool05@3oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool0g03oool407l0P8H0oooo00<000000?ooo`3oool05@3o
ool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo0440oooo00<00000
0?ooo`3oool0g03oool407l0P8H0oooo00<000000?ooo`3oool05@3oool00380oooo00<000000?oo
o`3oool0o`3ooomW0?ooo`030000003oool0oooo0440oooo0P00001L0?ooo`80@02o:P3oool00`00
0?l0oooo0?ooo`0X0?ooo`030000o`3oool0oooo02L0oooo101o08250?ooo`8000005`3oool00380
oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3o
ool0G03oool00`100;l0oooo0?ooo`1m0?ooo`@0O`20QP3oool00`000000oooo0?ooo`0E0?ooo`00
<P3oool200000?l0ooooI`3oool2000004<0oooo00<000000?ooo`3oool0i03oool407X0QGh0oooo
00<000000?ooo`3oool05@3oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool0i03oool407X0QGh0oooo00<000000?ooo`3oool05@3o
ool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo0440oooo00<00000
0?ooo`3oool0H`3oool20440_R/0oooo00<0003o0?ooo`3oool0:03oool00`000?l0oooo0?ooo`0V
0?ooo`@0NP25OP3oool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo0?ooo`3o0?oo
ofL0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`1T0?ooo`030440_P3oool0oooo
07d0oooo101j08En0?ooo`030000003oool0oooo01D0oooo000b0?ooo`030000003oool0oooo0?l0
ooooI`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000
oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0
@@3oool00`000000oooo0?ooo`3]0?ooo`<0I02KMP3oool00`000000oooo0?ooo`0E0?ooo`00<P3o
ool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?oo
o`1]0?ooo`80B@2f:@3oool00`000?l0oooo0?ooo`0X0?ooo`030000o`3oool0oooo02H0oooo101T
09]f0?ooo`030000003oool0oooo01D0oooo000Y0?ooo`8000001`3oool00`000000oooo0?ooo`3o
0?ooofL0oooo00<000000?ooo`3oool0>@3oool2000000H0oooo00<000000?ooo`3oool0K@3oool2
04T0]Wh0oooo0`1T09]f0?ooo`030000003oool0oooo01D0oooo000X0?ooo`040000003oool0oooo
000000H0oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo03P0oooo00@00000
0?ooo`3oool000001@3oool00`000000oooo0?ooo`3^0?ooo`0306@0V`3oool0oooo07D0oooo00<0
00000?ooo`3oool05@3oool002P0oooo00@000000?ooo`3oool000001P3oool300000?l0ooooI@3o
ool3000003X0oooo00@000000?ooo`3oool000001@3oool3000007D0oooo0`1T09_/0?ooo`<00000
5`3oool002P0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`3o0?ooofL0oooo
00<000000?ooo`3oool0>03oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo07@0
oooo101T09/Y0?ooo`030000o`3oool0oooo02P0oooo00<0003o0?ooo`3oool09`3oool204T0]Vh0
oooo00<000000?ooo`3oool05@3oool002P0oooo00@000000?ooo`3oool000001P3oool00`000000
oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0>03oool010000000oooo0?ooo`0000050?oo
o`030000003oool0oooo07D0oooo0`1T09]n0?ooo`80B@2fKP3oool00`000000oooo0?ooo`0E0?oo
o`00:03oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo0?l0ooooI`3oool00`00
0000oooo0?ooo`0h0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0MP3oool0
0`1T09/0oooo0?ooo`3]0?ooo`030000003oool0oooo01D0oooo000Y0?ooo`8000001`3oool00`00
0000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0>@3oool2000000H0oooo00<000000?oo
o`3oool0O@3oool407X0QND0oooo00<000000?ooo`3oool05@3oool00380oooo00<000000?ooo`3o
ool0o`3ooomW0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0O@3oool407X0QBT0
oooo00<0003o0?ooo`3oool0:03oool00`000?l0oooo0?ooo`2>0?ooo`030000003oool0oooo01D0
oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`110?ooo`030000
003oool0oooo07d0oooo101j08Em0?ooo`80@@2nIP3oool00`000000oooo0?ooo`0E0?ooo`00<P3o
ool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?oo
o`1m0?ooo`@0NP25OP3oool00`110;h0oooo0?ooo`1T0?ooo`030000003oool0oooo01D0oooo000b
0?ooo`800000o`3ooomW0?ooo`800000@`3oool00`000000oooo0?ooo`250?ooo`@0O`20g@3oool0
0`000000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?oo
o`3oool0@@3oool00`000000oooo0?ooo`250?ooo`@0O`20g@3oool00`000000oooo0?ooo`0E0?oo
o`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool2000008H0
oooo101o080Y0?ooo`030000o`3oool0oooo02P0oooo00<0003o0?ooo`3oool09`3oool20400_e`0
oooo0P00000G0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0
@@3oool00`000000oooo0?ooo`250?ooo`@0O`20O`3oool00`100;l0oooo0?ooo`1K0?ooo`030000
003oool0oooo01D0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?oo
o`110?ooo`030000003oool0oooo08h0oooo101o07oD0?ooo`030000003oool0oooo01D0oooo000b
0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`110?ooo`030000003oool0
oooo08h0oooo101o07oD0?ooo`030000003oool0oooo01D0oooo000b0?ooo`030000003oool0oooo
0?l0ooooI`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo08h0oooo101o07lY0?oo
o`030000o`3oool0oooo02P0oooo00<0003o0?ooo`3oool09`3oool203l0_e@0oooo00<000000?oo
o`3oool05@3oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo0440
oooo00<000000?ooo`3oool0SP3oool407l0Ogl0oooo00<0?`2o0?ooo`3oool0DP3oool00`000000
oooo0?ooo`0E0?ooo`00<P3oool200000?l0ooooI`3oool2000004<0oooo00<000000?ooo`3oool0
o`3ooomW0?ooo`030000003oool0oooo01D0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3o
ool00`000000oooo0?ooo`110?ooo`030000003oool0oooo09L0oooo101o07o;0?ooo`030000003o
ool0oooo01D0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`11
0?ooo`030000003oool0oooo09L0oooo101o07lX0?ooo`030000o`3oool0oooo02P0oooo00<0003o
0?ooo`3oool09`3oool203l0_d`0oooo00<000000?ooo`3oool05@3oool00380oooo00<000000?oo
o`3oool0o`3ooomW0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0U`3oool407l0
Ogh0oooo00<0?`2o0?ooo`3oool0BP3oool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`000000
oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`2G0?ooo`@0
O`1ob`3oool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo
00<000000?ooo`3oool0@@3oool200000:00oooo101o07o20?ooo`8000005`3oool00380oooo00<0
00000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0W`3o
ool407l0ObT0oooo00<0003o0?ooo`3oool0:03oool00`000?l0oooo0?ooo`0W0?ooo`80?`2o@`3o
ool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<00000
0?ooo`3oool0@@3oool00`000000oooo0?ooo`2O0?ooo`@0O`1oO`3oool00`0o0;l0oooo0?ooo`11
0?ooo`030000003oool0oooo01D0oooo000b0?ooo`800000o`3ooomW0?ooo`800000@`3oool00`00
0000oooo0?ooo`2O0?ooo`@0O`1o``3oool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`000000
oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`2X0?ooo`@0
O`1o^P3oool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`2X0?ooo`@0O`1o:@3oool00`000?l0oooo
0?ooo`2>0?ooo`030000003oool0oooo01D0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3o
ool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0:P0oooo101o07mm0?ooo`80?`2o>`3o
ool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<00000
0?ooo`3oool0@@3oool00`000000oooo0?ooo`2X0?ooo`@0O`1oOP3oool00`0o0;l0oooo0?ooo`0i
0?ooo`030000003oool0oooo01D0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo0;00oooo101o07nb0?ooo`030000003oool0oooo
01D0oooo000M0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`@000001P3oool00`000000
oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`2`0?ooo`@0
O`1o:@3oool00`020?d0oooo0?ooo`260?ooo`030000003oool0oooo01D0oooo000L0?ooo`040000
003oool0oooo000000P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?ooofL0
oooo00<000000?ooo`3oool0@@3oool200000;40oooo101o07mn0?ooo`80?`2o<@3oool2000001L0
oooo000L0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool01P3oool300000?l0
ooooI@3oool3000004<0oooo00<000000?ooo`3oool0/03oool407l0Ogl0oooo00<0?`2o0?ooo`3o
ool0<03oool00`000000oooo0?ooo`0E0?ooo`00703oool010000000oooo0?ooo`00000:0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo0440
oooo00<000000?ooo`3oool0^@3oool407l0OjT0oooo00<000000?ooo`3oool05@3oool001`0oooo
00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0
ooooI`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0;T0oooo101o07nY0?ooo`03
0000003oool0oooo01D0oooo000L0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool000001P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool00`00
0000oooo0?ooo`2i0?ooo`@0O`1o:03oool00`0A0>h0oooo0?ooo`1C0?ooo`80?`2o:@3oool00`00
0000oooo0?ooo`0E0?ooo`007@3oool2000000X0oooo0P0000070?ooo`030000003oool0oooo0?l0
ooooI`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0;T0oooo101o07mo0?ooo`03
03l0_`3oool0oooo02L0oooo00<000000?ooo`3oool05@3oool00380oooo00<000000?ooo`3oool0
o`3ooomW0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0`P3oool407l0Oj00oooo
00<000000?ooo`3oool05@3oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool0`P3oool407l0ObP0oooo0P1A0:if0?ooo`030000003o
ool0oooo01D0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`0]
0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`@000001@3oool00`000000oooo0?ooo`32
0?ooo`@0O`1o:03oool20540[U<0oooo0P0o0;lQ0?ooo`030000003oool0oooo01D0oooo000b0?oo
o`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`0/0?ooo`040000003oool0oooo
000000P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`320?ooo`@0O`1oOP3oool0
0`0o0;l0oooo0?ooo`0O0?ooo`030000003oool0oooo01D0oooo000b0?ooo`800000o`3ooomW0?oo
o`800000;P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00D0oooo0`00003e
0?ooo`D0XP1MJP3oool3000001L0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`00
0000oooo0?ooo`0/0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`3:0?ooo`@0O`1o9`3oool50:80GF`0oooo00<000000?ooo`3oool05@3oool0
0380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo02`0oooo00@000000?oo
o`3oool000002`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0<X0oooo101o07lV
0?ooo`H0XP1MDP3oool203l0_aP0oooo00<000000?ooo`3oool05@3oool00380oooo00<000000?oo
o`3oool0o`3ooomW0?ooo`030000003oool0oooo02`0oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`0000050?ooo`030000003oool0oooo0<X0oooo101o07lW0?ooo`D0XP1MD`3o
ool00`0o0;l0oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo000b0?ooo`030000003oool0
oooo0?l0ooooI`3oool00`000000oooo0?ooo`0]0?ooo`8000002P3oool2000000H0oooo00<00000
0?ooo`3oool0bP3oool407l0ObL0oooo1@2R05d40?ooo`@0^`14I03oool00`000000oooo0?ooo`0E
0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool00`00
0000oooo0?ooo`3C0?ooo`@0O`20803oool00`2R05d0oooo0?ooo`030?ooo`H0^`14H`3oool00`00
0000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3o
ool0@@3oool00`000000oooo0?ooo`3C0?ooo`@0O`209P3oool60;/0A540oooo0P0o0;l@0?ooo`03
0000003oool0oooo01D0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo
0?ooo`110?ooo`030000003oool0oooo0=<0oooo101o080V0?ooo`H0^`140`3oool50;l0@4X0oooo
00<0?`2o0?ooo`3oool03P3oool00`000000oooo0?ooo`0E0?ooo`00<P3oool200000?l0ooooI`3o
ool2000004<0oooo00<000000?ooo`3oool0d`3oool407l0P2H0oooo1P2k04@20?ooo`L0_`10FP3o
ool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<00000
0?ooo`3oool0@@3oool00`000000oooo0?ooo`3L0?ooo`@0OP217P3oool40;/0A0<0oooo1`2o041J
0?ooo`030000003oool0oooo01D0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo0=`0oooo101n084T0?ooo`P0_`10FP3oool00`00
0000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3o
ool0@@3oool200000=d0oooo101n084U0?ooo`L0_`10D@3oool203l0_`H0oooo0P00000G0?ooo`00
<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool00`000000oooo
0?ooo`3L0?ooo`@0OP219@3oool70;l0@0<0oooo1@2o03m:0?ooo`0303l0_`3oool0oooo00D0oooo
00<000000?ooo`3oool05@3oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool0o`3oool70?ooo`D0_`100`3oool70;l0?e40oooo00<0
00000?ooo`3oool05@3oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool0i03oool307@0Rb40oooo00<0_`100?ooo`3oool00`3oool7
0;l0?e40oooo00<000000?ooo`3oool05@3oool00380oooo00<000000?ooo`3oool0o`3ooomW0?oo
o`030000003oool0oooo0440oooo00<000000?ooo`3oool0h`3oool407@0RbH0oooo202o03mA0?oo
o`030000003oool0oooo01D0oooo000b0?ooo`800000o`3ooomW0?ooo`800000@`3oool00`000000
oooo0?ooo`3T0?ooo`<0M02;9`3oool70;l0?`80oooo1@2o03m:0?ooo`030000003oool0oooo01D0
oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`110?ooo`030000
003oool0oooo0>D0oooo00<0M02;0?ooo`3oool09P3oool70;l0?`030?ooo`2o03l0_`0o00D0_`0o
B@3oool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<0
00000?ooo`3oool0@@3oool00`000000oooo0?ooo`3^0?ooo`80B@2f7`3oool50;l0?`80oooo1`2o
03m90?ooo`030000003oool0oooo01D0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo0>h0oooo0P190;HQ0?ooo`040;l0?`3oool0
oooo0?ooo`P0_`0oB@3oool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo0?ooo`3o
0?ooofL0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3o0?oooaL0oooo1`2o03l3
0?ooo`D0_`0o@@3oool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo0?ooo`3o0?oo
ofL0oooo00<000000?ooo`3oool0@@3oool200000?l0oooo603oool70;l0?`80oooo1`2o03lo0?oo
o`8000005`3oool001d0oooo0P0000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`3o0?oooaP0oooo1@2o03l30?ooo`L0_`0o@03oool00`000000oooo0?ooo`0E0?ooo`00
703oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0o`3ooomW0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0m`3oool00`0C0>`0
oooo0?ooo`0O0?ooo`030;l0?`3oool0oooo0080oooo202o03m00?ooo`030000003oool0oooo01D0
oooo000L0?ooo`040000003oool0oooo000000L0oooo1@0000060?ooo`<00000o`3ooomU0?ooo`<0
0000@`3oool00`000000oooo0?ooo`3o0?ooob00oooo1`2o03l30?ooo`D0_`0o>03oool00`000000
oooo0?ooo`0E0?ooo`00703oool010000000oooo0?ooo`0000070?ooo`040000003oool0oooo0000
00L0oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo0440oooo00<000000?oo
o`3oool0o`3ooolP0?ooo`L0_`0o0P3oool70;l0?cL0oooo00<000000?ooo`3oool05@3oool001`0
oooo00@000000?ooo`3oool00000203oool00`000000oooo000000070?ooo`030000003oool0oooo
0?l0ooooI`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0?l0oooo8@3oool50;l0
?`<0oooo1`2o03lg0?ooo`030000003oool0oooo01D0oooo000L0?ooo`040000003oool0oooo0000
00T0oooo0P0000070?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo0?l0oooo0@3oool00`030?`0oooo0?ooo`0O0?ooo`030;l0?`3oool0oooo
0080oooo202o03lg0?ooo`030000003oool0oooo01D0oooo000M0?ooo`8000002`3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`110?ooo`03
0000003oool0oooo0?l0oooo:@3oool70;l0?`80oooo1@2o03l`0?ooo`030000003oool0oooo01D0
oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`110?ooo`030000
003oool0oooo0?l0oooo:@3oool70;l0?`030?ooo`2o03l0_`0o00D0_`0o;`3oool00`000000oooo
0?ooo`0E0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0@@3o
ool00`000000oooo0?ooo`3o0?ooobX0oooo1@2o03l20?ooo`L0_`0o;`3oool00`000000oooo0?oo
o`0E0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool0
0`000000oooo0?ooo`3o0?ooo`T0oooo00<0003o0?ooo`3oool0803oool0102o03l0oooo0?ooo`3o
ool80;l0?bl0oooo00<000000?ooo`3oool05@3oool00380oooo0P00001^0?ooo`030000o`3oool0
oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0
oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0
oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0
oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0
oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0
oooo00H0oooo00<0003o0?ooo`3oool0J`3oool2000004<0oooo0P00003o0?oooc80oooo1`2o03l3
0?ooo`D0_`0o9P3oool2000001L0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo0?l0oooo<@3oool70;l0?`80oooo1`2o03lV0?oo
o`030000003oool0oooo01D0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000
oooo0?ooo`110?ooo`030000003oool0oooo0?l0oooo<P3oool50;l0?`<0oooo1`2o03lV0?ooo`03
0000003oool0oooo01D0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo
0?ooo`110?ooo`030000003oool0oooo0?l0oooo4P3oool00`000?l0oooo0?ooo`0O0?ooo`030;l0
?`3oool0oooo0080oooo202o03lV0?ooo`030000003oool0oooo01D0oooo000b0?ooo`030000003o
ool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0?l0oooo>P3o
ool70;l0?bH0oooo00<000000?ooo`3oool05@3oool00380oooo00<000000?ooo`3oool0o`3ooomW
0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0o`3ooolj0?ooo`L0_`0o0P3oool5
0;l0?al0oooo00<000000?ooo`3oool05@3oool00380oooo00<000000?ooo`3oool0o`3ooomW0?oo
o`030000003oool0oooo0440oooo00<000000?ooo`3oool0o`3ooolk0?ooo`D0_`0o0P3oool70;l0
?ah0oooo00<000000?ooo`3oool05@3oool00380oooo00<000000?ooo`3oool0103oool407l0O`D0
oooo101o07l40?ooo`@0O`1o1@3oool407l0O`D0oooo101o07l40?ooo`@0O`1o1@3oool407l0O`@0
oooo101o07l50?ooo`@0O`1o1@3oool407l0O`@0oooo101o08050?ooo`@0O0231@3oool306`0ThH0
oooo0`1/09<60?ooo`@0O023103oool407l0P0D0oooo101o07l40?ooo`@0O`1o1@3oool407l0O`D0
oooo101o07l40?ooo`@0O`1o1@3oool407l0O`@0oooo101o07l50?ooo`@0O`1o1@3oool407l0O`@0
oooo101o07l60?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0o`3ooolJ0?ooo`03
0000o`3oool0oooo0200oooo00<0_`0o0?ooo`3oool00P3oool70;l0?ah0oooo00<000000?ooo`3o
ool05@3oool00380oooo0P0000050?ooo`@0O`1o1@3oool407l0O`@0oooo101o07l50?ooo`@0O`1o
1@3oool407l0O`@0oooo101o07l50?ooo`@0O`1o103oool407l0O`D0oooo101o07l50?ooo`@0O`1o
103oool407l0P0D0oooo101l08<40?ooo`@0K02C1P3oool203H0b@L0oooo00<02`3d0?ooo`3oool0
1P3oool00`010?h0oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`060?ooo`030040oP3oool0oooo00D0oooo00<02`3d0?ooo`3oool0
1@3oool203H0b@D0oooo101/09<60?ooo`@0O023103oool407l0P0D0oooo101o07l40?ooo`@0O`1o
1@3oool407l0O`D0oooo101o07l40?ooo`@0O`1o1@3oool407l0O`@0oooo101o07l50?ooo`@0O`1o
1@3oool407l0O`@0oooo101o07l50?ooo`800000;`3oool2000000@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo@@3oool80;l0?ah0oooo
00<000000?ooo`3oool05@3oool00380oooo00<000000?ooo`3oool0103oool407l0O`D0oooo101o
07l40?ooo`@0O`1o1@3oool407l0O`D0oooo101o07l40?ooo`@0O`1o1@3oool407l0O`@0oooo101o
07l50?ooo`@0O`1o1@3oool407l0O`@0oooo101o08050?ooo`@0O0231@3oool306`0T`L0oooo00<0
=P390?ooo`3oool0M@3oool00`0f0<T0oooo0?ooo`040?ooo`<0K02C1P3oool407`0P`@0oooo101o
08050?ooo`@0O`1o103oool407l0O`D0oooo101o07l50?ooo`@0O`1o103oool407l0O`D0oooo101o
07l40?ooo`@0O`1o1@3oool407l0O`D0oooo101o07l40?ooo`@0O`1o1P3oool00`000000oooo0?oo
o`0/0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`3o0?oood80oooo1`2o03l30?ooo`D0_`0o5P3oool00`000000oooo0?ooo`0E0?ooo`00<P3o
ool00`000000oooo0?ooo`040?ooo`@0O`1o1@3oool407l0O`@0oooo101o07l50?ooo`@0O`1o1@3o
ool407l0O`@0oooo101o07l50?ooo`@0O`1o103oool407l0O`D0oooo101o07l50?ooo`@0O`1o103o
ool407l0P0D0oooo101l08<60?ooo`0306`0T`3oool0oooo08H0oooo00<0K02C0?ooo`3oool01@3o
ool407`0P`@0oooo101o08050?ooo`@0O`1o103oool407l0O`D0oooo101o07l50?ooo`@0O`1o103o
ool407l0O`D0oooo101o07l40?ooo`@0O`1o1@3oool407l0O`D0oooo101o07l40?ooo`@0O`1o1P3o
ool00`000000oooo0?ooo`0/0?ooo`040000003oool0oooo000000L0oooo1@0000050?ooo`<00000
o`3ooom20?ooo`L0_`0o0P3oool70;l0?a<0oooo0`00000G0?ooo`00<P3oool00`000000oooo0?oo
o`3o0?ooofL0oooo00<000000?ooo`3oool0;03oool010000000oooo0?ooo`0000070?ooo`040000
003oool0oooo000000H0oooo00<000000?ooo`3oool0o`3ooom30?ooo`D0_`0o0`3oool70;l0?aD0
oooo00<000000?ooo`3oool05@3oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000
003oool0oooo02`0oooo00@000000?ooo`3oool00000203oool00`000000oooo000000060?ooo`03
0000003oool0oooo0?l0oooo8`3oool00`000?l0oooo0?ooo`0O0?ooo`030;l0?`3oool0oooo0080
oooo202o03lE0?ooo`030000003oool0oooo01D0oooo000b0?ooo`030000003oool0oooo0?l0oooo
I`3oool00`000000oooo0?ooo`0/0?ooo`040000003oool0oooo000000T0oooo0P0000060?ooo`03
0000003oool0oooo0?l0ooooB`3oool70;l0?`<0oooo1@2o03l=0?ooo`030000003oool0oooo01D0
oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`0]0?ooo`800000
2`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooB`3oool70;l0?`80oooo
1`2o03l<0?ooo`030000003oool0oooo01D0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3o
ool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0?l0ooooC03oool50;l0?`<0oooo1`2o
03l<0?ooo`030000003oool0oooo01D0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo0?l0oooo;03oool00`000?l0oooo0?ooo`0O
0?ooo`030;l0?`3oool0oooo0080oooo202o03l<0?ooo`030000003oool0oooo01D0oooo000b0?oo
o`800000o`3ooomW0?ooo`800000@`3oool00`000000oooo0?ooo`3o0?oooe@0oooo1`2o03l20?oo
o`D0_`0o1@3oool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0
oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3o0?oooe@0oooo1`2o03l00`3oool0
_`0o0;l0?`050;l0?`@0oooo00<000000?ooo`3oool05@3oool00380oooo00<000000?ooo`3oool0
o`3ooomW0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0o`3ooomE0?ooo`D0_`0o
0P3oool70;l0?`@0oooo00<000000?ooo`3oool05@3oool00380oooo00<000000?ooo`3oool0o`3o
oomW0?ooo`030000003oool0oooo0440oooo0P00003o0?ooocD0oooo00<0003o0?ooo`3oool0803o
ool0102o03l0oooo0?ooo`3oool80;l0?`<0oooo0P00000G0?ooo`00<P3oool00`000000oooo0?oo
o`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3o0?oooe`0oooo1`2o
03l40?ooo`030000003oool0oooo01D0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo0?l0ooooG03oool70;l0?`@0oooo00<00000
0?ooo`3oool05@3oool001d0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000070?oo
o`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo
0?l0ooooG@3oool50;l0?`D0oooo00<000000?ooo`3oool05@3oool001`0oooo00@000000?ooo`3o
ool00000203oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo0?l0ooooI`3oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo0?l0oooo?@3oool00`000?l0oooo0?ooo`0O
0?ooo`030;l0?`3oool0oooo00D0oooo00<000000?ooo`3oool05@3oool001`0oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`0000060?ooo`<00000o`3ooomU0?ooo`<00000@`3o
ool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool05@3oool001`0oooo00@00000
0?ooo`3oool00000203oool3000000L0oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo01D0oooo000L
0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`3o0?ooofL0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<0
00000?ooo`3oool05@3oool001`0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo0?l0ooooA@3oool00`000?l0oooo0?ooo`0O0?ooo`030000003oool0oooo01D0oooo000M
0?ooo`8000002P3oool3000000H0oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo01D0oooo000b0?oo
o`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo
0?l0ooooI`3oool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo0?ooo`250?ooo`@0
OP211@3oool407l0P0@0oooo101o07l50?ooo`@0O`1o1@3oool407l0O`@0oooo101o07l50?ooo`@0
O`1o103oool407l0O`D0oooo101o07l50?ooo`@0O`20103oool407h0PHL0oooo00<000000?ooo`3o
ool0@@3oool200000?l0ooooI`3oool2000001L0oooo000b0?ooo`030000003oool0oooo07D0oooo
0P190;H60?ooo`<0M02;1@3oool407h0P@D0oooo101o08040?ooo`@0O`1o1@3oool407l0O`D0oooo
101o07l40?ooo`@0O`1o1@3oool407l0O`@0oooo101o07l50?ooo`@0O`1o1@3oool407l0P0@0oooo
101n08450?ooo`<0M02;1`3oool204T0]WH0oooo00<000000?ooo`3oool0@@3oool00`000000oooo
0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool05@3oool00380oooo0P00000H0?ooo`030000o`3o
ool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o
ool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o
ool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`0300<0o03o
ool0oooo00H0oooo00<04`3/0?ooo`3oool01@3oool204T0]PD0oooo101d08/50?ooo`@0OP211@3o
ool407l0P0@0oooo101o07l50?ooo`@0O`1o1@3oool407l0O`@0oooo101o07l50?ooo`@0O`1o103o
ool407l0O`D0oooo101o07l50?ooo`@0O`20103oool407h0P@@0oooo101d08/70?ooo`80B@2f1P3o
ool00`0C0>`0oooo0?ooo`060?ooo`0300<0o03oool0oooo00H0oooo00<0003o0?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo01D0oooo0P0000130?ooo`030000003o
ool0oooo0?l0ooooCP3oool00`000?l0oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo000b
0?ooo`030000003oool0oooo07d0oooo0`1d08/50?ooo`@0OP211@3oool407l0P0@0oooo101o07l5
0?ooo`@0O`1o1@3oool407l0O`@0oooo101o07l50?ooo`@0O`1o103oool407l0O`D0oooo101o07l5
0?ooo`@0O`20103oool407h0P@D0oooo0`1d08]o0?ooo`030000003oool0oooo0440oooo00<00000
0?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo01D0oooo000b0?ooo`030000003oool0oooo
07h0oooo00<0M02;0?ooo`3oool0I03oool00`1d08/0oooo0?ooo`1n0?ooo`030000003oool0oooo
0440oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo01D0oooo000b0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`1C0?ooo`03
0000003oool0oooo05<0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0440oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1C0?ooo`03
0000003oool0oooo05<0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`1C0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool05@3oool00380oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
@@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0E0?ooo`00<P3ooooo000006/00000@`3ooooo000006/000005`3o
ool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0
ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo
0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 863}, {253.25, 0}} -> {-0.0530409, -0.0147182, \
0.00244042, 0.00244042}, {{21.6875, 411.938}, {247.188, 6}} -> {-0.536713, \
-0.815489, 0.00232472, 0.00611241}, {{451, 841.25}, {247.188, 6}} -> \
{-1.53474, -0.639845, 0.00232472, 0.00479589}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  GraphicsArray  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(\(values = {};\)\), "\[IndentingNewLine]", 
    \(Scan[\((doit[#, calculateFAST])\) &, 
      Table[x, {x, 0.1, 0.2, 0.005}]]\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(scale = 0.03;\)\), "\[IndentingNewLine]", 
    \(\(pts = 
        Map[specresults[#] /. rule[#] &, 
          values];\)\), "\[IndentingNewLine]", 
    \(\(pts1 = pointswithsize\ @\ \ pts[\([All, 1]\)];\)\), "\n", 
    \(\(pts2 = 
        pointswithsize\ @\ \ pts[\([All, 2]\)];\)\), "\[IndentingNewLine]", 
    \(Show\ [\ 
      GraphicsArray[\ {Graphics\ [pts1, Frame \[Rule] True], 
          Graphics[pts2, Frame \[Rule] True]}], 
      ImageSize \[Rule] 12\ 72]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
%%ImageSize: 864 254.277 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.928571 9.52381 0.309017 0.452772 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.21429 -0.0125 -12 -9 ]
[.21429 -0.0125 12 0 ]
[.40476 -0.0125 -12 -9 ]
[.40476 -0.0125 12 0 ]
[.59524 -0.0125 -12 -9 ]
[.59524 -0.0125 12 0 ]
[.78571 -0.0125 -12 -9 ]
[.78571 -0.0125 12 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .03735 -24 -4.5 ]
[-0.0125 .03735 0 4.5 ]
[-0.0125 .12791 -24 -4.5 ]
[-0.0125 .12791 0 4.5 ]
[-0.0125 .21846 -24 -4.5 ]
[-0.0125 .21846 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .39957 -18 -4.5 ]
[-0.0125 .39957 0 4.5 ]
[-0.0125 .49013 -18 -4.5 ]
[-0.0125 .49013 0 4.5 ]
[-0.0125 .58068 -18 -4.5 ]
[-0.0125 .58068 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0.1)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(0.12)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.14)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.16)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.18)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(0.2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .03735 m
.00625 .03735 L
s
[(-0.6)] -0.0125 .03735 1 0 Mshowa
0 .12791 m
.00625 .12791 L
s
[(-0.4)] -0.0125 .12791 1 0 Mshowa
0 .21846 m
.00625 .21846 L
s
[(-0.2)] -0.0125 .21846 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .39957 m
.00625 .39957 L
s
[(0.2)] -0.0125 .39957 1 0 Mshowa
0 .49013 m
.00625 .49013 L
s
[(0.4)] -0.0125 .49013 1 0 Mshowa
0 .58068 m
.00625 .58068 L
s
[(0.6)] -0.0125 .58068 1 0 Mshowa
.125 Mabswid
0 .05999 m
.00375 .05999 L
s
0 .08263 m
.00375 .08263 L
s
0 .10527 m
.00375 .10527 L
s
0 .15055 m
.00375 .15055 L
s
0 .17319 m
.00375 .17319 L
s
0 .19582 m
.00375 .19582 L
s
0 .2411 m
.00375 .2411 L
s
0 .26374 m
.00375 .26374 L
s
0 .28638 m
.00375 .28638 L
s
0 .33166 m
.00375 .33166 L
s
0 .35429 m
.00375 .35429 L
s
0 .37693 m
.00375 .37693 L
s
0 .42221 m
.00375 .42221 L
s
0 .44485 m
.00375 .44485 L
s
0 .46749 m
.00375 .46749 L
s
0 .51276 m
.00375 .51276 L
s
0 .5354 m
.00375 .5354 L
s
0 .55804 m
.00375 .55804 L
s
0 .01472 m
.00375 .01472 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .03735 m
1 .03735 L
s
.99375 .12791 m
1 .12791 L
s
.99375 .21846 m
1 .21846 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .39957 m
1 .39957 L
s
.99375 .49013 m
1 .49013 L
s
.99375 .58068 m
1 .58068 L
s
.125 Mabswid
.99625 .05999 m
1 .05999 L
s
.99625 .08263 m
1 .08263 L
s
.99625 .10527 m
1 .10527 L
s
.99625 .15055 m
1 .15055 L
s
.99625 .17319 m
1 .17319 L
s
.99625 .19582 m
1 .19582 L
s
.99625 .2411 m
1 .2411 L
s
.99625 .26374 m
1 .26374 L
s
.99625 .28638 m
1 .28638 L
s
.99625 .33166 m
1 .33166 L
s
.99625 .35429 m
1 .35429 L
s
.99625 .37693 m
1 .37693 L
s
.99625 .42221 m
1 .42221 L
s
.99625 .44485 m
1 .44485 L
s
.99625 .46749 m
1 .46749 L
s
.99625 .51276 m
1 .51276 L
s
.99625 .5354 m
1 .5354 L
s
.99625 .55804 m
1 .55804 L
s
.99625 .01472 m
1 .01472 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.493 0 .507 r
.0148 w
.02381 .01472 Mdot
.007 0 .993 r
.0002 w
.02381 .08263 Mdot
0 0 1 r
0 w
.02381 .10527 Mdot
.02381 .51276 Mdot
.007 0 .993 r
.0002 w
.02381 .5354 Mdot
.493 0 .507 r
.0148 w
.02381 .60332 Mdot
.489 0 .511 r
.01467 w
.07143 .01472 Mdot
.011 0 .989 r
.00033 w
.07143 .08263 Mdot
0 0 1 r
0 w
.07143 .10527 Mdot
.07143 .51276 Mdot
.011 0 .989 r
.00033 w
.07143 .5354 Mdot
.489 0 .511 r
.01467 w
.07143 .60332 Mdot
.482 0 .518 r
.01447 w
.11905 .01472 Mdot
.018 0 .982 r
.00053 w
.11905 .08263 Mdot
0 0 1 r
0 w
.11905 .10527 Mdot
.11905 .51276 Mdot
.018 0 .982 r
.00053 w
.11905 .5354 Mdot
.482 0 .518 r
.01447 w
.11905 .60332 Mdot
.472 0 .528 r
.01415 w
.16667 .01472 Mdot
.028 0 .972 r
.00085 w
.16667 .08263 Mdot
0 0 1 r
0 w
.16667 .10527 Mdot
.16667 .51276 Mdot
.028 0 .972 r
.00085 w
.16667 .5354 Mdot
.472 0 .528 r
.01415 w
.16667 .60332 Mdot
.455 0 .545 r
.01364 w
.21429 .01472 Mdot
.045 0 .955 r
.00136 w
.21429 .08263 Mdot
0 0 1 r
0 w
.21429 .10527 Mdot
.21429 .51276 Mdot
.045 0 .955 r
.00136 w
.21429 .5354 Mdot
.455 0 .545 r
.01364 w
.21429 .60332 Mdot
.429 0 .571 r
.01288 w
.2619 .01472 Mdot
.071 0 .929 r
.00212 w
.2619 .08263 Mdot
0 0 1 r
0 w
.2619 .10527 Mdot
.2619 .51276 Mdot
.071 0 .929 r
.00212 w
.2619 .5354 Mdot
.429 0 .571 r
.01288 w
.2619 .60332 Mdot
.393 0 .607 r
.0118 w
.30952 .01472 Mdot
.107 0 .893 r
.0032 w
.30952 .08263 Mdot
0 0 1 r
0 w
.30952 .10527 Mdot
.30952 .51276 Mdot
.107 0 .893 r
.0032 w
.30952 .5354 Mdot
.393 0 .607 r
.0118 w
.30952 .60332 Mdot
.346 0 .654 r
.01037 w
.35714 .01472 Mdot
.154 0 .846 r
.00463 w
.35714 .08263 Mdot
0 0 1 r
0 w
.35714 .10527 Mdot
.35714 .51276 Mdot
.154 0 .846 r
.00463 w
.35714 .5354 Mdot
.346 0 .654 r
.01037 w
.35714 .60332 Mdot
.288 0 .712 r
.00864 w
.40476 .01472 Mdot
.212 0 .788 r
.00636 w
.40476 .08263 Mdot
0 0 1 r
0 w
.40476 .10527 Mdot
.40476 .51276 Mdot
.212 0 .788 r
.00636 w
.40476 .5354 Mdot
.288 0 .712 r
.00864 w
.40476 .60332 Mdot
.226 0 .774 r
.00678 w
.45238 .01472 Mdot
.274 0 .726 r
.00822 w
.45238 .08263 Mdot
0 0 1 r
0 w
.45238 .10527 Mdot
.45238 .51276 Mdot
.274 0 .726 r
.00822 w
.45238 .5354 Mdot
.226 0 .774 r
.00678 w
.45238 .60332 Mdot
.167 0 .833 r
.005 w
.5 .01472 Mdot
.333 0 .667 r
.01 w
.5 .08263 Mdot
0 0 1 r
0 w
.5 .10527 Mdot
.5 .51276 Mdot
.333 0 .667 r
.01 w
.5 .5354 Mdot
.167 0 .833 r
.005 w
.5 .60332 Mdot
.116 0 .884 r
.00349 w
.54762 .01472 Mdot
.384 0 .616 r
.01151 w
.54762 .08263 Mdot
0 0 1 r
0 w
.54762 .10527 Mdot
.54762 .51276 Mdot
.384 0 .616 r
.01151 w
.54762 .5354 Mdot
.116 0 .884 r
.00349 w
.54762 .60332 Mdot
.078 0 .922 r
.00233 w
.59524 .01472 Mdot
.422 0 .578 r
.01267 w
.59524 .08263 Mdot
0 0 1 r
0 w
.59524 .10527 Mdot
.59524 .51276 Mdot
.422 0 .578 r
.01267 w
.59524 .5354 Mdot
.078 0 .922 r
.00233 w
.59524 .60332 Mdot
.05 0 .95 r
.00151 w
.64286 .01472 Mdot
.45 0 .55 r
.01349 w
.64286 .08263 Mdot
0 0 1 r
0 w
.64286 .10527 Mdot
.64286 .51276 Mdot
.45 0 .55 r
.01349 w
.64286 .5354 Mdot
.05 0 .95 r
.00151 w
.64286 .60332 Mdot
.032 0 .968 r
.00095 w
.69048 .01472 Mdot
.468 0 .532 r
.01405 w
.69048 .08263 Mdot
0 0 1 r
0 w
.69048 .10527 Mdot
.69048 .51276 Mdot
.468 0 .532 r
.01405 w
.69048 .5354 Mdot
.032 0 .968 r
.00095 w
.69048 .60332 Mdot
.02 0 .98 r
.00059 w
.7381 .01472 Mdot
.48 0 .52 r
.01441 w
.7381 .08263 Mdot
0 0 1 r
0 w
.7381 .10527 Mdot
.7381 .51276 Mdot
.48 0 .52 r
.01441 w
.7381 .5354 Mdot
.02 0 .98 r
.00059 w
.7381 .60332 Mdot
.012 0 .988 r
.00036 w
.78571 .01472 Mdot
.488 0 .512 r
.01464 w
.78571 .08263 Mdot
.78571 .5354 Mdot
.012 0 .988 r
.00036 w
.78571 .60332 Mdot
.007 0 .993 r
.00022 w
.83333 .01472 Mdot
.493 0 .507 r
.01478 w
.83333 .08263 Mdot
.83333 .5354 Mdot
.007 0 .993 r
.00022 w
.83333 .60332 Mdot
.005 0 .995 r
.00014 w
.88095 .01472 Mdot
.495 0 .505 r
.01486 w
.88095 .08263 Mdot
.88095 .5354 Mdot
.005 0 .995 r
.00014 w
.88095 .60332 Mdot
.003 0 .997 r
8e-05 w
.92857 .01472 Mdot
.497 0 .503 r
.01492 w
.92857 .08263 Mdot
.92857 .5354 Mdot
.003 0 .997 r
8e-05 w
.92857 .60332 Mdot
.002 0 .998 r
5e-05 w
.97619 .01472 Mdot
.498 0 .502 r
.01495 w
.97619 .08263 Mdot
.97619 .5354 Mdot
.002 0 .998 r
5e-05 w
.97619 .60332 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.928571 9.52381 0.0882906 1.47151 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.21429 -0.0125 -12 -9 ]
[.21429 -0.0125 12 0 ]
[.40476 -0.0125 -12 -9 ]
[.40476 -0.0125 12 0 ]
[.59524 -0.0125 -12 -9 ]
[.59524 -0.0125 12 0 ]
[.78571 -0.0125 -12 -9 ]
[.78571 -0.0125 12 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08829 -6 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .23544 -18 -4.5 ]
[-0.0125 .23544 0 4.5 ]
[-0.0125 .38259 -18 -4.5 ]
[-0.0125 .38259 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0.1)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(0.12)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.14)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.16)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.18)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(0.2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08829 m
.00625 .08829 L
s
[(0)] -0.0125 .08829 1 0 Mshowa
0 .23544 m
.00625 .23544 L
s
[(0.1)] -0.0125 .23544 1 0 Mshowa
0 .38259 m
.00625 .38259 L
s
[(0.2)] -0.0125 .38259 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(0.3)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .11772 m
.00375 .11772 L
s
0 .14715 m
.00375 .14715 L
s
0 .17658 m
.00375 .17658 L
s
0 .20601 m
.00375 .20601 L
s
0 .26487 m
.00375 .26487 L
s
0 .2943 m
.00375 .2943 L
s
0 .32373 m
.00375 .32373 L
s
0 .35316 m
.00375 .35316 L
s
0 .41202 m
.00375 .41202 L
s
0 .44145 m
.00375 .44145 L
s
0 .47088 m
.00375 .47088 L
s
0 .50031 m
.00375 .50031 L
s
0 .05886 m
.00375 .05886 L
s
0 .02943 m
.00375 .02943 L
s
0 .55917 m
.00375 .55917 L
s
0 .5886 m
.00375 .5886 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .08829 m
1 .08829 L
s
.99375 .23544 m
1 .23544 L
s
.99375 .38259 m
1 .38259 L
s
.99375 .52974 m
1 .52974 L
s
.125 Mabswid
.99625 .11772 m
1 .11772 L
s
.99625 .14715 m
1 .14715 L
s
.99625 .17658 m
1 .17658 L
s
.99625 .20601 m
1 .20601 L
s
.99625 .26487 m
1 .26487 L
s
.99625 .2943 m
1 .2943 L
s
.99625 .32373 m
1 .32373 L
s
.99625 .35316 m
1 .35316 L
s
.99625 .41202 m
1 .41202 L
s
.99625 .44145 m
1 .44145 L
s
.99625 .47088 m
1 .47088 L
s
.99625 .50031 m
1 .50031 L
s
.99625 .05886 m
1 .05886 L
s
.99625 .02943 m
1 .02943 L
s
.99625 .55917 m
1 .55917 L
s
.99625 .5886 m
1 .5886 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.497 0 .503 r
.0149 w
.02381 .01472 Mdot
0 0 1 r
0 w
.02381 .16187 Mdot
0 w
.02381 .16187 Mdot
.01 0 .99 r
.0003 w
.02381 .30902 Mdot
.493 0 .507 r
.0148 w
.02381 .45617 Mdot
.495 0 .505 r
.01484 w
.07143 .02207 Mdot
0 0 1 r
0 w
.07143 .16922 Mdot
0 w
.07143 .16922 Mdot
.016 0 .984 r
.00049 w
.07143 .31637 Mdot
.489 0 .511 r
.01467 w
.07143 .46353 Mdot
.491 0 .509 r
.01473 w
.11905 .02943 Mdot
0 0 1 r
0 w
.11905 .17658 Mdot
0 w
.11905 .17658 Mdot
.027 0 .973 r
.0008 w
.11905 .32373 Mdot
.482 0 .518 r
.01447 w
.11905 .47088 Mdot
.486 0 .514 r
.01457 w
.16667 .03679 Mdot
0 0 1 r
0 w
.16667 .18394 Mdot
.043 0 .957 r
.00128 w
.16667 .33109 Mdot
.472 0 .528 r
.01415 w
.16667 .47824 Mdot
.477 0 .523 r
.01432 w
.21429 .04415 Mdot
0 0 1 r
0 w
.21429 .1913 Mdot
.068 0 .932 r
.00204 w
.21429 .33845 Mdot
.455 0 .545 r
.01364 w
.21429 .4856 Mdot
.465 0 .535 r
.01394 w
.2619 .0515 Mdot
0 0 1 r
0 w
.2619 .19865 Mdot
.106 0 .894 r
.00317 w
.2619 .3458 Mdot
.429 0 .571 r
.01288 w
.2619 .49296 Mdot
.447 0 .553 r
.0134 w
.30952 .05886 Mdot
0 0 1 r
0 w
.30952 .20601 Mdot
.16 0 .84 r
.00479 w
.30952 .35316 Mdot
.393 0 .607 r
.0118 w
.30952 .50031 Mdot
.423 0 .577 r
.01269 w
.35714 .06622 Mdot
0 0 1 r
0 w
.35714 .21337 Mdot
.231 0 .769 r
.00694 w
.35714 .36052 Mdot
.346 0 .654 r
.01037 w
.35714 .50767 Mdot
.394 0 .606 r
.01182 w
.40476 .07358 Mdot
0 0 1 r
0 w
.40476 .22073 Mdot
.318 0 .682 r
.00954 w
.40476 .36788 Mdot
.288 0 .712 r
.00864 w
.40476 .51503 Mdot
.363 0 .637 r
.01089 w
.45238 .08093 Mdot
0 0 1 r
0 w
.45238 .22808 Mdot
.411 0 .589 r
.01233 w
.45238 .37523 Mdot
.226 0 .774 r
.00678 w
.45238 .52239 Mdot
.333 0 .667 r
.01 w
.5 .08829 Mdot
0 0 1 r
0 w
.5 .23544 Mdot
.5 0 .5 r
.015 w
.5 .38259 Mdot
.167 0 .833 r
.005 w
.5 .52974 Mdot
.308 0 .692 r
.00925 w
.54762 .09565 Mdot
0 0 1 r
0 w
.54762 .2428 Mdot
.575 0 .425 r
.01726 w
.54762 .38995 Mdot
.116 0 .884 r
.00349 w
.54762 .5371 Mdot
.289 0 .711 r
.00867 w
.59524 .10301 Mdot
0 0 1 r
0 w
.59524 .25016 Mdot
.633 0 .367 r
.019 w
.59524 .39731 Mdot
.078 0 .922 r
.00233 w
.59524 .54446 Mdot
.275 0 .725 r
.00825 w
.64286 .11036 Mdot
0 0 1 r
0 w
.64286 .25751 Mdot
.675 0 .325 r
.02024 w
.64286 .40467 Mdot
.05 0 .95 r
.00151 w
.64286 .55182 Mdot
.266 0 .734 r
.00798 w
.69048 .11772 Mdot
0 0 1 r
0 w
.69048 .26487 Mdot
.702 0 .298 r
.02107 w
.69048 .41202 Mdot
.032 0 .968 r
.00095 w
.69048 .55917 Mdot
.26 0 .74 r
.0078 w
.7381 .12508 Mdot
0 0 1 r
0 w
.7381 .27223 Mdot
.72 0 .28 r
.02161 w
.7381 .41938 Mdot
.02 0 .98 r
.00059 w
.7381 .56653 Mdot
.256 0 .744 r
.00768 w
.78571 .13244 Mdot
.732 0 .268 r
.02195 w
.78571 .42674 Mdot
.012 0 .988 r
.00036 w
.78571 .57389 Mdot
.254 0 .746 r
.00761 w
.83333 .13979 Mdot
.739 0 .261 r
.02217 w
.83333 .4341 Mdot
.007 0 .993 r
.00022 w
.83333 .58125 Mdot
.252 0 .748 r
.00757 w
.88095 .14715 Mdot
.743 0 .257 r
.0223 w
.88095 .44145 Mdot
.005 0 .995 r
.00014 w
.88095 .5886 Mdot
.251 0 .749 r
.00754 w
.92857 .15451 Mdot
.746 0 .254 r
.02238 w
.92857 .44881 Mdot
.003 0 .997 r
8e-05 w
.92857 .59596 Mdot
.251 0 .749 r
.00753 w
.97619 .16187 Mdot
.747 0 .253 r
.02242 w
.97619 .45617 Mdot
.002 0 .998 r
5e-05 w
.97619 .60332 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{864, 254.25},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=P0000oR000`400?l00000o`00003oo`3ooooo
0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00
o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS
0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0oooo
o`3ooomS0?ooo`00o`3ooooL0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`@00000=03o
ool2000000@0oooo00<000000?ooo`3oool00P3oool400000080oooo1000000a0?ooo`800000103o
ool00`000000oooo0?ooo`020?ooo`@00000103oool00`000000oooo0?ooo`0`0?ooo`800000103o
ool00`000000oooo0?ooo`020?ooo`@000000`3oool200000380oooo0P0000040?ooo`030000003o
ool0oooo0080oooo100000030?ooo`800000=@3oool2000000@0oooo00<000000?ooo`3oool00P3o
ool4000001P0oooo000c0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`@00000<`3oool2
000000@0oooo00<000000?ooo`3oool00P3oool400000080oooo1000000`0?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@00000103oool00`000000oooo0?ooo`0_0?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@000000`3oool200000340oooo0P0000040?ooo`030000003oool0
oooo0080oooo100000030?ooo`800000<`3oool2000000@0oooo00<000000?ooo`3oool00P3oool4
00000400oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0b0?ooo`040000003o
ool0oooo000000X0oooo00D000000?ooo`3oool0oooo0000000c0?ooo`040000003oool0oooo0000
00X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0_0?ooo`040000003oool0oooo
000000X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo02h0oooo00@0
00000?ooo`3oool000002P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0<@3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo01T0oooo000b0?ooo`04
0000003oool0oooo000000X0oooo00<000000?ooo`3oool0<@3oool010000000oooo0?ooo`00000:
0?ooo`050000003oool0oooo0?ooo`000000<P3oool010000000oooo0?ooo`00000:0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0;P3oool010000000oooo0?ooo`00000:0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0]0?ooo`040000003oool0oooo
000000X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo02l0oooo00@0
00000?ooo`3oool00000203oool00`000000oooo0?ooo`110?ooo`040000003oool0oooo000000X0
oooo00<000000?ooo`3oool0<P3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0<03oool010000000oooo0?ooo`00000:0?ooo`030000003oool0
oooo00D00000<03oool010000000oooo0?ooo`00000:0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`0^0?ooo`040000003oool0oooo000000X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo0340oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0?ooo`0H0?ooo`00<P3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0
oooo0340oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo02l0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`05000002l0oooo
00@000000?ooo`3oool000002P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool0;@3oool010000000oooo0?ooo`00000:0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`0_0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0
@03oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo0380oooo00@000000?ooo`3o
ool000002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02l0oooo00@000000?oo
o`3oool000002P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02l0oooo00@0
00000?ooo`3oool000002P3oool010000000oooo0?ooo`3oool300000340oooo00@000000?ooo`3o
ool000002P3oool00`000000oooo0?ooo`020?ooo`800000=03oool010000000oooo0?ooo`00000:
0?ooo`030000003oool0oooo01L0oooo000b0?ooo`040000003oool0oooo000000X0oooo00<00000
0?ooo`3oool0<@3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0;P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool0;P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo
0?ooo`<00000<03oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo0080oooo0P00
000b0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0?`3oool010000000oooo
0?ooo`00000:0?ooo`030000003oool0oooo0380oooo00@000000?ooo`3oool000002P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo02h0oooo00@000000?ooo`3oool000002P3oool0
1`000000oooo0?ooo`3oool000000?ooo`000000<@3oool010000000oooo0?ooo`00000:0?ooo`05
0000003oool0oooo0?ooo`000000<`3oool010000000oooo0?ooo`00000:0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0a0?ooo`040000003oool0oooo000000/0oooo
00<000000?ooo`3oool05P3oool00380oooo00@000000?ooo`3oool000002P3oool00`000000oooo
0?ooo`0a0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0]0?ooo`040000003oool0oooo000000X0oooo00L000000?ooo`3oool0oooo0000003o
ool000000300oooo00@000000?ooo`3oool000002P3oool01@000000oooo0?ooo`3oool000000380
oooo00@000000?ooo`3oool000002P3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool0;`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo03h0oooo00@0
00000?ooo`3oool00000203oool3000003@0oooo00@000000?ooo`3oool00000203oool3000000<0
oooo00@000000?ooo`3oool00000<03oool010000000oooo0?ooo`0000080?ooo`<00000103oool2
00000340oooo00@000000?ooo`3oool00000203oool3000000<0oooo00<000000?ooo`3oool0<@3o
ool010000000oooo0?ooo`0000080?ooo`<000000`3oool010000000oooo0?ooo`00000c0?ooo`04
0000003oool0oooo000000P0oooo00@000000?ooo`3oool00000603oool00380oooo00@000000?oo
o`3oool00000203oool3000003<0oooo00@000000?ooo`3oool00000203oool3000000<0oooo00@0
00000?ooo`3oool00000;`3oool010000000oooo0?ooo`0000080?ooo`<00000103oool200000300
oooo00@000000?ooo`3oool00000203oool3000000<0oooo00<000000?ooo`3oool0<03oool01000
0000oooo0?ooo`0000080?ooo`<000000`3oool010000000oooo0?ooo`00000a0?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool00000@@3oool2000000/0oooo00<000000?ooo`3o
ool0<`3oool2000000/0oooo00<000000?ooo`3oool00P3oool200000380oooo0P00000;0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0<03oool2000000/0oooo00<000000?ooo`3o
ool00P3oool300000340oooo0P00000;0?ooo`030000003oool0oooo0080oooo0P00000e0?ooo`80
00002P3oool2000001T0oooo000c0?ooo`8000002`3oool00`000000oooo0?ooo`0b0?ooo`800000
2`3oool00`000000oooo0?ooo`020?ooo`800000<@3oool2000000/0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0_0?ooo`8000002`3oool00`000000oooo0?ooo`020?ooo`<00000
<03oool2000000/0oooo00<000000?ooo`3oool00P3oool2000003<0oooo0P00000:0?ooo`800000
o`3oooo80?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?oo
ool0ooooo`3ooomS0?ooo`00o`3ooooJ0?ooool00000L@00000G0?ooo`00o`3ooooJ0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool05@3oool00380ooooo`00001[000003d0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`030000003oool0
oooo01D0oooo000b0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`120?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0>`3oool00`00
0000oooo0?ooo`050?ooo`@0O`20o`3ooomT0?ooo`030000003oool0oooo01D0oooo000b0?ooo`03
0000003oool0oooo00@0oooo101n084=0?ooo`@0O@223P3oool407/0Q0d0oooo101h08Oo0?ooob/0
oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`050?ooo`@0O`20o`3ooomT0?ooo`03
0000003oool0oooo01D0oooo000b0?ooo`030000003oool0oooo00@0oooo101n084=0?ooo`@0O@22
3P3oool407/0Q0d0oooo101h08L=0?ooo`<0M02;3`3oool306d0TPh0oooo0`1T09/P0?ooo`80B@2f
e@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00D0oooo101o080=0?ooo`@0OP21
o`3ooomC0?ooo`030000003oool0oooo01D0oooo000b0?ooo`8000001@3oool407h0P@d0oooo101m
088>0?ooo`@0N`243@3oool407P0Q``0oooo101d08/>0?ooo`@0K@2B3@3oool406@0V`h0oooo0P1H
0:L@0?ooo`80B@2f3P3oool203T0aR40oooo00<07@3R0?ooo`3oool03`3oool00`0C0>`0oooo0?oo
o`0>0?ooo`0300`0l`3oool0oooo00l0oooo00<0203g0?ooo`3oool03P3oool00`050?X0oooo0?oo
o`0>0?ooo`0300<0o03oool0oooo00h0oooo00<00@3n0?ooo`3oool03`3oool00`010?h0oooo0?oo
o`0>0?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool0103oool2000003d0oooo00<0
00000?ooo`3oool01@3oool407l0P0d0oooo101n087o0?oooe<0oooo00<000000?ooo`3oool05@3o
ool00380oooo00<000000?ooo`3oool0103oool407h0P@d0oooo101m088>0?ooo`@0N`243@3oool4
07P0Q`d0oooo0`1d08/?0?ooo`<0K@2B3P3oool306@0V`h0oooo0P1H0:LQ0?ooo`0303T0aP3oool0
oooo00h0oooo00<0:P3E0?ooo`3oool0/P3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo01H0oooo101n087o0?oooe<0oooo00<000000?ooo`3oool05@3oool00380oooo00<000000?oo
o`3oool0BP3oool00`1d08/0oooo0?ooo`0?0?ooo`0306d0TP3oool0oooo00h0oooo00<0I02K0?oo
o`3oool0mP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo01H0oooo101n084>0?oo
o`@0O@22o`3ooom10?ooo`030000003oool0oooo01D0oooo000b0?ooo`030000003oool0oooo0?l0
ooooI`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo02P0oooo101m08;o0?oood40
oooo00<000000?ooo`3oool05@3oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000
003oool0oooo03/0oooo0P00000Y0?ooo`@0O@22o`3ooom00?ooo`8000005`3oool00380oooo00<0
00000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0:03o
ool407d0PPd0oooo101l08?o0?oooc00oooo00<000000?ooo`3oool05@3oool00380oooo00<00000
0?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0>@3oool4
07`0Pol0oooo<03oool00`000000oooo0?ooo`0E0?ooo`007@3oool2000000@0oooo00<000000?oo
o`3oool00`3oool2000000L0oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0>@3oool407`0Pol0oooo<03oool00`000000oooo0?ooo`0E0?oo
o`00703oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000H0oooo00<00000
0?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0>@3oool4
07`0P`h0oooo101j08Go0?oooah0oooo00<000000?ooo`3oool05@3oool001`0oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`0000060?ooo`<00000o`3ooomU0?ooo`<00000?@3o
ool00`000000oooo0?ooo`1;0?ooo`@0NP25o`3ooolN0?ooo`030000003oool0oooo01D0oooo000F
0?ooo`@000000P3oool010000000oooo0?ooo`0000080?ooo`<000001`3oool00`000000oooo0?oo
o`3o0?ooofL0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`1;0?ooo`@0NP253@3o
ool407L0R?l0oooo3@3oool00`000000oooo0?ooo`0E0?ooo`00703oool010000000oooo0?ooo`00
00080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003o
ool0oooo03/0oooo00<000000?ooo`3oool0B`3oool407X0Q@d0oooo101g08So0?ooo`d0oooo00<0
00000?ooo`3oool05@3oool001`0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`0k0?ooo`030000003o
ool0oooo05`0oooo101g08So0?ooo`d0oooo00<000000?ooo`3oool05@3oool001d0oooo0P00000:
0?ooo`<000001P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`1L0?ooo`@0M`28o`3oool=0?ooo`030000003oool0oooo01D0oooo000b0?oo
o`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo
06h0oooo0`1b08gk0?ooo`030000003oool0oooo01D0oooo000b0?ooo`030000003oool0oooo0?l0
ooooI`3oool00`000000oooo0?ooo`0k0?ooo`800000KP3oool40780SOX0oooo0P00000G0?ooo`00
<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0>`3oool00`000000oooo
0?ooo`1^0?ooo`<0LP2=3P3oool306`0TnX0oooo00<000000?ooo`3oool05@3oool00380oooo0P00
003o0?ooofL0oooo0P00000m0?ooo`030000003oool0oooo06l0oooo00<0LP2=0?ooo`3oool0303o
ool406`0TnX0oooo00<000000?ooo`3oool05@3oool00380oooo00<000000?ooo`3oool0o`3ooomW
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0O`3oool306`0TnX0oooo00<00000
0?ooo`3oool05@3oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0P03oool00`1/09<0oooo0?ooo`0>0?ooo`<0I02Kf03oool00`00
0000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3o
ool0>`3oool00`000000oooo0?ooo`2@0?ooo`@0I02Kf03oool00`000000oooo0?ooo`0E0?ooo`00
<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0>`3oool00`000000oooo
0?ooo`2A0?ooo`<0I02K3`3oool305`0XlH0oooo00<000000?ooo`3oool05@3oool00380oooo00<0
00000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0TP3o
ool00`1T09/0oooo0?ooo`0=0?ooo`@0G02SaP3oool00`000000oooo0?ooo`0E0?ooo`00<P3oool0
0`000000oooo0?ooo`320?ooo`<0HP2M<03oool407L0R0d0oooo101j08D=0?ooo`@0O0233P3oool4
07h0P@d0oooo101n084=0?ooo`@0O`203@3oool407l0P0H0oooo00<000000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`2S0?ooo`<0G02SaP3oool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`00
0000oooo0?ooo`060?ooo`030040oP3oool0oooo00h0oooo00<00P3m0?ooo`3oool03P3oool00`04
0?/0oooo0?ooo`0>0?ooo`0300L0n03oool0oooo0580oooo0P0f0<TQ0?ooo`80E@2Z3P3oool40680
W@h0oooo0`1/09<>0?ooo`<0L`2<3P3oool407L0R0d0oooo101j08D=0?ooo`@0O0233P3oool407h0
P@d0oooo101n084=0?ooo`@0O`203@3oool407l0P0H0oooo00<000000?ooo`3oool0<`3oool20000
00H0oooo00<000000?ooo`3oool0Y03oool00`1L0:<0oooo0?ooo`350?ooo`030000003oool0oooo
01D0oooo000b0?ooo`800000B`3oool00`0;0?@0oooo0?ooo`0>0?ooo`030180k@3oool0oooo00h0
oooo00<06`3T0?ooo`3oool03P3oool00`0W0=P0oooo0?ooo`0?0?ooo`0303H0b@3oool0oooo00d0
oooo0P160;T@0?ooo`80E@2Z3`3oool30680W@d0oooo101/09<=0?ooo`@0L`2<3P3oool407L0R0d0
oooo101j08D=0?ooo`@0O0233P3oool407h0P@d0oooo101n084=0?ooo`@0O`203@3oool407l0P0D0
oooo0P00000d0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0]03oool205D0
Z[H0oooo00<000000?ooo`3oool05@3oool00380oooo00<000000?ooo`3oool0X03oool00`160;T0
oooo0?ooo`0P0?ooo`030680W@3oool0oooo00d0oooo0`1/09<>0?ooo`<0L`2<3P3oool407L0R0d0
oooo101j08D=0?ooo`@0O0233P3oool407h0P@d0oooo101n084=0?ooo`@0O`203@3oool407l0P0H0
oooo00<000000?ooo`3oool0<P3oool010000000oooo0?ooo`0000050?ooo`<00000]03oool205D0
Z[@0oooo0`00000G0?ooo`00<P3oool00`000000oooo0?ooo`3D0?ooo`0306`0T`3oool0oooo00h0
oooo00<0L`2<0?ooo`3oool0OP3oool00`000000oooo0?ooo`0b0?ooo`040000003oool0oooo0000
00D0oooo00<000000?ooo`3oool0aP3oool204h0/J@0oooo00<000000?ooo`3oool05@3oool00380
oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo0380oooo00@000000?ooo`3o
ool000001@3oool00`000000oooo0?ooo`360?ooo`80CP2aY03oool00`000000oooo0?ooo`0E0?oo
o`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0<P3oool010000000
oooo0?ooo`0000050?ooo`030000003oool0oooo0?l0ooooK@3oool00`000000oooo0?ooo`0E0?oo
o`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0<`3oool2000000H0
oooo00<000000?ooo`3oool0f03oool204T0]Y80oooo00<000000?ooo`3oool05@3oool00380oooo
00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0
f03oool204T0]Y80oooo00<000000?ooo`3oool05@3oool00380oooo00<000000?ooo`3oool0o`3o
oomW0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`030000003o
ool0oooo01D0oooo000b0?ooo`8000001`3oool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0
oooo00h0oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0
oooo00h0oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0
oooo00h0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0
oooo00h0oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0
oooo00l0oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?ooo`1J0?ooo`800000?@3oool0
0`000000oooo0?ooo`3Y0?ooo`80AP2iP@3oool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`00
0000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`3Y0?oo
o`80AP2iP@3oool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0
oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3o
ool05@3oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo03/0oooo
0P00003k0?ooo`80A02kK`3oool2000001L0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3o
ool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0?/0oooo00<0A02k0?ooo`3oool0KP3o
ool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<00000
0?ooo`3oool0>`3oool00`000000oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3oool05@3oool0
01d0oooo0P0000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`3o0?oo
o``0oooo0P120;eO0?ooo`030000003oool0oooo01D0oooo000L0?ooo`040000003oool0oooo0000
00X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?oo
o`3oool0>`3oool00`000000oooo0?ooo`3o0?ooo`d0oooo00<0@P2m0?ooo`3oool0G@3oool00`00
0000oooo0?ooo`0E0?ooo`00703oool010000000oooo0?ooo`0000070?ooo`D000001P3oool30000
0?l0ooooI@3oool3000003d0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`030000003oool0oooo
01D0oooo000F0?ooo`@000000P3oool010000000oooo0?ooo`0000070?ooo`040000003oool0oooo
000000L0oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo03/0oooo00<00000
0?ooo`3oool0o`3ooolN0?ooo`80@@2nC@3oool00`000000oooo0?ooo`0E0?ooo`00703oool01000
0000oooo0?ooo`0000080?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0o`3ooomW
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0o`3ooolO0?ooo`030440_P3oool0
oooo04/0oooo00<000000?ooo`3oool05@3oool001`0oooo00@000000?ooo`3oool000002@3oool2
000000L0oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo03/0oooo00<00000
0?ooo`3oool0o`3oool_0?ooo`80@@2n?03oool00`000000oooo0?ooo`0E0?ooo`007@3oool20000
00/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?oo
o`3oool0>`3oool00`000000oooo0?ooo`3o0?oooc00oooo00<0@@2n0?ooo`3oool0>P3oool00`00
0000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3o
ool0>`3oool00`000000oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3oool05@3oool00380oooo
00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo03/0oooo0P00003o0?oood80oooo
0P100;lY0?ooo`8000005`3oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003o
ool0oooo03/0oooo00<000000?ooo`3oool0o`3ooom20?ooo`030400_`3oool0oooo02P0oooo00<0
00000?ooo`3oool05@3oool00380oooo0P00003o0?ooofL0oooo0P00000m0?ooo`030000003oool0
oooo0?l0ooooK@3oool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo0?ooo`3o0?oo
ofL0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`3o0?oooe80oooo0P100;lI0?oo
o`030000003oool0oooo01D0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo0?l0ooooD`3oool00`100;l0oooo0?ooo`0G0?ooo`03
0000003oool0oooo01D0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo
0?ooo`0k0?ooo`030000003oool0oooo00H0oooo00<0003o0?ooo`3oool0o`3ooomT0?ooo`030000
003oool0oooo01D0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?oo
o`0k0?ooo`030000003oool0oooo0?l0ooooI03oool20400_`L0oooo00<000000?ooo`3oool05@3o
ool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo03/0oooo00<00000
0?ooo`3oool0o`3ooomU0?ooo`030400_`3oool0oooo00D0oooo00<000000?ooo`3oool05@3oool0
0380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool0603oool00`000?l0oooo0?ooo`3o0?oooe80oooo00<000000?ooo`3oool05@3oool00380
oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3o
ool0o`3ooom]0?ooo`030000003oool0oooo01D0oooo000b0?ooo`030000003oool0oooo0?l0oooo
I`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0?l0ooooK@3oool00`000000oooo
0?ooo`0E0?ooo`00<P3oool200000?l0ooooI`3oool2000003d0oooo0P00000Z0?ooo`030000o`3o
ool0oooo0?l0oooo@03oool2000001L0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool0
0`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0?l0ooooK@3oool00`000000oooo0?ooo`0E
0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0>`3oool00`00
0000oooo0?ooo`0k0?ooo`030000o`3oool0oooo0?l0oooo;`3oool00`000000oooo0?ooo`0E0?oo
o`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0>`3oool00`000000
oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3oool05@3oool00380oooo00<000000?ooo`3oool0
o`3ooomW0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`030000
003oool0oooo01D0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?oo
o`0k0?ooo`030000003oool0oooo04`0oooo00<0003o0?ooo`3oool0o`3ooolN0?ooo`030000003o
ool0oooo01D0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`0k
0?ooo`030000003oool0oooo0?l0ooooK@3oool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`00
0000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`3o0?oo
ofd0oooo00<000000?ooo`3oool05@3oool00380oooo0P00003o0?ooofL0oooo0P00000m0?ooo`03
0000003oool0oooo05h0oooo00<0003o0?ooo`3oool0o`3oool<0?ooo`030000003oool0oooo01D0
oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo0?l0ooooK@3oool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo0?oo
o`3o0?ooofL0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`1_0?ooo`030000o`3o
ool0oooo0?X0oooo00<000000?ooo`3oool05@3oool00380oooo00<000000?ooo`3oool0o`3ooomW
0?ooo`030000003oool0oooo03/0oooo0P00003o0?ooofd0oooo0P00000G0?ooo`00<P3oool00`00
0000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`3o0?oo
ofd0oooo00<000000?ooo`3oool05@3oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`03
0000003oool0oooo03/0oooo00<000000?ooo`3oool0P@3oool00`000?l0oooo0?ooo`3X0?ooo`03
0000003oool0oooo01D0oooo000M0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`@00000
1P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0>`3oool00`000000oooo
0?ooo`3o0?ooofd0oooo00<000000?ooo`3oool05@3oool001`0oooo00@000000?ooo`3oool00000
203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo
0?ooo`0k0?ooo`030000003oool0oooo0?l0ooooK@3oool00`000000oooo0?ooo`0E0?ooo`00703o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00H0oooo0`00003o0?ooofD0oooo
0`00000m0?ooo`030000003oool0oooo0980oooo00<0003o0?ooo`3oool0e`3oool00`000000oooo
0?ooo`0E0?ooo`005P3oool400000080oooo00@000000?ooo`3oool000002P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo0?l0ooooK@3oool00`000000oooo0?ooo`0E0?ooo`00703oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000
003oool0oooo03/0oooo00<000000?ooo`3oool0Y03oool00`000?l0oooo0?ooo`350?ooo`030000
003oool0oooo01D0oooo000L0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
00001P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0>`3oool00`000000
oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3oool05@3oool001d0oooo0P00000:0?ooo`800000
1`3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool09`3oool2000000@0oooo
00<000000?ooo`3oool00P3oool4000000D0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`030000
003oool0oooo01D0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`2e0?ooo`030000o`3oool0oooo0;@0oooo00<000000?ooo`3oool05@3oool00380oooo00<0
00000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo02H0oooo00@000000?ooo`3oool00000
2P3oool00`000000oooo0?ooo`040?ooo`<00000o`3ooom[0?ooo`<000005`3oool00380oooo00<0
00000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo02H0oooo00@000000?ooo`3oool00000
2P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooK@3oool00`000000oooo
0?ooo`0E0?ooo`00<P3oool200000?l0ooooI`3oool2000002P0oooo00@000000?ooo`3oool00000
2P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0<L0oooo00<0003o0?ooo`3oool0
XP3oool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<0
00000?ooo`3oool09P3oool010000000oooo0?ooo`0000080?ooo`<000001P3oool00`000000oooo
0?ooo`3o0?ooofd0oooo00<000000?ooo`3oool05@3oool00380oooo00<000000?ooo`3oool0o`3o
oomW0?ooo`030000003oool0oooo02L0oooo0P00000;0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0o`3ooom]0?ooo`030000003oool0oooo01D0oooo000b0?ooo`030000003oool0
oooo0?l0ooooI`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0=P0oooo00<0003o
0?ooo`3oool0T@3oool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo0?ooo`3o0?oo
ofL0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`3o0?ooofd0oooo00<000000?oo
o`3oool05@3oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo03/0
oooo00<000000?ooo`3oool0jP3oool00`000?l0oooo0?ooo`1o0?ooo`030000003oool0oooo01D0
oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo0?l0ooooK@3oool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo0?oo
o`3o0?ooofL0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`3o0?ooofd0oooo00<0
00000?ooo`3oool05@3oool00380oooo0P00003o0?ooofL0oooo0P00000m0?ooo`800000o03oool0
0`000?l0oooo0?ooo`1]0?ooo`8000005`3oool00380oooo00<000000?ooo`3oool0o`3ooomW0?oo
o`030000003oool0oooo03/0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`030000003oool0oooo
01D0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`0k0?ooo`03
0000003oool0oooo0?l0ooooK@3oool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo
0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`3o0?ooo`h0oooo
00<0003o0?ooo`3oool0G03oool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo0?oo
o`3o0?ooofL0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`3o0?ooofd0oooo00<0
00000?ooo`3oool05@3oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`030000003oool0oooo01D0oooo000b0?oo
o`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo
0?l0ooooK@3oool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0
oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3o
ool05@3oool00380oooo0P00003o0?ooofL0oooo0P00000m0?ooo`030000003oool0oooo0?l0oooo
K@3oool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<0
00000?ooo`3oool0>`3oool00`000000oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3oool05@3o
ool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo03/0oooo00<00000
0?ooo`3oool0o`3ooom]0?ooo`030000003oool0oooo01D0oooo000b0?ooo`030000003oool0oooo
0?l0ooooI`3oool00`000000oooo0?ooo`0k0?ooo`800000o`3ooom]0?ooo`8000005`3oool00380
oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3o
ool0o`3ooom]0?ooo`030000003oool0oooo01D0oooo000b0?ooo`030000003oool0oooo0?l0oooo
I`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0?l0ooooK@3oool00`000000oooo
0?ooo`0E0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0>`3o
ool00`000000oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3oool05@3oool002T0oooo0P000007
0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo0?l0ooooK@3oool00`000000oooo0?ooo`0E0?ooo`00:03oool010000000oooo0?ooo`000006
0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo00H0oooo00<00P3m0?ooo`3oool0o`3ooomT0?ooo`030000003oool0oooo01D0oooo000X0?oo
o`040000003oool0oooo000000H0oooo0`00003o0?ooofD0oooo0`00000m0?ooo`030000003oool0
oooo0?l0ooooK@3oool00`000000oooo0?ooo`0E0?ooo`00:03oool010000000oooo0?ooo`000006
0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo0?l0ooooK@3oool00`000000oooo0?ooo`0E0?ooo`00:03oool010000000oooo0?ooo`000006
0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo01P0oooo00<0103k0?ooo`3oool0o`3ooomB0?ooo`030000003oool0oooo01D0oooo000X0?oo
o`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`030000003oool0oooo01D0oooo000Y0?oo
o`8000001`3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0>`3oool00`00
0000oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3oool05@3oool00380oooo00<000000?ooo`3o
ool0o`3ooomW0?ooo`030000003oool0oooo03/0oooo0P00000Z0?ooo`0300H0n@3oool0oooo0?l0
oooo@03oool2000001L0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo
0?ooo`0k0?ooo`030000003oool0oooo0?l0ooooK@3oool00`000000oooo0?ooo`0E0?ooo`00<P3o
ool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?oo
o`0k0?ooo`0300/0m03oool0oooo0?l0oooo;`3oool00`000000oooo0?ooo`0E0?ooo`00<P3oool2
00000?l0ooooI`3oool2000003d0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`030000003oool0
oooo01D0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`0k0?oo
o`030000003oool0oooo0?l0ooooK@3oool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`000000
oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`1<0?ooo`03
0140kP3oool0oooo0?l0oooo7P3oool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo
0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`3o0?ooofd0oooo
00<000000?ooo`3oool05@3oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003o
ool0oooo03/0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`030000003oool0oooo01D0oooo000b
0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo05d0oooo00<06`3T0?ooo`3oool0o`3oool=0?ooo`030000003oool0oooo01D0oooo000b0?oo
o`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo
0?l0ooooK@3oool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0
oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3o
ool05@3oool00380oooo0P00003o0?ooofL0oooo0P00000m0?ooo`800000K`3oool00`0X0=L0oooo
0?ooo`3j0?ooo`8000005`3oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003o
ool0oooo03/0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`030000003oool0oooo01D0oooo000b
0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo0800oooo0P0k0<CZ0?ooo`030000003oool0oooo01D0oooo000b0?ooo`030000003oool0oooo
0?l0ooooI`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0840oooo00<0>`340?oo
o`3oool0j03oool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0
oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3o
ool05@3oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo03/0oooo
00<000000?ooo`3oool0TP3oool20540[]P0oooo00<000000?ooo`3oool05@3oool00380oooo00<0
00000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0TP3o
ool20540[]P0oooo00<000000?ooo`3oool05@3oool00380oooo00<000000?ooo`3oool0o`3ooomW
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0X`3oool306T0U/H0oooo00<00000
0?ooo`3oool05@3oool00380oooo0P00003o0?ooofL0oooo0P00000m0?ooo`030000003oool0oooo
0:80oooo101Y09K60?ooo`030000003oool0oooo01D0oooo000b0?ooo`030000003oool0oooo0?l0
ooooI`3oool00`000000oooo0?ooo`0W0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`@0
00001@3oool00`000000oooo0?ooo`2S0?ooo`<0J@2F3P3oool407l0Ok@0oooo00<000000?ooo`3o
ool05@3oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo02H0oooo
00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0:@0
oooo00<0J@2F0?ooo`3oool03@3oool407l0Ok@0oooo00<000000?ooo`3oool05@3oool00380oooo
00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo02H0oooo00@000000?ooo`3oool0
00002@3oool00`000000oooo0?ooo`050?ooo`<00000]03oool407l0O`d0oooo1@2C06bP0?ooo`<0
00005`3oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo02H0oooo
00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0;@0
oooo101o07l=0?ooo`D0T`1/XP3oool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo
0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool09P3oool010000000oooo0?ooo`00000;0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0a03oool609<0K:80oooo00<000000?ooo`3o
ool05@3oool001d0oooo0P0000040?ooo`030000003oool0oooo0080oooo100000060?ooo`030000
003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`0V0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`350?ooo`D0T`1/303oool50:80
GI40oooo00<000000?ooo`3oool05@3oool001`0oooo00@000000?ooo`3oool00000203oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`0W0?oo
o`8000002P3oool2000000H0oooo00<000000?ooo`3oool0a@3oool509<0K0`0oooo1@2R05fA0?oo
o`030000003oool0oooo01D0oooo000L0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`3oool01P3oool300000?l0ooooI@3oool3000003d0oooo00<000000?ooo`3oool0a`3oool00`2C
06`0oooo0?ooo`0;0?ooo`H0XP1M3@3oool40:`0Dh00oooo00<000000?ooo`3oool05@3oool001`0
oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0?l0ooooI`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0=H0oooo1@2R05d<0?oo
o`H0[01CO`3oool00`000000oooo0?ooo`0E0?ooo`00703oool010000000oooo0?ooo`00000;0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0eP3oool50:80G@`0oooo1P2/05=o0?ooo`030000003oool0oooo
01D0oooo000L0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000001P3oool0
0`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`3H
0?ooo`030:80G@3oool0oooo00`0oooo1P2/05<<0?ooo`@0/`1<K`3oool00`000000oooo0?ooo`0E
0?ooo`007@3oool2000000X0oooo0P0000070?ooo`030000003oool0oooo0?l0ooooI`3oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo0>L0oooo1P2/05<;0?ooo`H0/`1<KP3oool00`00
0000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3o
ool0>`3oool00`000000oooo0?ooo`3X0?ooo`@0[01C303oool60;<0C6h0oooo00<000000?ooo`3o
ool05@3oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo03/0oooo
0P00003i0?ooo`H0/`1<3@3oool40;P0Ae`0oooo0P00000G0?ooo`00<P3oool00`000000oooo0?oo
o`3o0?ooofL0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`3h0?ooo`H0/`1<303o
ool60;P0A``0oooo1@2k04A;0?ooo`030000003oool0oooo01D0oooo000b0?ooo`030000003oool0
oooo0?l0ooooI`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0?T0oooo102c04`=
0?ooo`H0^0172`3oool70;/0A4X0oooo00<000000?ooo`3oool05@3oool00380oooo0P00003o0?oo
ofL0oooo0P00000m0?ooo`030000003oool0oooo0?l0oooo2`3oool60;P0A`/0oooo1`2k04A:0?oo
o`030000003oool0oooo01D0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo0?l0oooo2`3oool60;P0A`X0oooo202k04@<0?ooo`D0
_@12>@3oool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo
00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`3o0?ooo``0oooo102h04L<0?ooo`L0^`14
2`3oool70;d0@SP0oooo00<000000?ooo`3oool05@3oool00380oooo00<000000?ooo`3oool0o`3o
oomW0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`L0^`142`3o
ool70;d0@SP0oooo00<000000?ooo`3oool05@3oool00380oooo00<000000?ooo`3oool0o`3ooomW
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0o`3ooolM0?ooo`D0^`142`3oool8
0;d0@P/0oooo1@2n044X0?ooo`030000003oool0oooo01D0oooo000b0?ooo`030000003oool0oooo
0?l0ooooI`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0?l0oooo7`3oool00`2k
04@0oooo0?ooo`0<0?ooo`L0_@122P3oool70;h0@BL0oooo00<000000?ooo`3oool05@3oool00380
oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3o
ool0o`3oool^0?ooo`L0_@122P3oool70;h0@BL0oooo00<000000?ooo`3oool05@3oool00380oooo
00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo03/0oooo0P00003o0?oooc00oooo
1@2m048:0?ooo`P0_P11303oool50;h0@AD0oooo0P00000G0?ooo`00<P3oool200000?l0ooooI`3o
ool2000003d0oooo00<000000?ooo`3oool0o`3ooola0?ooo`030;d0@P3oool0oooo00/0oooo1`2n
044;0?ooo`L0_P115@3oool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo0?ooo`3o
0?ooofL0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`3o0?ooocl0oooo1`2n044;
0?ooo`L0_P112`3oool50;l0@0D0oooo00<000000?ooo`3oool05@3oool00380oooo00<000000?oo
o`3oool0o`3ooomW0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0o`3ooom00?oo
o`D0_P112`3oool80;h0@@X0oooo1`2o04040?ooo`030000003oool0oooo01D0oooo000b0?ooo`03
0000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00D0
oooo101n087o0?ooocT0oooo00<0_P110?ooo`3oool0303oool70;h0@@X0oooo1`2o04040?ooo`03
0000003oool0oooo01D0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo
0?ooo`0k0?ooo`030000003oool0oooo00D0oooo101n087o0?ooodP0oooo1`2n04490?ooo`P0_`10
103oool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<0
00000?ooo`3oool0>`3oool00`000000oooo0?ooo`050?ooo`@0OP21o`3ooom90?ooo`D0_P112`3o
ool70;l0@0@0oooo00<000000?ooo`3oool05@3oool00380oooo00<000000?ooo`3oool0o`3ooomW
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool01@3oool407h0P@d0oooo101m08;o
0?ooocX0oooo00<0_P110?ooo`3oool02`3oool70;l0@0@0oooo00<000000?ooo`3oool05@3oool0
0380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool05P3oool407d0P_l0ooooB@3oool50;l0@0D0oooo00<000000?ooo`3oool05@3oool00380
oooo0P00003o0?ooofL0oooo0P00000m0?ooo`030000003oool0oooo01H0oooo101m088>0?ooo`@0
N`24o`3oooli0?ooo`030;l0@03oool0oooo00D0oooo00<000000?ooo`3oool05@3oool00380oooo
00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0
5P3oool407d0PPh0oooo101k08Co0?oood40oooo00<000000?ooo`3oool05@3oool00380oooo00<0
00000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo03/0oooo0P00000Y0?ooo`@0N`24o`3o
oom00?ooo`8000005`3oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool0:03oool407/0Q0d0oooo101h08Oo0?oooc00oooo00<00000
0?ooo`3oool05@3oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0>@3oool407P0Qol0oooo<03oool00`000000oooo0?ooo`0E0?oo
o`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0>`3oool00`000000
oooo0?ooo`0i0?ooo`@0N027o`3oool`0?ooo`030000003oool0oooo01D0oooo000M0?ooo`800000
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
o`3ooomW0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0>@3oool407P0Q`h0oooo
101d08_o0?oooah0oooo00<000000?ooo`3oool05@3oool001`0oooo00@000000?ooo`3oool00000
2P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo
0?ooo`0k0?ooo`030000003oool0oooo04/0oooo101d08_o0?oooah0oooo00<000000?ooo`3oool0
5@3oool001`0oooo00@000000?ooo`3oool000001`3oool5000000H0oooo0`00003o0?ooofD0oooo
0`00000m0?ooo`030000003oool0oooo04/0oooo101d08_o0?oooah0oooo00<000000?ooo`3oool0
5@3oool001`0oooo00@000000?ooo`3oool000001`3oool010000000oooo0?ooo`0000070?ooo`03
0000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo04/0
oooo101d08/>0?ooo`<0K@2Bo`3oool=0?ooo`030000003oool0oooo01D0oooo000L0?ooo`040000
003oool0oooo000000P0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`3o0?ooofL0
oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`1L0?ooo`@0K@2Bo`3oool=0?ooo`03
0000003oool0oooo01D0oooo000L0?ooo`040000003oool0oooo000000T0oooo0P0000070?ooo`03
0000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo05d0
oooo0`1]09;o0?ooo`d0oooo00<000000?ooo`3oool05@3oool001d0oooo0P00000;0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo03/0oooo
00<000000?ooo`3oool0GP3oool00`1]0980oooo0?ooo`0=0?ooo`<0I02Kn`3oool00`000000oooo
0?ooo`0E0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0>`3o
ool2000006h0oooo101T09_j0?ooo`8000005`3oool00380oooo00<000000?ooo`3oool0o`3ooomW
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0KP3oool306@0Vo/0oooo00<00000
0?ooo`3oool05@3oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0K`3oool00`1T09/0oooo0?ooo`0>0?ooo`80F02WjP3oool00`00
0000oooo0?ooo`0E0?ooo`00<P3oool2000000L0oooo00<0003o0?ooo`3oool03P3oool00`000?l0
oooo0?ooo`0>0?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool03`3oool00`000?l0
oooo0?ooo`0>0?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool03P3oool00`000?l0
oooo0?ooo`0>0?ooo`030000o`3oool0oooo00l0oooo00<0003o0?ooo`3oool03P3oool00`000?l0
oooo0?ooo`0>0?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool03P3oool00`000?l0
oooo0?ooo`0?0?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool0FP3oool2000003d0
oooo00<000000?ooo`3oool0P03oool205P0YnX0oooo00<000000?ooo`3oool05@3oool00380oooo
00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0
TP3oool204T0]]P0oooo00<000000?ooo`3oool05@3oool00380oooo00<000000?ooo`3oool0o`3o
oomW0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0TP3oool204T0]]P0oooo00<0
00000?ooo`3oool05@3oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`030000003oool0oooo01D0oooo000b0?oo
o`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo
0?l0ooooK@3oool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0
oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`2S0?ooo`80>@36a`3oool00`000000
oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo0?ooo`3e0?ooo`@0M`28K@3oool00`000000oooo
0?ooo`0W0?ooo`800000103oool00`000000oooo0?ooo`030?ooo`8000001P3oool00`000000oooo
0?ooo`2T0?ooo`0303T0aP3oool0oooo0<D0oooo00<000000?ooo`3oool05@3oool00380oooo00<0
00000?ooo`3oool0`P3oool30680W@h0oooo0`1/09<>0?ooo`<0L`2<3P3oool407L0R0d0oooo101j
08D=0?ooo`@0O0233P3oool407h0P@d0oooo101n084=0?ooo`@0O`203@3oool407l0P0H0oooo00<0
00000?ooo`3oool09P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000D0
oooo00<000000?ooo`3oool0o`3ooom]0?ooo`030000003oool0oooo01D0oooo000b0?ooo`800000
1`3oool00`010?h0oooo0?ooo`0>0?ooo`030080o@3oool0oooo00h0oooo00<0103k0?ooo`3oool0
3P3oool00`070?P0oooo0?ooo`0>0?ooo`0300/0m03oool0oooo00h0oooo00<04P3]0?ooo`3oool0
<03oool203H0b@l0oooo0P160;T@0?ooo`80E@2Z3P3oool40680W@d0oooo101/09<=0?ooo`@0L`2<
3P3oool407L0R0d0oooo101j08D=0?ooo`@0O0233P3oool407h0P@d0oooo101n084=0?ooo`@0O`20
3@3oool407l0P0D0oooo0P00000X0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3o
ool00`3oool300000;@0oooo00<0:P3E0?ooo`3oool0/`3oool3000001L0oooo000b0?ooo`030000
003oool0oooo06`0oooo00<06`3T0?ooo`3oool03P3oool00`0W0=P0oooo0?ooo`0?0?ooo`0303H0
b@3oool0oooo00h0oooo00<0AP2i0?ooo`3oool03P3oool205D0ZPl0oooo0`1R09d>0?ooo`<0K02C
3P3oool307<0S0h0oooo101g08P=0?ooo`@0NP253@3oool407`0P`h0oooo101n084=0?ooo`@0OP21
3@3oool407l0P0d0oooo101o08060?ooo`030000003oool0oooo02H0oooo00@000000?ooo`3oool0
00002@3oool2000000H0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`030000003oool0oooo01D0
oooo000b0?ooo`030000003oool0oooo0<<0oooo00<0HP2M0?ooo`3oool03P3oool00`1/09<0oooo
0?ooo`0>0?ooo`0307<0S03oool0oooo01h0oooo101j08D=0?ooo`@0O0233P3oool407h0P@d0oooo
101n084=0?ooo`@0O`203@3oool407l0P0H0oooo00<000000?ooo`3oool09P3oool010000000oooo
0?ooo`00000;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`03
0000003oool0oooo01D0oooo000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo
0?ooo`0V0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000001@3oool00`00
0000oooo0?ooo`360?ooo`0301d0hP3oool0oooo0:<0oooo00<000000?ooo`3oool05@3oool00380
oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo02L0oooo0P00000:0?ooo`80
00001P3oool00`000000oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3oool05@3oool00380oooo
00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0
f03oool00`0C0>`0oooo0?ooo`2A0?ooo`030000003oool0oooo01D0oooo000b0?ooo`030000003o
ool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0?l0ooooK@3o
ool00`000000oooo0?ooo`0E0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<00000
0?ooo`3oool0>`3oool00`000000oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3oool05@3oool0
0380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool0jP3oool00`0<0?<0oooo0?ooo`1o0?ooo`030000003oool0oooo01D0oooo000b0?ooo`80
0000o`3ooomW0?ooo`800000?@3oool00`000000oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3o
ool05@3oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo03/0oooo
00<000000?ooo`3oool0n`3oool00`080?L0oooo0?ooo`1^0?ooo`030000003oool0oooo01D0oooo
000b0?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`0k0?ooo`800000o`3o
oom]0?ooo`8000005`3oool00380oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`030000003oool0oooo01D0oooo000b0?oo
o`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo
0?l0oooo3P3oool00`050?X0oooo0?ooo`1L0?ooo`030000003oool0oooo01D0oooo000b0?ooo`03
0000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0?l0
ooooK@3oool00`000000oooo0?ooo`0E0?ooo`007@3oool2000000@0oooo00<000000?ooo`3oool0
0`3oool2000000L0oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo03/0oooo
00<000000?ooo`3oool0o`3ooom]0?ooo`030000003oool0oooo01D0oooo000L0?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`3o0?ooofL0
oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`3o0?oooal0oooo00<00`3l0?ooo`3o
ool0B`3oool00`000000oooo0?ooo`0E0?ooo`00703oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo000000H0oooo0`00003o0?ooofD0oooo0`00000m0?ooo`030000003oool0oooo
0?l0ooooK@3oool00`000000oooo0?ooo`0E0?ooo`00703oool010000000oooo0?ooo`0000080?oo
o`<000001`3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0>`3oool00`00
0000oooo0?ooo`3o0?oooc40oooo00<00@3n0?ooo`3oool0>@3oool00`000000oooo0?ooo`0E0?oo
o`00703oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0o`3ooomW0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0o`3ooom]0?oo
o`030000003oool0oooo01D0oooo000L0?ooo`040000003oool0oooo000000P0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0>`3oool00`00
0000oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3oool05@3oool001d0oooo0P00000:0?ooo`<0
00001P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0>`3oool200000?l0
oooo@`3oool00`010?h0oooo0?ooo`0W0?ooo`8000005`3oool00380oooo00<000000?ooo`3oool0
o`3ooomW0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`030000
003oool0oooo01D0oooo000b0?ooo`030000003oool0oooo00@0oooo101n084=0?ooo`@0O@223P3o
ool407/0Q0d0oooo101h08Oo0?ooob/0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?oo
o`3o0?ooofd0oooo00<000000?ooo`3oool05@3oool00380oooo00<000000?ooo`3oool0103oool4
07h0P@d0oooo101m088>0?ooo`@0N`243@3oool407P0Q`d0oooo0`1d08/?0?ooo`<0K@2B3P3oool3
06@0V`h0oooo0P1H0:L@0?ooo`80B@2fe@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo0?l0ooooE03oool00`000?l0oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo000b0?oo
o`8000001@3oool407h0P@d0oooo101m088>0?ooo`@0N`243@3oool407P0Q``0oooo101d08/>0?oo
o`@0K@2B3@3oool406@0V`h0oooo0P1H0:L@0?ooo`80B@2f3P3oool203T0aQ00oooo00<0:P3E0?oo
o`3oool03P3oool00`0M0>80oooo0?ooo`0?0?ooo`0301<0k03oool0oooo00h0oooo00<0303c0?oo
o`3oool03`3oool00`080?L0oooo0?ooo`0>0?ooo`0300D0nP3oool0oooo00h0oooo00<00`3l0?oo
o`3oool03P3oool00`010?h0oooo0?ooo`0?0?ooo`030040oP3oool0oooo00h0oooo00<0003o0?oo
o`3oool03P3oool00`000?l0oooo0?ooo`040?ooo`800000?@3oool00`000000oooo0?ooo`3o0?oo
ofd0oooo00<000000?ooo`3oool05@3oool00380oooo00<000000?ooo`3oool0103oool407h0P@d0
oooo101m088>0?ooo`@0N`243@3oool407P0Q`d0oooo0`1d08/?0?ooo`<0K@2B3P3oool306@0Vc40
oooo00<0>@360?ooo`3oool0``3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0?l0
ooooI@3oool00`000?l0oooo0?ooo`050?ooo`030000003oool0oooo01D0oooo000b0?ooo`030000
003oool0oooo04X0oooo00<0M02;0?ooo`3oool03`3oool00`1]0980oooo0?ooo`0>0?ooo`0306@0
V`3oool0oooo0?H0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`3o0?ooofd0oooo
00<000000?ooo`3oool05@3oool00380oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`120?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`120?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0k0?ooo`030000003oool0oooo0?l0ooooK@3oool00`000000oooo0?ooo`0E0?ooo`00<P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0o`3ooom]
0?ooo`030000003oool0oooo01D0oooo000b0?ooool00000J`00000m0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo
04<0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool05@3oool00?l0oooofP3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo01D0oooo003o0?ooomX0ooooo`00001a000001L0oooo003o0?ooool0ooooo`3o
oomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0
ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo0000
\
\>"],
  ImageRangeCache->{{{0, 863}, {253.25, 0}} -> {-0.0530409, -0.0147182, \
0.00244042, 0.00244042}, {{21.6875, 411.938}, {247.188, 6}} -> {0.0829106, \
-0.815489, 0.000290591, 0.00611241}, {{451, 841.25}, {247.188, 6}} -> \
{-0.0378489, -0.0968453, 0.000285791, 0.00184968}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  GraphicsArray  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
},
FrontEndVersion->"5.1 for X",
ScreenRectangle->{{0, 2880}, {0, 1200}},
WindowSize->{963, 1077},
WindowMargins->{{Automatic, 159}, {Automatic, 1}},
Visible->True,
ShowSelection->True,
InputAliases->{"intt"->RowBox[ {"\[Integral]", 
        RowBox[ {"\[SelectionPlaceholder]", 
          RowBox[ {"\[DifferentialD]", "\[Placeholder]"}]}]}], 
    "dintt"->RowBox[ {
        SubsuperscriptBox[ 
        "\[Integral]", "\[SelectionPlaceholder]", "\[Placeholder]"], 
        RowBox[ {"\[Placeholder]", 
          RowBox[ {"\[DifferentialD]", "\[Placeholder]"}]}]}], 
    "sumt"->RowBox[ {
        UnderoverscriptBox[ "\[Sum]", 
          RowBox[ {"\[SelectionPlaceholder]", "=", "\[Placeholder]"}], 
          "\[Placeholder]"], "\[Placeholder]"}], "prodt"->RowBox[ {
        UnderoverscriptBox[ "\[Product]", 
          RowBox[ {"\[SelectionPlaceholder]", "=", "\[Placeholder]"}], 
          "\[Placeholder]"], "\[Placeholder]"}], "dt"->RowBox[ {
        SubscriptBox[ "\[PartialD]", "\[Placeholder]"], " ", 
        "\[SelectionPlaceholder]"}], "notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {"\"\[Placeholder]\"", "\[Rule]", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Title"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Color"->RGBColor[0.269993, 0.308507, 0.6]},
    CellLabelMargins->{{12, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{24, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->12],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{8, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->8],
  
  Cell[StyleData[All, "SlideShow"],
    PageWidth->WindowWidth,
    ScrollingOptions->{"PagewiseDisplay"->True,
    "VerticalScrollRange"->Fit},
    ShowCellBracket->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{27, Inherited}, {10, 30}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LineSpacing->{1, 11},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{27, 10}, {10, 30}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "SlideShow"]],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {12, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{27, Inherited}, {20, 2}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{27, 10}, {20, 2}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "SlideShow"]],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{27, Inherited}, {8, 2}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->16],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "SlideShow"]],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{0, 0}, {0, 1}},
    CellMargins->{{27, Inherited}, {8, 34}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->4,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LineSpacing->{1, 2},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->20,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "SlideShow"]],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{60, Inherited}, {8, 12}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "SlideShow"]],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{60, Inherited}, {2, 10}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "SlideShow"]],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{60, 10}, {7, 7}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["Text", "SlideShow"]],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    Hyphenation->True,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{60, 10}, {6, 6}},
    DefaultNewInlineCellStyle->"None",
    LineSpacing->{1, 3},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "SlideShow"]],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    TextJustification->0.5,
    Hyphenation->True,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names. Some attributes for these styles are actually set in FormatType Styles \
(in the last section of this stylesheet). \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{66, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Mathematica",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}},
    FontSize->11],
  
  Cell[StyleData["Input", "SlideShow"]],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InputOnly"],
    CellMargins->{{66, 10}, {7, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Mathematica",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["InputOnly", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["InputOnly", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}},
    FontSize->11],
  
  Cell[StyleData["InputOnly", "SlideShow"]],
  
  Cell[StyleData["InputOnly", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{66, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}},
    FontSize->11],
  
  Cell[StyleData["Output", "SlideShow"]],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{66, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    AutoStyleOptions->{"UnmatchedBracketStyle"->None},
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->RGBColor[0.6, 0.100008, 0.100008]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11],
  
  Cell[StyleData["Message", "SlideShow"]],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{66, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11],
  
  Cell[StyleData["Print", "SlideShow"]],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageMargins->{{38, Inherited}, {Inherited, 0}},
    Magnification->0.6],
  
  Cell[StyleData["Graphics", "SlideShow"]],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    Magnification->0.8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    LanguageCategory->None,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0.269993, 0.308507, 0.6]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "SlideShow"]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FrameLabel"],
    LanguageCategory->None,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["FrameLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["FrameLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["FrameLabel", "SlideShow"]],
  
  Cell[StyleData["FrameLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Inert"],
    StyleMenuListing->None,
    Background->RGBColor[0.870588, 0.905882, 0.972549]],
  
  Cell[StyleData["Inert", "Printout"],
    StyleMenuListing->None,
    Background->GrayLevel[1]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["InlineFormula", "SlideShow"]],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{60, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["DisplayFormula", "SlideShow"]],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{60, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->False,
    LanguageCategory->"Formula",
    ScriptLevel->1,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["Program", "SlideShow"]],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Outline Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline1"],
    CellMargins->{{60, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 50},
    ParagraphIndent->-38,
    CounterIncrements->"Outline1",
    CounterAssignments->{{"Outline2", 0}, {"Outline3", 0}, {"Outline4", 0}},
    FontSize->18,
    FontWeight->"Bold",
    CounterBoxOptions->{
    CounterFunction:>Utilities`Notation`Private`CapitalRomanNumeral}],
  
  Cell[StyleData["Outline1", "SlideShow"]],
  
  Cell[StyleData["Outline1", "Printout"],
    CounterBoxOptions->{
    CounterFunction:>Utilities`Notation`Private`CapitalRomanNumeral}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline2"],
    CellMargins->{{90, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    CounterAssignments->{{"Outline3", 0}, {"Outline4", 0}},
    FontSize->15,
    FontWeight->"Bold",
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "A", "Z"], #]&)}],
  
  Cell[StyleData["Outline2", "SlideShow"]],
  
  Cell[StyleData["Outline2", "Printout"],
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "A", "Z"], #]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline3"],
    CellMargins->{{120, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-21,
    CounterIncrements->"Outline3",
    CounterAssignments->{{"Outline4", 0}},
    FontSize->12,
    CounterBoxOptions->{CounterFunction:>Identity}],
  
  Cell[StyleData["Outline3", "SlideShow"]],
  
  Cell[StyleData["Outline3", "Printout"],
    CounterBoxOptions->{CounterFunction:>Identity}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline4"],
    CellMargins->{{150, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 80},
    ParagraphIndent->-18,
    CounterIncrements->"Outline4",
    FontSize->10,
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "a", "z"], #]&)}],
  
  Cell[StyleData["Outline4", "SlideShow"]],
  
  Cell[StyleData["Outline4", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Hyperlink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["Hyperlink", "SlideShow"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["MainBookLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["MainBookLink", "SlideShow"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["AddOnsLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["AddOnsLink", "SlideShow"]],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["RefGuideLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["RefGuideLink", "SlideShow"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLinkText"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLinkText", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["RefGuideLinkText", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["RefGuideLinkText", "SlideShow"]],
  
  Cell[StyleData["RefGuideLinkText", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["GettingStartedLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["GettingStartedLink", "SlideShow"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DemosLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "Demos", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["DemosLink", "SlideShow"]],
  
  Cell[StyleData["DemosLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TourLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "Tour", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["TourLink", "SlideShow"]],
  
  Cell[StyleData["TourLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["OtherInformationLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["OtherInformationLink", "SlideShow"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MasterIndexLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MasterIndex", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MasterIndexLink", "SlideShow"]],
  
  Cell[StyleData["MasterIndexLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, Placeholder]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Placeholder->True,
    StyleMenuListing->None,
    FontSlant->"Italic",
    FontColor->RGBColor[0.890623, 0.864698, 0.384756],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "SlideShow"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PrimaryPlaceholder"],
    StyleMenuListing->None,
    DrawHighlighted->True,
    FontSlant->"Italic",
    Background->RGBColor[0.912505, 0.891798, 0.507774],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["PrimaryPlaceholder", "Presentation"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Condensed"]],
  
  Cell[StyleData["PrimaryPlaceholder", "SlideShow"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options. This is particularly true of Input and Output.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    Hyphenation->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    InputAutoReplacements->{},
    AllowInlineCells->False,
    Hyphenation->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{0.6, 1},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    LanguageCategory->"Formula",
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Automatic Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are used to affect the display \
of certain types of objects in typeset expressions.  For example, \
\"UnmatchedBracket\" style defines how unmatched bracket, curly bracket, and \
parenthesis characters are displayed (typically by coloring them to make them \
stand out).\
\>", "Text"],
  
  Cell[StyleData["UnmatchedBracket"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.760006, 0.330007, 0.8]],
  
  Cell[StyleData["Completions"],
    StyleMenuListing->None,
    FontFamily->"Courier"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles from HelpBrowser", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{66, 12}, {2, 24}},
    PageBreakBelow->False,
    CellFrameMargins->{{8, 8}, {8, 2}},
    CellFrameColor->GrayLevel[0.700008],
    CellFrameLabelMargins->4,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None,
    FontColor->GrayLevel[0.2]],
  
  Cell[StyleData["MathCaption", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["MathCaption", "SlideShow"]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{39, 0}, {0, 14}},
    Hyphenation->True,
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectName"],
    ShowCellBracket->True,
    CellMargins->{{66, 4}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Mathematica",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ObjectName", "SlideShow"]],
  
  Cell[StyleData["ObjectName", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Usage"],
    ShowCellBracket->True,
    CellMargins->{{66, 4}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Mathematica",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["Usage", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Usage", "SlideShow"]],
  
  Cell[StyleData["Usage", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notes"],
    ShowCellBracket->True,
    CellMargins->{{66, 4}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Mathematica",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["Notes", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Notes", "SlideShow"]],
  
  Cell[StyleData["Notes", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineOutput"],
    ShowCellBracket->True,
    CellMargins->{{66, 4}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Mathematica",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["InlineOutput", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["InlineOutput", "SlideShow"]],
  
  Cell[StyleData["InlineOutput", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Emphasis Boxes and Pictures", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Box"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["Box", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Box", "SlideShow"]],
  
  Cell[StyleData["Box", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DoubleBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->2,
    RowAlignments->Top}],
  
  Cell[StyleData["DoubleBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DoubleBox", "SlideShow"]],
  
  Cell[StyleData["DoubleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["1ColumnBox", "SlideShow"]],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    SingleLetterItalics->False,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->{0.31, 0.67}}],
  
  Cell[StyleData["2ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["2ColumnBox", "SlideShow"]],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->0.46}],
  
  Cell[StyleData["2ColumnEvenBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["2ColumnEvenBox", "SlideShow"]],
  
  Cell[StyleData["2ColumnEvenBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["2ColumnSmallBox", "SlideShow"]],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->0.32}],
  
  Cell[StyleData["3ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["3ColumnBox", "SlideShow"]],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.24,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["3ColumnSmallBox", "SlideShow"]],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    SingleLetterItalics->False,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->{0.13, 0.35, 0.13, 0.35}}],
  
  Cell[StyleData["4ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["4ColumnBox", "SlideShow"]],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->0.202}],
  
  Cell[StyleData["5ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["5ColumnBox", "SlideShow"]],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->{0.12, 0.22, 0.12, 0.12, 0.22, 0.12}}],
  
  Cell[StyleData["6ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["6ColumnBox", "SlideShow"]],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FramedBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["FramedBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["FramedBox", "SlideShow"]],
  
  Cell[StyleData["FramedBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.4, 0.6},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DefinitionBox", "SlideShow"]],
  
  Cell[StyleData["DefinitionBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox3Col"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.35, 0.2, 0.45},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox3Col", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DefinitionBox3Col", "SlideShow"]],
  
  Cell[StyleData["DefinitionBox3Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox4Col"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.15, 0.35, 0.15, 0.35},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox4Col", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DefinitionBox4Col", "SlideShow"]],
  
  Cell[StyleData["DefinitionBox4Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox5Col"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->0.2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox5Col", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DefinitionBox5Col", "SlideShow"]],
  
  Cell[StyleData["DefinitionBox5Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox6Col"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.13, 0.24, 0.13, 0.13, 0.24, 0.13},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox6Col", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DefinitionBox6Col", "SlideShow"]],
  
  Cell[StyleData["DefinitionBox6Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TopBox", "SlideShow"]],
  
  Cell[StyleData["TopBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{27, 12}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakAbove->False,
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["MiddleBox", "SlideShow"]],
  
  Cell[StyleData["MiddleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 2}},
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BottomBox"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{27, 12}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakAbove->False,
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["BottomBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["BottomBox", "SlideShow"]],
  
  Cell[StyleData["BottomBox", "Printout"],
    CellMargins->{{2, 0}, {0, -5}},
    FontSize->10,
    Background->GrayLevel[1],
    GridBoxOptions->{RowMinHeight->2.2}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{27, 12}, {-2, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopSpanBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TopSpanBox", "SlideShow"]],
  
  Cell[StyleData["TopSpanBox", "Printout"],
    CellMargins->{{2, 0}, {-2, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{27, 12}, {0, 0}},
    CellHorizontalScrolling->True,
    PageBreakAbove->False,
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleSpanBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["MiddleSpanBox", "SlideShow"]],
  
  Cell[StyleData["MiddleSpanBox", "Printout"],
    CellMargins->{{2, 0}, {-5, 0}},
    FontSize->10,
    Background->GrayLevel[1],
    GridBoxOptions->{RowMinHeight->1.8}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{27, Inherited}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Picture", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Picture", "SlideShow"]],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, Inherited}, {4, 4}},
    Magnification->0.65]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OpenCloseItemizedPicture"],
    CellMargins->{{88, 4}, {4, 4}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["OpenCloseItemizedPicture", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["OpenCloseItemizedPicture", "SlideShow"]],
  
  Cell[StyleData["OpenCloseItemizedPicture", "Printout"],
    CellMargins->{{76, 2}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->1,
    "ClosedCellHeight"->0},
    CellOpen->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedPicture"],
    CellMargins->{{88, 4}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedPicture", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ItemizedPicture", "SlideShow"]],
  
  Cell[StyleData["ItemizedPicture", "Printout"],
    CellMargins->{{77, 2}, {4, -4}},
    Magnification->0.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ListGraphic"],
    CellMargins->{{88, 4}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ListGraphic", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ListGraphic", "SlideShow"]],
  
  Cell[StyleData["ListGraphic", "Printout"],
    CellMargins->{{77, 2}, {4, -4}},
    Magnification->0.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ListNoteBox"],
    CellFrame->0.5,
    CellMargins->{{88, 12}, {8, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["ListNoteBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ListNoteBox", "SlideShow"]],
  
  Cell[StyleData["ListNoteBox", "Printout"],
    CellMargins->{{77, 4}, {6, 2}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellMargins->{{41, 4}, {0, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["PictureGroup", "SlideShow"]],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{76, 2}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->1,
    "ClosedCellHeight"->0},
    CellOpen->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Sound"],
    ShowCellBracket->True,
    CellMargins->{{27, Inherited}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Sound", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Sound", "SlideShow"]],
  
  Cell[StyleData["Sound", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{35, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.34, 0.64},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["2ColumnTable", "SlideShow"]],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenTable"],
    CellMargins->{{35, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.49,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnEvenTable", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["2ColumnEvenTable", "SlideShow"]],
  
  Cell[StyleData["2ColumnEvenTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{35, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.28, 0.28, 0.43},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["3ColumnTable", "SlideShow"]],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Slide Show Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideShowNavigationBar"],
    Editable->False,
    CellFrame->True,
    CellMargins->{{0, 0}, {3, 3}},
    CellElementSpacings->{"CellMinHeight"->0.8125},
    CellGroupingRules->{"SectionGrouping", 30},
    CellFrameMargins->False,
    CellFrameColor->GrayLevel[1],
    CellFrameLabelMargins->False,
    TextAlignment->Center,
    CounterIncrements->"SlideShowNavigationBar",
    StyleMenuListing->None,
    FontSize->10,
    Background->GrayLevel[0.8],
    Magnification->1,
    GridBoxOptions->{GridBaseline->Center,
    RowSpacings->0,
    ColumnSpacings->0,
    ColumnWidths->{3.5, 3.5, 3.5, 3.5, 13, 5, 4},
    RowAlignments->Baseline,
    ColumnAlignments->{
      Center, Center, Center, Center, Center, Center, Right, Center}}],
  
  Cell[StyleData["SlideShowNavigationBar", "Presentation"]],
  
  Cell[StyleData["SlideShowNavigationBar", "SlideShow"],
    Deletable->False,
    ShowCellBracket->False,
    CellMargins->{{-1, -1}, {-1, -1}},
    PageBreakAbove->True,
    CellFrameMargins->{{1, 1}, {0, 0}}],
  
  Cell[StyleData["SlideShowNavigationBar", "Printout"],
    CellMargins->{{18, 4}, {4, 4}},
    LineSpacing->{1, 3},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideShowSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{0, 0}, {10, 0}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->{{12, 4}, {6, 12}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Plain",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.408011, 0.440726, 0.8]],
  
  Cell[StyleData["SlideShowSection", "Presentation"],
    CellFrameMargins->{{20, 10}, {10, 18}},
    FontSize->27],
  
  Cell[StyleData["SlideShowSection", "SlideShow"],
    ShowCellBracket->False,
    PageBreakAbove->True],
  
  Cell[StyleData["SlideShowSection", "Printout"],
    CellMargins->{{18, 30}, {0, 30}},
    CellFrameMargins->5,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideHyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontSize->26,
    FontColor->GrayLevel[0.400015],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonMinHeight->0.85,
    ButtonMargins->0.5,
    ButtonNote->None}],
  
  Cell[StyleData["SlideHyperlink", "Presentation"],
    CellMargins->{{14, 10}, {6, 12}},
    FontSize->36],
  
  Cell[StyleData["SlideHyperlink", "SlideShow"]],
  
  Cell[StyleData["SlideHyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideTOCLink"],
    CellMargins->{{24, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Helvetica",
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonMargins->1.5,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["SlideTOCLink", "Presentation"],
    CellMargins->{{35, 10}, {8, 8}},
    FontSize->18],
  
  Cell[StyleData["SlideTOCLink", "SlideShow"]],
  
  Cell[StyleData["SlideTOCLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideTOC"],
    CellDingbat->"\[Bullet]",
    CellMargins->{{18, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    FontFamily->"Helvetica"],
  
  Cell[StyleData["SlideTOC", "Presentation"],
    CellMargins->{{25, 10}, {10, 5}},
    FontSize->18],
  
  Cell[StyleData["SlideTOC", "SlideShow"],
    FontSize->14],
  
  Cell[StyleData["SlideTOC", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 224, 5, 84, "Text"],

Cell[CellGroupData[{
Cell[2003, 60, 51, 1, 27, "Input"],
Cell[2057, 63, 74, 1, 23, "Print"]
}, Open  ]],
Cell[2146, 67, 54, 1, 27, "Input"],
Cell[2203, 70, 49, 1, 27, "Input"],
Cell[2255, 73, 201, 3, 59, "Input"],

Cell[CellGroupData[{
Cell[2481, 80, 434, 8, 43, "Input"],
Cell[2918, 90, 38054, 797, 96, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41009, 892, 121, 2, 43, "Input"],
Cell[41133, 896, 34873, 719, 235, "Print"],
Cell[76009, 1617, 26708, 525, 195, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[102754, 2147, 52, 1, 27, "Input"],
Cell[102809, 2150, 4380, 105, 369, "Print"]
}, Open  ]],
Cell[107204, 2258, 200, 4, 43, "Input"],
Cell[107407, 2264, 283, 9, 10, "Text"],
Cell[107693, 2275, 237, 5, 43, "Input"],

Cell[CellGroupData[{
Cell[107955, 2284, 372, 9, 187, "Input"],
Cell[108330, 2295, 35, 1, 27, "Output"],
Cell[108368, 2298, 36, 1, 27, "Output"],
Cell[108407, 2301, 36, 1, 27, "Output"],
Cell[108446, 2304, 35, 1, 27, "Output"],
Cell[108484, 2307, 36, 1, 27, "Output"],
Cell[108523, 2310, 36, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[108596, 2316, 218, 4, 75, "Input"],
Cell[108817, 2322, 306, 5, 29, "Output"],
Cell[109126, 2329, 556, 8, 46, "Output"],
Cell[109685, 2339, 53, 1, 27, "Output"]
}, Open  ]],
Cell[109753, 2343, 285, 9, 5, "Text"],

Cell[CellGroupData[{
Cell[110063, 2356, 435, 9, 139, "Input"],
Cell[110501, 2367, 36, 1, 27, "Output"],
Cell[110540, 2370, 37, 1, 27, "Output"],
Cell[110580, 2373, 36, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[110653, 2379, 263, 5, 75, "Input"],
Cell[110919, 2386, 36, 1, 27, "Output"],
Cell[110958, 2389, 35, 1, 27, "Output"],
Cell[110996, 2392, 38, 1, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[111071, 2398, 255, 5, 75, "Input"],
Cell[111329, 2405, 306, 5, 29, "Output"],
Cell[111638, 2412, 556, 8, 46, "Output"],
Cell[112197, 2422, 38, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[112272, 2428, 75, 1, 27, "Input"],
Cell[112350, 2431, 556, 8, 46, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[112943, 2444, 158, 2, 43, "Input"],
Cell[113104, 2448, 1304, 23, 138, "Output"],
Cell[114411, 2473, 103, 2, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[114551, 2480, 158, 2, 43, "Input"],
Cell[114712, 2484, 1028, 19, 101, "Output"],
Cell[115743, 2505, 93, 1, 44, "Output"]
}, Open  ]],
Cell[115851, 2509, 283, 9, 10, "Text"],
Cell[116137, 2520, 288, 5, 59, "Input"],

Cell[CellGroupData[{
Cell[116450, 2529, 166, 3, 43, "Input"],
Cell[116619, 2534, 51, 1, 27, "Output"],
Cell[116673, 2537, 175, 3, 44, "Output"]
}, Open  ]],
Cell[116863, 2543, 920, 15, 203, "Input"],

Cell[CellGroupData[{
Cell[117808, 2562, 154, 3, 43, "Input"],
Cell[117965, 2567, 39, 1, 23, "Print"],
Cell[118007, 2570, 42, 1, 23, "Print"],
Cell[118052, 2573, 42, 1, 23, "Print"],
Cell[118097, 2576, 58, 1, 23, "Print"],
Cell[118158, 2579, 58, 1, 23, "Print"],
Cell[118219, 2582, 56, 1, 25, "Print"],
Cell[118278, 2585, 53, 1, 23, "Print"],
Cell[118334, 2588, 52, 1, 23, "Print"],
Cell[118389, 2591, 52, 1, 23, "Print"],
Cell[118444, 2594, 37, 1, 23, "Print"],
Cell[118484, 2597, 36, 1, 23, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[118557, 2603, 82, 1, 27, "Input"],
Cell[118642, 2606, 1298, 26, 222, "Output"]
}, Open  ]],
Cell[119955, 2635, 436, 8, 59, "Input"],
Cell[120394, 2645, 333, 7, 75, "Input"],

Cell[CellGroupData[{
Cell[120752, 2656, 185, 4, 27, "Input"],
Cell[120940, 2662, 56884, 1468, 263, 11041, 899, "GraphicsData", \
"PostScript", "Graphics"],
Cell[177827, 4132, 135, 3, 27, "Output"]
}, Open  ]],
Cell[177977, 4138, 283, 9, 10, "Text"],
Cell[178263, 4149, 32, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[178320, 4153, 200, 3, 59, "Input"],
Cell[178523, 4158, 387, 6, 97, "Output"],
Cell[178913, 4166, 387, 6, 97, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[179337, 4177, 110, 2, 43, "Input"],
Cell[179450, 4181, 454, 8, 29, "Output"],
Cell[179907, 4191, 454, 8, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[180398, 4204, 116, 2, 43, "Input"],
Cell[180517, 4208, 454, 8, 29, "Output"],
Cell[180974, 4218, 454, 8, 29, "Output"]
}, Open  ]],
Cell[181443, 4229, 283, 9, 8, "Text"],

Cell[CellGroupData[{
Cell[181751, 4242, 239, 4, 59, "Input"],
Cell[181993, 4248, 565, 9, 134, "Output"],
Cell[182561, 4259, 387, 6, 97, "Output"],
Cell[182951, 4267, 387, 6, 97, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[183375, 4278, 78, 1, 27, "Input"],
Cell[183456, 4281, 397, 6, 81, "Output"]
}, Open  ]],
Cell[183868, 4290, 283, 9, 8, "Text"],

Cell[CellGroupData[{
Cell[184176, 4303, 137, 2, 43, "Input"],
Cell[184316, 4307, 1467, 26, 83, "Output"],
Cell[185786, 4335, 1467, 26, 83, "Output"]
}, Open  ]],
Cell[187268, 4364, 283, 9, 10, "Text"],
Cell[187554, 4375, 57, 1, 27, "Input"],
Cell[187614, 4378, 164, 3, 43, "Input"],

Cell[CellGroupData[{
Cell[187803, 4385, 82, 1, 27, "Input"],
Cell[187888, 4388, 5945, 106, 786, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[193870, 4499, 116, 2, 27, "Input"],
Cell[193989, 4503, 118, 2, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[194144, 4510, 503, 11, 91, "Input"],
Cell[194650, 4523, 72165, 2222, 263, 19572, 1569, "GraphicsData", \
"PostScript", "Graphics"],
Cell[266818, 6747, 135, 3, 27, "Output"]
}, Open  ]],
Cell[266968, 6753, 160, 3, 43, "Input"],

Cell[CellGroupData[{
Cell[267153, 6760, 503, 11, 91, "Input"],
Cell[267659, 6773, 65877, 1908, 263, 16519, 1295, "GraphicsData", \
"PostScript", "Graphics"],
Cell[333539, 8683, 135, 3, 27, "Output"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

